@@ -1,7 +1,7 @@
 #!/bin/bash
 # StarPU --- Runtime system for heterogeneous multicore architectures.
 #
-# Copyright (C) 2023-2024  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+# Copyright (C) 2023-2025   University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
 #
 # StarPU is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -21,7 +21,7 @@ set -e
 export starpudir=$PWD
 export rootdir=$PWD/../starpu_chameleon
 export builddir=$PWD/../starpu_chameleon/build
-rm -rf $rootdir
+if test -d $rootdir ; then rm -rf $rootdir ; fi
 mkdir -p $builddir
 
 ./autogen.sh
@@ -38,7 +38,7 @@ cd chameleon
 git show HEAD
 mkdir build
 cd build
-CFLAGS=-g cmake ../ -DCHAMELEON_USE_CUDA=ON -DCHAMELEON_USE_MPI=ON
+CFLAGS=-g cmake ../ -DCHAMELEON_USE_MPI=ON
 make -j 20
 
 set +e
