@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2013, 2014  CNRS
+ * Copyright (C) 2013-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -40,7 +40,7 @@ void dummy_big_kernel(void *descr[], void *cl_arg)
 	int i;
 
 	starpu_codelet_unpack_args(cl_arg, &nb_data);
-	assert(nb_data == 9);
+	assert(nb_data == STARPU_NMAXBUFS + 1);
 	FPRINTF(stderr, "Number of data: %d\n", nb_data);
 
 	for(i=0 ; i<nb_data; i++)
@@ -65,14 +65,21 @@ struct starpu_codelet dummy_big_cl =
 	.nbuffers = STARPU_NMAXBUFS+1
 };
 
-int main(int argc, char **argv)
+struct starpu_codelet dummy_variable_cl =
+{
+	.cpu_funcs = {dummy_big_kernel},
+	.cpu_funcs_name = {"dummy_big_kernel"},
+	.nbuffers = STARPU_VARIABLE_NBUFFERS
+};
+
+int main(void)
 {
 	starpu_data_handle_t handle;
 	struct starpu_data_descr *descrs;
 	int ret;
 	int val=42;
 	int i;
-	struct starpu_task *task, *task2;
+	struct starpu_task *task, *task2, *task3;
 
 	ret = starpu_init(NULL);
 	if (ret == -ENODEV) return 77;
@@ -80,6 +87,8 @@ int main(int argc, char **argv)
 
 	starpu_variable_data_register(&handle, STARPU_MAIN_RAM, (uintptr_t)&val, sizeof(int));
 
+
+	/* This tests a small constant number of arguments with starpu_task_submit */
 	task = starpu_task_create();
 	task->synchronous = 1;
 	task->cl = &dummy_small_cl;
@@ -93,6 +102,8 @@ int main(int argc, char **argv)
 	if (ret == -ENODEV) goto enodev;
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_submit");
 
+
+	/* This tests a large constant number of arguments with starpu_task_submit */
 	task2 = starpu_task_create();
 	task2->synchronous = 1;
 	task2->cl = &dummy_big_cl;
@@ -111,15 +122,40 @@ int main(int argc, char **argv)
 	if (ret == -ENODEV) goto enodev;
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_submit");
 
+
+	/* This tests a large variable number of arguments with starpu_task_submit */
+	task3 = starpu_task_create();
+	task3->synchronous = 1;
+	task3->cl = &dummy_variable_cl;
+	task3->cl_arg_free = 1;
+	starpu_codelet_pack_args(&task3->cl_arg, &task3->cl_arg_size,
+				 STARPU_VALUE, &(dummy_big_cl.nbuffers), sizeof(dummy_big_cl.nbuffers),
+				 0);
+	task3->dyn_handles = malloc(dummy_big_cl.nbuffers * sizeof(*(task3->dyn_handles)));
+	task3->dyn_modes = malloc(dummy_big_cl.nbuffers * sizeof(*(task3->dyn_modes)));
+	task3->nbuffers = dummy_big_cl.nbuffers;
+	for(i=0 ; i<dummy_big_cl.nbuffers ; i++)
+	{
+		task3->dyn_handles[i] = handle;
+		task3->dyn_modes[i] = STARPU_RW;
+	}
+	ret = starpu_task_submit(task3);
+	if (ret == -ENODEV) goto enodev;
+	STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_submit");
+
+
+	/* This tests a small number of arguments with starpu_task_insert */
 	ret = starpu_task_insert(&dummy_small_cl,
 				 STARPU_VALUE, &(dummy_small_cl.nbuffers), sizeof(dummy_small_cl.nbuffers),
 				 STARPU_RW, handle,
 				 0);
 	if (ret == -ENODEV) goto enodev;
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_insert");
-        ret = starpu_task_wait_for_all();
+	ret = starpu_task_wait_for_all();
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_wait_for_all");
 
+
+	/* This tests a large constant number of arguments with starpu_task_insert */
 	descrs = malloc(dummy_big_cl.nbuffers * sizeof(struct starpu_data_descr));
 	for(i=0 ; i<dummy_big_cl.nbuffers ; i++)
 	{
@@ -132,10 +168,29 @@ int main(int argc, char **argv)
 				 0);
 	if (ret == -ENODEV) goto enodev;
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_insert");
-        ret = starpu_task_wait_for_all();
+	ret = starpu_task_wait_for_all();
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_wait_for_all");
 	free(descrs);
 
+
+	/* This tests a large variable number of arguments with starpu_task_insert */
+	descrs = malloc(dummy_big_cl.nbuffers * sizeof(struct starpu_data_descr));
+	for(i=0 ; i<dummy_big_cl.nbuffers ; i++)
+	{
+		descrs[i].handle = handle;
+		descrs[i].mode = STARPU_RW;
+	}
+	ret = starpu_task_insert(&dummy_variable_cl,
+				 STARPU_VALUE, &(dummy_big_cl.nbuffers), sizeof(dummy_big_cl.nbuffers),
+				 STARPU_DATA_MODE_ARRAY, descrs, dummy_big_cl.nbuffers,
+				 0);
+	if (ret == -ENODEV) goto enodev;
+	STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_insert");
+	ret = starpu_task_wait_for_all();
+	STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_wait_for_all");
+	free(descrs);
+
+
 	starpu_data_unregister(handle);
 	starpu_shutdown();
 
