@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2011-2012 INRIA
+ * Copyright (C) 2011-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -30,12 +30,13 @@ static int nopencl = 0;
 static struct point array_of_structs[N_ELEMENTS];
 static starpu_data_handle_t array_of_structs_handle;
 
-void
-multiformat_scal_cpu_func(void *buffers[], void *args)
+void multiformat_scal_cpu_func(void *buffers[], void *args)
 {
 	struct point *aos;
 	unsigned int n, i;
 
+	(void)args;
+
 	aos = (struct point *) STARPU_MULTIFORMAT_GET_CPU_PTR(buffers[0]);
 	n = STARPU_MULTIFORMAT_GET_NX(buffers[0]);
 
@@ -110,12 +111,12 @@ static struct starpu_codelet opencl_cl =
 #endif /* !STARPU_USE_OPENCL */
 
 /*
- * Main functions 
+ * Main functions
  */
 static void
 init_problem_data(void)
 {
-	int i; 
+	int i;
 	for (i = 0; i < N_ELEMENTS; i++)
 	{
 		array_of_structs[i].x = 1.0 + i;
@@ -274,7 +275,18 @@ main(void)
 #ifdef STARPU_USE_CPU
 	int ret;
 
-	ret = starpu_init(NULL);
+	struct starpu_conf conf;
+	starpu_conf_init(&conf);
+
+	/* this example doesn't support Master-Slave */
+	conf.nmpi_ms = 0;
+	conf.ntcpip_ms = 0;
+#if defined(STARPU_USE_CUDA0) || defined(STARPU_USE_CUDA1)
+	conf.ncuda = 0;
+#endif
+
+	ret = starpu_init(&conf);
+	if (ret == -ENODEV) return 77;
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_init");
 
 	ncpu = starpu_cpu_worker_get_count();
@@ -295,7 +307,7 @@ main(void)
 	ret = starpu_opencl_load_opencl_from_file("examples/basic_examples/multiformat_opencl_kernel.cl",
 						  &opencl_program, NULL);
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_opencl_load_opencl_from_file");
-	ret = starpu_opencl_load_opencl_from_file("examples/basic_examples/multiformat_conversion_codelets_opencl_kernel.cl", 
+	ret = starpu_opencl_load_opencl_from_file("examples/basic_examples/multiformat_conversion_codelets_opencl_kernel.cl",
 						  &opencl_conversion_program, NULL);
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_opencl_load_opencl_from_file");
 #endif
@@ -312,9 +324,10 @@ main(void)
 	print_it();
 
 #ifdef STARPU_USE_OPENCL
-        ret = starpu_opencl_unload_opencl(&opencl_program);
-        STARPU_CHECK_RETURN_VALUE(ret, "starpu_opencl_unload_opencl");
-        starpu_opencl_unload_opencl(&opencl_conversion_program);
+	ret = starpu_opencl_unload_opencl(&opencl_program);
+	STARPU_CHECK_RETURN_VALUE(ret, "starpu_opencl_unload_opencl");
+	ret = starpu_opencl_unload_opencl(&opencl_conversion_program);
+	STARPU_CHECK_RETURN_VALUE(ret, "starpu_opencl_unload_opencl");
 #endif
 	starpu_shutdown();
 
