@@ -1,8 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2011                                     Inria
- * Copyright (C) 2010-2013,2015-2017                      CNRS
- * Copyright (C) 2011,2014,2015                           Université de Bordeaux
+ * Copyright (C) 2010-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -26,7 +24,7 @@ do                                                          	\
 	int check_err;                           	        \
 	check_err = clSetKernelArg(kernel, n, size, ptr);       \
 	if (check_err != CL_SUCCESS)                            \
-       		STARPU_OPENCL_REPORT_ERROR(check_err);          \
+		STARPU_OPENCL_REPORT_ERROR(check_err);          \
 } while (0)
 
 extern struct starpu_opencl_program opencl_program;
@@ -37,14 +35,14 @@ void opencl_func(void *buffers[], void *cl_arg)
 	cl_kernel kernel;
 	cl_command_queue queue;
 
-        int *factor = cl_arg;
+	int *factor = cl_arg;
 	cl_mem block = (cl_mem)STARPU_BLOCK_GET_DEV_HANDLE(buffers[0]);
 	unsigned offset = STARPU_BLOCK_GET_OFFSET(buffers[0]);
 	int nx = (int)STARPU_BLOCK_GET_NX(buffers[0]);
 	int ny = (int)STARPU_BLOCK_GET_NY(buffers[0]);
 	int nz = (int)STARPU_BLOCK_GET_NZ(buffers[0]);
-        unsigned ldy = STARPU_BLOCK_GET_LDY(buffers[0]);
-        unsigned ldz = STARPU_BLOCK_GET_LDZ(buffers[0]);
+	unsigned ldy = STARPU_BLOCK_GET_LDY(buffers[0]);
+	unsigned ldz = STARPU_BLOCK_GET_LDZ(buffers[0]);
 
 	id = starpu_worker_get_id_check();
 	devid = starpu_worker_get_devid(id);
@@ -62,8 +60,8 @@ void opencl_func(void *buffers[], void *cl_arg)
 	CHECK_CL_SET_KERNEL_ARG(kernel, 7, sizeof(*factor), factor);
 
 	{
-		size_t global=nx*ny*nz;
-		err = clEnqueueNDRangeKernel(queue, kernel, 1, NULL, &global, NULL, 0, NULL, NULL);
+		size_t global[3]={nx,ny,nz};
+		err = clEnqueueNDRangeKernel(queue, kernel, 3, NULL, global, NULL, 0, NULL, NULL);
 		if (err != CL_SUCCESS) STARPU_OPENCL_REPORT_ERROR(err);
 	}
 	starpu_opencl_release_kernel(kernel);
