@@ -1,8 +1,8 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2008-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2010       Mehdi Juhoor
- * Copyright (C) 2013       Thibaut Lambert
+ * Copyright (C) 2008-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2013-2013  Thibaut Lambert
+ * Copyright (C) 2010-2010  Mehdi Juhoor
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -23,12 +23,12 @@
 
 #include "dw_factolu.h"
 
-#define TAG11(k)	((starpu_tag_t)( (1ULL<<60) | (unsigned long long)(k)))
-#define TAG12(k,i)	((starpu_tag_t)(((2ULL<<60) | (((unsigned long long)(k))<<32)	\
+#define TAG_GETRF(k)	((starpu_tag_t)((1ULL<<60) | (unsigned long long)(k)))
+#define TAG_TRSM_LL(k,i)	((starpu_tag_t)(((2ULL<<60) | (((unsigned long long)(k))<<32)	\
 					| (unsigned long long)(i))))
-#define TAG21(k,j)	((starpu_tag_t)(((3ULL<<60) | (((unsigned long long)(k))<<32)	\
+#define TAG_TRSM_RU(k,j)	((starpu_tag_t)(((3ULL<<60) | (((unsigned long long)(k))<<32)	\
 					| (unsigned long long)(j))))
-#define TAG22(k,i,j)	((starpu_tag_t)(((4ULL<<60) | ((unsigned long long)(k)<<32) 	\
+#define TAG_GEMM(k,i,j)	((starpu_tag_t)(((4ULL<<60) | ((unsigned long long)(k)<<32) 	\
 					| ((unsigned long long)(i)<<16)	\
 					| (unsigned long long)(j))))
 
@@ -49,25 +49,25 @@ static struct starpu_task *create_task(starpu_tag_t id)
 	return task;
 }
 
-static struct starpu_codelet cl11 =
+static struct starpu_codelet cl_getrf =
 {
 	.modes = { STARPU_RW },
-	.cpu_funcs = {dw_cpu_codelet_update_u11},
-	.cpu_funcs_name = {"dw_cpu_codelet_update_u11"},
+	.cpu_funcs = {dw_cpu_codelet_update_getrf},
+	.cpu_funcs_name = {"dw_cpu_codelet_update_getrf"},
 #ifdef STARPU_USE_CUDA
-	.cuda_funcs = {dw_cublas_codelet_update_u11},
+	.cuda_funcs = {dw_cublas_codelet_update_getrf},
 #endif
 	.nbuffers = 1,
-	.model = &model_11
+	.model = &model_getrf
 };
 
-static struct starpu_task *create_task_11(starpu_data_handle_t dataA, unsigned k)
+static struct starpu_task *create_task_getrf(starpu_data_handle_t dataA, unsigned k)
 {
-/*	printf("task 11 k = %d TAG = %llx\n", k, (TAG11(k))); */
+/*	printf("task 11 k = %d TAG = %llx\n", k, (TAG_GETRF(k))); */
 
-	struct starpu_task *task = create_task(TAG11(k));
+	struct starpu_task *task = create_task(TAG_GETRF(k));
 
-	task->cl = &cl11;
+	task->cl = &cl_getrf;
 
 	/* which sub-data is manipulated ? */
 	task->handles[0] = starpu_data_get_sub_data(dataA, 2, k, k);
@@ -79,33 +79,33 @@ static struct starpu_task *create_task_11(starpu_data_handle_t dataA, unsigned k
 	/* enforce dependencies ... */
 	if (k > 0)
 	{
-		starpu_tag_declare_deps(TAG11(k), 1, TAG22(k-1, k, k));
+		starpu_tag_declare_deps(TAG_GETRF(k), 1, TAG_GEMM(k-1, k, k));
 	}
 
 	return task;
 }
 
-static struct starpu_codelet cl12 =
+static struct starpu_codelet cl_trsm_ll =
 {
 	.modes = { STARPU_R, STARPU_RW },
-	.cpu_funcs = {dw_cpu_codelet_update_u12},
-	.cpu_funcs_name = {"dw_cpu_codelet_update_u12"},
+	.cpu_funcs = {dw_cpu_codelet_update_trsm_ll},
+	.cpu_funcs_name = {"dw_cpu_codelet_update_trsm_ll"},
 #ifdef STARPU_USE_CUDA
-	.cuda_funcs = {dw_cublas_codelet_update_u12},
+	.cuda_funcs = {dw_cublas_codelet_update_trsm_ll},
 #endif
 	.nbuffers = 2,
-	.model = &model_12
+	.model = &model_trsm_ll
 };
 
-static void create_task_12(starpu_data_handle_t dataA, unsigned k, unsigned i)
+static void create_task_trsm_ll(starpu_data_handle_t dataA, unsigned k, unsigned i)
 {
 	int ret;
 
-/*	printf("task 12 k,i = %d,%d TAG = %llx\n", k,i, TAG12(k,i)); */
+/*	printf("task 12 k,i = %d,%d TAG = %llx\n", k,i, TAG_TRSM_LL(k,i)); */
 
-	struct starpu_task *task = create_task(TAG12(k, i));
-	
-	task->cl = &cl12;
+	struct starpu_task *task = create_task(TAG_TRSM_LL(k, i));
+
+	task->cl = &cl_trsm_ll;
 
 	/* which sub-data is manipulated ? */
 	task->handles[0] = starpu_data_get_sub_data(dataA, 2, k, k);
@@ -119,36 +119,36 @@ static void create_task_12(starpu_data_handle_t dataA, unsigned k, unsigned i)
 	/* enforce dependencies ... */
 	if (k > 0)
 	{
-		starpu_tag_declare_deps(TAG12(k, i), 2, TAG11(k), TAG22(k-1, i, k));
+		starpu_tag_declare_deps(TAG_TRSM_LL(k, i), 2, TAG_GETRF(k), TAG_GEMM(k-1, i, k));
 	}
 	else
 	{
-		starpu_tag_declare_deps(TAG12(k, i), 1, TAG11(k));
+		starpu_tag_declare_deps(TAG_TRSM_LL(k, i), 1, TAG_GETRF(k));
 	}
 
 	ret = starpu_task_submit(task);
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_submit");
 }
 
-static struct starpu_codelet cl21 =
+static struct starpu_codelet cl_trsm_ru =
 {
 	.modes = { STARPU_R, STARPU_RW },
-	.cpu_funcs = {dw_cpu_codelet_update_u21},
-	.cpu_funcs_name = {"dw_cpu_codelet_update_u21"},
+	.cpu_funcs = {dw_cpu_codelet_update_trsm_ru},
+	.cpu_funcs_name = {"dw_cpu_codelet_update_trsm_ru"},
 #ifdef STARPU_USE_CUDA
-	.cuda_funcs = {dw_cublas_codelet_update_u21},
+	.cuda_funcs = {dw_cublas_codelet_update_trsm_ru},
 #endif
 	.nbuffers = 2,
-	.model = &model_21
+	.model = &model_trsm_ru
 };
 
-static void create_task_21(starpu_data_handle_t dataA, unsigned k, unsigned j)
+static void create_task_trsm_ru(starpu_data_handle_t dataA, unsigned k, unsigned j)
 {
 	int ret;
-	struct starpu_task *task = create_task(TAG21(k, j));
+	struct starpu_task *task = create_task(TAG_TRSM_RU(k, j));
+
+	task->cl = &cl_trsm_ru;
 
-	task->cl = &cl21;
-	
 	/* which sub-data is manipulated ? */
 	task->handles[0] = starpu_data_get_sub_data(dataA, 2, k, k);
 	task->handles[1] = starpu_data_get_sub_data(dataA, 2, k, j);
@@ -161,45 +161,45 @@ static void create_task_21(starpu_data_handle_t dataA, unsigned k, unsigned j)
 	/* enforce dependencies ... */
 	if (k > 0)
 	{
-		starpu_tag_declare_deps(TAG21(k, j), 2, TAG11(k), TAG22(k-1, k, j));
+		starpu_tag_declare_deps(TAG_TRSM_RU(k, j), 2, TAG_GETRF(k), TAG_GEMM(k-1, k, j));
 	}
 	else
 	{
-		starpu_tag_declare_deps(TAG21(k, j), 1, TAG11(k));
+		starpu_tag_declare_deps(TAG_TRSM_RU(k, j), 1, TAG_GETRF(k));
 	}
 
 	ret = starpu_task_submit(task);
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_submit");
 }
 
-static struct starpu_codelet cl22 =
+static struct starpu_codelet cl_gemm =
 {
 	.modes = { STARPU_R, STARPU_R, STARPU_RW },
-	.cpu_funcs = {dw_cpu_codelet_update_u22},
-	.cpu_funcs_name = {"dw_cpu_codelet_update_u22"},
+	.cpu_funcs = {dw_cpu_codelet_update_gemm},
+	.cpu_funcs_name = {"dw_cpu_codelet_update_gemm"},
 #ifdef STARPU_USE_CUDA
-	.cuda_funcs = {dw_cublas_codelet_update_u22},
+	.cuda_funcs = {dw_cublas_codelet_update_gemm},
 #endif
 	.nbuffers = 3,
-	.model = &model_22
+	.model = &model_gemm
 };
 
-static void create_task_22(starpu_data_handle_t dataA, unsigned k, unsigned i, unsigned j)
+static void create_task_gemm(starpu_data_handle_t dataA, unsigned k, unsigned i, unsigned j)
 {
 	int ret;
 
-/*	printf("task 22 k,i,j = %d,%d,%d TAG = %llx\n", k,i,j, TAG22(k,i,j)); */
+/*	printf("task 22 k,i,j = %d,%d,%d TAG = %llx\n", k,i,j, TAG_GEMM(k,i,j)); */
 
-	struct starpu_task *task = create_task(TAG22(k, i, j));
+	struct starpu_task *task = create_task(TAG_GEMM(k, i, j));
 
-	task->cl = &cl22;
+	task->cl = &cl_gemm;
 
 	/* which sub-data is manipulated ? */
 	task->handles[0] = starpu_data_get_sub_data(dataA, 2, i, k);
 	task->handles[1] = starpu_data_get_sub_data(dataA, 2, k, j);
 	task->handles[2] = starpu_data_get_sub_data(dataA, 2, i, j);
 
-	if (!no_prio &&  (i == k + 1) && (j == k +1) )
+	if (!no_prio &&  (i == k + 1) && (j == k +1))
 	{
 		task->priority = STARPU_MAX_PRIO;
 	}
@@ -207,11 +207,11 @@ static void create_task_22(starpu_data_handle_t dataA, unsigned k, unsigned i, u
 	/* enforce dependencies ... */
 	if (k > 0)
 	{
-		starpu_tag_declare_deps(TAG22(k, i, j), 3, TAG22(k-1, i, j), TAG12(k, i), TAG21(k, j));
+		starpu_tag_declare_deps(TAG_GEMM(k, i, j), 3, TAG_GEMM(k-1, i, j), TAG_TRSM_LL(k, i), TAG_TRSM_RU(k, j));
 	}
 	else
 	{
-		starpu_tag_declare_deps(TAG22(k, i, j), 2, TAG12(k, i), TAG21(k, j));
+		starpu_tag_declare_deps(TAG_GEMM(k, i, j), 2, TAG_TRSM_LL(k, i), TAG_TRSM_RU(k, j));
 	}
 
 	ret = starpu_task_submit(task);
@@ -219,7 +219,7 @@ static void create_task_22(starpu_data_handle_t dataA, unsigned k, unsigned i, u
 }
 
 /*
- *	code to bootstrap the factorization 
+ *	code to bootstrap the factorization
  */
 
 static void dw_codelet_facto_v3(starpu_data_handle_t dataA, unsigned nblocks)
@@ -236,7 +236,7 @@ static void dw_codelet_facto_v3(starpu_data_handle_t dataA, unsigned nblocks)
 
 	for (k = 0; k < nblocks; k++)
 	{
-		struct starpu_task *task = create_task_11(dataA, k);
+		struct starpu_task *task = create_task_getrf(dataA, k);
 
 		/* we defer the launch of the first task */
 		if (k == 0)
@@ -248,18 +248,18 @@ static void dw_codelet_facto_v3(starpu_data_handle_t dataA, unsigned nblocks)
 			ret = starpu_task_submit(task);
 			STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_submit");
 		}
-		
+
 		for (i = k+1; i<nblocks; i++)
 		{
-			create_task_12(dataA, k, i);
-			create_task_21(dataA, k, i);
+			create_task_trsm_ll(dataA, k, i);
+			create_task_trsm_ru(dataA, k, i);
 		}
 
 		for (i = k+1; i<nblocks; i++)
 		{
 			for (j = k+1; j<nblocks; j++)
 			{
-				create_task_22(dataA, k, i, j);
+				create_task_gemm(dataA, k, i, j);
 			}
 		}
 	}
@@ -276,7 +276,7 @@ static void dw_codelet_facto_v3(starpu_data_handle_t dataA, unsigned nblocks)
 
 
 	/* stall the application until the end of computations */
-	starpu_tag_wait(TAG11(nblocks-1));
+	starpu_tag_wait(TAG_GETRF(nblocks-1));
 
 	end = starpu_timing_now();
 
