@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -28,6 +28,10 @@
 #define CUBLAS_SWAP	cublasDswap
 #define CUBLAS_IAMAX	cublasIdamax
 
+
+#define CUSOLVER_GETRF  cusolverDnDgetrf
+#define CUSOLVER_GETRF_BUFFERSIZE cusolverDnDgetrf_bufferSize
+
 #define CPU_GEMM	STARPU_DGEMM
 #define CPU_TRSM	STARPU_DTRSM
 #define CPU_SCAL	STARPU_DSCAL
