@@ -1,9 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010,2011,2013-2015                      Université de Bordeaux
- * Copyright (C) 2012,2013                                Inria
- * Copyright (C) 2010                                     Mehdi Juhoor
- * Copyright (C) 2010-2013,2015-2017                      CNRS
+ * Copyright (C) 2010-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2010-2010  Mehdi Juhoor
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -158,7 +156,7 @@ int main(int argc, char **argv)
 	/* Use a write-through policy : when the data is modified on an
 	 * accelerator, we know that it will only be modified once and be
 	 * accessed by the CPU later on */
-	starpu_data_set_wt_mask(cnt_array_handle, (1<<0));
+	starpu_data_set_wt_mask(cnt_array_handle, (1<<STARPU_MAIN_RAM));
 
 	struct starpu_data_filter f =
 	{
