@@ -1,8 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2016,2017                                Inria
- * Copyright (C) 2012,2013,2016,2017,2019                 CNRS
- * Copyright (C) 2010-2015                                Université de Bordeaux
+ * Copyright (C) 2010-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -131,7 +129,7 @@ static void check_load(struct starpu_block_interface *block, struct starpu_block
 	STARPU_ASSERT(block->ny == boundary->ny);
 	STARPU_ASSERT(boundary->nz == K);
 
-	/* NB: this is not fully garanteed ... but it's *very* likely and that
+	/* NB: this is not fully guaranteed ... but it's *very* likely and that
 	 * makes our life much simpler */
 	STARPU_ASSERT(block->ldy == boundary->ldy);
 	STARPU_ASSERT(block->ldz == boundary->ldz);
@@ -188,17 +186,17 @@ static void update_func_cuda(void *descr[], void *arg)
 	struct block_description *block = get_block_description(z);
 
 	int workerid = starpu_worker_get_id_check();
-	DEBUG( "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n");
+	DEBUG("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n");
 	if (block->bz == 0)
 		FPRINTF(stderr,"!!! DO update_func_cuda z %u CUDA%d !!!\n", block->bz, workerid);
 	else
-		DEBUG( "!!! DO update_func_cuda z %u CUDA%d !!!\n", block->bz, workerid);
+		DEBUG("!!! DO update_func_cuda z %u CUDA%d !!!\n", block->bz, workerid);
 #if defined(STARPU_USE_MPI) && !defined(STARPU_SIMGRID) && !defined(STARPU_USE_MPI_MASTER_SLAVE)
 	int rank = 0;
 	MPI_Comm_rank(MPI_COMM_WORLD, &rank);
-	DEBUG( "!!!           RANK %d              !!!\n", rank);
+	DEBUG("!!!           RANK %d              !!!\n", rank);
 #endif
-	DEBUG( "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n");
+	DEBUG("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n");
 
 	unsigned block_size_z = get_block_size(block->bz);
 	unsigned i;
@@ -259,9 +257,9 @@ static void load_subblock_from_buffer_opencl(struct starpu_block_interface *bloc
 	cl_mem block_data = (cl_mem)block->dev_handle;
 	cl_mem boundary_data = (cl_mem)boundary->dev_handle;
 
-        cl_command_queue cq;
-        starpu_opencl_get_current_queue(&cq);
-        cl_int ret = clEnqueueCopyBuffer(cq, boundary_data, block_data, 0, offset, boundary_size, 0, NULL, NULL);
+	cl_command_queue cq;
+	starpu_opencl_get_current_queue(&cq);
+	cl_int ret = clEnqueueCopyBuffer(cq, boundary_data, block_data, 0, offset, boundary_size, 0, NULL, NULL);
 	if (ret != CL_SUCCESS) STARPU_OPENCL_REPORT_ERROR(ret);
 }
 
@@ -275,17 +273,17 @@ static void update_func_opencl(void *descr[], void *arg)
 	struct block_description *block = get_block_description(z);
 
 	int workerid = starpu_worker_get_id_check();
-	DEBUG( "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n");
+	DEBUG("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n");
 	if (block->bz == 0)
 		FPRINTF(stderr,"!!! DO update_func_opencl z %u OPENCL%d !!!\n", block->bz, workerid);
 	else
-		DEBUG( "!!! DO update_func_opencl z %u OPENCL%d !!!\n", block->bz, workerid);
+		DEBUG("!!! DO update_func_opencl z %u OPENCL%d !!!\n", block->bz, workerid);
 #if defined(STARPU_USE_MPI) && !defined(STARPU_SIMGRID) && !defined(STARPU_USE_MPI_MASTER_SLAVE)
 	int rank = 0;
 	MPI_Comm_rank(MPI_COMM_WORLD, &rank);
-	DEBUG( "!!!           RANK %d              !!!\n", rank);
+	DEBUG("!!!           RANK %d              !!!\n", rank);
 #endif
-	DEBUG( "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n");
+	DEBUG("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n");
 
 	unsigned block_size_z = get_block_size(block->bz);
 	unsigned i;
@@ -293,8 +291,8 @@ static void update_func_opencl(void *descr[], void *arg)
 
 	record_who_runs_what(block);
 
-        cl_command_queue cq;
-        starpu_opencl_get_current_queue(&cq);
+	cl_command_queue cq;
+	starpu_opencl_get_current_queue(&cq);
 
 	/*
 	 *	Load neighbours' boundaries : TOP
@@ -327,7 +325,7 @@ static void update_func_opencl(void *descr[], void *arg)
 		opencl_life_update_host(block->bz, old, newer, oldb->nx, oldb->ny, oldb->nz, oldb->ldy, oldb->ldz, i);
 #else
 		cl_event event;
-                cl_int ret = clEnqueueCopyBuffer(cq, old, newer, 0, 0, oldb->nx * oldb->ny * oldb->nz * sizeof(*newer), 0, NULL, &event);
+		cl_int ret = clEnqueueCopyBuffer(cq, old, newer, 0, 0, oldb->nx * oldb->ny * oldb->nz * sizeof(*newer), 0, NULL, &event);
 		if (ret != CL_SUCCESS) STARPU_OPENCL_REPORT_ERROR(ret);
 
 #endif /* LIFE */
@@ -345,17 +343,17 @@ void update_func_cpu(void *descr[], void *arg)
 	struct block_description *block = get_block_description(zz);
 
 	int workerid = starpu_worker_get_id_check();
-	DEBUG( "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n");
+	DEBUG("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n");
 	if (block->bz == 0)
-		DEBUG("!!! DO update_func_cpu z %u CPU%d !!!\n", block->bz, workerid);
+		DEBUG("!!! DO update_func_cpu z %u worker%d !!!\n", block->bz, workerid);
 	else
-		DEBUG("!!! DO update_func_cpu z %u CPU%d !!!\n", block->bz, workerid);
+		DEBUG("!!! DO update_func_cpu z %u worker%d !!!\n", block->bz, workerid);
 #if defined(STARPU_USE_MPI) && !defined(STARPU_SIMGRID) && !defined(STARPU_USE_MPI_MASTER_SLAVE)
 	int rank = 0;
 	MPI_Comm_rank(MPI_COMM_WORLD, &rank);
-	DEBUG( "!!!           RANK %d            !!!\n", rank);
+	DEBUG("!!!            RANK %d              !!!\n", rank);
 #endif
-	DEBUG( "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n");
+	DEBUG("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n");
 
 	unsigned block_size_z = get_block_size(block->bz);
 	unsigned i;
@@ -489,10 +487,10 @@ static void load_subblock_into_buffer_opencl(struct starpu_block_interface *bloc
 	cl_mem block_data = (cl_mem)block->dev_handle;
 	cl_mem boundary_data = (cl_mem)boundary->dev_handle;
 
-        cl_command_queue cq;
-        starpu_opencl_get_current_queue(&cq);
+	cl_command_queue cq;
+	starpu_opencl_get_current_queue(&cq);
 
-        cl_int ret = clEnqueueCopyBuffer(cq, block_data, boundary_data, offset, 0, boundary_size, 0, NULL, NULL);
+	cl_int ret = clEnqueueCopyBuffer(cq, block_data, boundary_data, offset, 0, boundary_size, 0, NULL, NULL);
 	if (ret != CL_SUCCESS) STARPU_OPENCL_REPORT_ERROR(ret);
 }
 #endif /* STARPU_USE_OPENCL */
@@ -504,14 +502,14 @@ unsigned bottom_per_worker[STARPU_NMAXWORKERS];
 /* top save, CPU version */
 void dummy_func_top_cpu(void *descr[], void *arg)
 {
-    unsigned z;
-    starpu_codelet_unpack_args(arg, &z);
+	unsigned z;
+	starpu_codelet_unpack_args(arg, &z);
 	struct block_description *block = get_block_description(z);
 
 	int workerid = starpu_worker_get_id_check();
 	top_per_worker[workerid]++;
 
-	DEBUG( "DO SAVE Bottom block %d\n", block->bz);
+	DEBUG("DO SAVE Bottom block %d\n", block->bz);
 
 	/* The offset along the z axis is (block_size_z + K)- K */
 	unsigned block_size_z = get_block_size(block->bz);
@@ -523,15 +521,15 @@ void dummy_func_top_cpu(void *descr[], void *arg)
 /* bottom save, CPU version */
 void dummy_func_bottom_cpu(void *descr[], void *arg)
 {
-    unsigned z;
-    starpu_codelet_unpack_args(arg, &z);
+	unsigned z;
+	starpu_codelet_unpack_args(arg, &z);
 	struct block_description *block = get_block_description(z);
-    STARPU_ASSERT(block);
+	STARPU_ASSERT(block);
 
 	int workerid = starpu_worker_get_id_check();
 	bottom_per_worker[workerid]++;
 
-	DEBUG( "DO SAVE Top block %d\n", block->bz);
+	DEBUG("DO SAVE Top block %d\n", block->bz);
 
 	load_subblock_into_buffer_cpu(descr[0], descr[2], K);
 	load_subblock_into_buffer_cpu(descr[1], descr[3], K);
@@ -541,14 +539,14 @@ void dummy_func_bottom_cpu(void *descr[], void *arg)
 #ifdef STARPU_USE_CUDA
 static void dummy_func_top_cuda(void *descr[], void *arg)
 {
-    unsigned z;
-    starpu_codelet_unpack_args(arg, &z);
+	unsigned z;
+	starpu_codelet_unpack_args(arg, &z);
 	struct block_description *block = get_block_description(z);
 
 	int workerid = starpu_worker_get_id_check();
 	top_per_worker[workerid]++;
 
-	DEBUG( "DO SAVE Top block %d\n", block->bz);
+	DEBUG("DO SAVE Top block %d\n", block->bz);
 
 	/* The offset along the z axis is (block_size_z + K)- K */
 	unsigned block_size_z = get_block_size(block->bz);
@@ -568,7 +566,7 @@ static void dummy_func_bottom_cuda(void *descr[], void *arg)
 	int workerid = starpu_worker_get_id_check();
 	bottom_per_worker[workerid]++;
 
-	DEBUG( "DO SAVE Bottom block %d on CUDA\n", block->bz);
+	DEBUG("DO SAVE Bottom block %d on CUDA\n", block->bz);
 
 	load_subblock_into_buffer_cuda(descr[0], descr[2], K);
 	load_subblock_into_buffer_cuda(descr[1], descr[3], K);
@@ -579,14 +577,14 @@ static void dummy_func_bottom_cuda(void *descr[], void *arg)
 #ifdef STARPU_USE_OPENCL
 static void dummy_func_top_opencl(void *descr[], void *arg)
 {
-    unsigned z;
-    starpu_codelet_unpack_args(arg, &z);
+	unsigned z;
+	starpu_codelet_unpack_args(arg, &z);
 	struct block_description *block = get_block_description(z);
 
 	int workerid = starpu_worker_get_id_check();
 	top_per_worker[workerid]++;
 
-	DEBUG( "DO SAVE Top block %d\n", block->bz);
+	DEBUG("DO SAVE Top block %d\n", block->bz);
 
 	/* The offset along the z axis is (block_size_z + K)- K */
 	unsigned block_size_z = get_block_size(block->bz);
@@ -606,7 +604,7 @@ static void dummy_func_bottom_opencl(void *descr[], void *arg)
 	int workerid = starpu_worker_get_id_check();
 	bottom_per_worker[workerid]++;
 
-	DEBUG( "DO SAVE Bottom block %d on OPENCL\n", block->bz);
+	DEBUG("DO SAVE Bottom block %d on OPENCL\n", block->bz);
 
 	load_subblock_into_buffer_opencl(descr[0], descr[2], K);
 	load_subblock_into_buffer_opencl(descr[1], descr[3], K);
@@ -659,13 +657,13 @@ struct starpu_codelet save_cl_top =
 };
 
 /* Memset a block's buffers */
-static void memset_func(void *descr[], void *arg)
+void memset_func(void *descr[], void *arg)
 {
 	(void)descr;
-    	unsigned sizex, sizey, bz;
-    	starpu_codelet_unpack_args(arg, &sizex, &sizey, &bz);
+	unsigned sizex, sizey, bz;
+	starpu_codelet_unpack_args(arg, &sizex, &sizey, &bz);
 	struct block_description *block = get_block_description(bz);
-    	unsigned size_bz = get_block_size(bz);
+	unsigned size_bz = get_block_size(bz);
 
 	unsigned x,y,z;
 	for (x = 0; x < sizex + 2*K; x++)
@@ -717,6 +715,7 @@ static struct starpu_perfmodel memset_model =
 struct starpu_codelet cl_memset =
 {
 	.cpu_funcs = {memset_func},
+	.cpu_funcs_name = {"memset_func"},
 	.model = &memset_model,
 	.nbuffers = 6,
 	.modes = {STARPU_W, STARPU_W, STARPU_W, STARPU_W, STARPU_W, STARPU_W}
