@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2010-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -47,7 +47,7 @@ unsigned nbz = NBZ;
 
 double start;
 double begin, end;
-double timing; 
+double timing;
 
 /*
  *	Initialization
@@ -166,7 +166,7 @@ static void init_problem(int argc, char **argv, int rank, int world_size)
 
 static void free_problem(int rank)
 {
-    free_memory_on_node(rank);
+	free_memory_on_node(rank);
 	free_blocks_array();
 	free(who_runs_what);
 	free(who_runs_what_index);
@@ -177,7 +177,7 @@ static void free_problem(int rank)
  *	Main body
  */
 
-void f(unsigned task_per_worker[STARPU_NMAXWORKERS])
+void func(unsigned task_per_worker[STARPU_NMAXWORKERS])
 {
 	unsigned total = 0;
 	int worker;
@@ -237,7 +237,14 @@ int main(int argc, char **argv)
 		fflush(stderr);
 	}
 
-	ret = starpu_init(NULL);
+	struct starpu_conf conf;
+	starpu_conf_init(&conf);
+
+	/*nbz is a global variable, this example doesn't support Master-Slave*/
+	conf.nmpi_ms = 0;
+	conf.ntcpip_ms = 0;
+
+	ret = starpu_init(&conf);
 	if (ret == -ENODEV) return 77;
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_init");
 
@@ -247,8 +254,8 @@ int main(int argc, char **argv)
 #endif
 
 #ifdef STARPU_USE_OPENCL
-        opencl_life_init();
-        opencl_shadow_init();
+	opencl_life_init();
+	opencl_shadow_init();
 #endif /*STARPU_USE_OPENCL*/
 
 	init_problem(argc, argv, rank, world_size);
@@ -270,7 +277,7 @@ int main(int argc, char **argv)
 
 	//wait_end_tasks(rank);
 
-    starpu_task_wait_for_all();
+	starpu_task_wait_for_all();
 
 	end = starpu_timing_now();
 
@@ -323,13 +330,13 @@ int main(int argc, char **argv)
 
 	if (rank == 0)
 	{
-#if 1 
+#if 1
 		FPRINTF(stderr, "update:\n");
-		f(update_per_worker);
+		func(update_per_worker);
 		FPRINTF(stderr, "top:\n");
-		f(top_per_worker);
+		func(top_per_worker);
 		FPRINTF(stderr, "bottom:\n");
-		f(bottom_per_worker);
+		func(bottom_per_worker);
 #endif
 #if 1
 		unsigned nzblocks_per_process = (nbz + world_size - 1) / world_size;
@@ -383,8 +390,8 @@ int main(int argc, char **argv)
 #endif
 
 #ifdef STARPU_USE_OPENCL
-        opencl_life_free();
-        opencl_shadow_free();
+	opencl_life_free();
+	opencl_shadow_free();
 #endif /*STARPU_USE_OPENCL*/
 
 	return 0;
