@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2010-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -30,38 +30,43 @@
 
 typedef HANDLE sem_t;
 
-static __inline int sem_init(sem_t *sem, int pshared, unsigned int value) {
-  (void)pshared;
-  winPthreadAssertWindows(*sem = CreateSemaphore(NULL, value, MAXLONG, NULL));
-  return 0;
+static __inline int sem_init(sem_t *sem, int pshared, unsigned int value)
+{
+	(void)pshared;
+	winPthreadAssertWindows(*sem = CreateSemaphore(NULL, value, MAXLONG, NULL));
+	return 0;
 }
 
-static __inline int do_sem_wait(sem_t *sem, DWORD timeout) {
-  switch (WaitForSingleObject(*sem, timeout)) {
-    default:
-    case WAIT_FAILED:
-      setSystemErrno();
-      return -1;
-    case WAIT_TIMEOUT:
-      errno = EAGAIN;
-      return -1;
-    case WAIT_ABANDONED:
-    case WAIT_OBJECT_0:
-      return 0;
-  }
+static __inline int do_sem_wait(sem_t *sem, DWORD timeout)
+{
+	switch (WaitForSingleObject(*sem, timeout))
+	{
+	default:
+	case WAIT_FAILED:
+		setSystemErrno();
+		return -1;
+	case WAIT_TIMEOUT:
+		errno = EAGAIN;
+		return -1;
+	case WAIT_ABANDONED:
+	case WAIT_OBJECT_0:
+		return 0;
+	}
 }
 
-#define sem_wait(sem) do_sem_wait(sem, INFINITE)
+#define sem_wait(sem)	 do_sem_wait(sem, INFINITE)
 #define sem_trywait(sem) do_sem_wait(sem, 0)
 
-static __inline int sem_post(sem_t *sem) {
-  winPthreadAssertWindows(ReleaseSemaphore(*sem, 1, NULL));
-  return 0;
+static __inline int sem_post(sem_t *sem)
+{
+	winPthreadAssertWindows(ReleaseSemaphore(*sem, 1, NULL));
+	return 0;
 }
 
-static __inline int sem_destroy(sem_t *sem) {
-  winPthreadAssertWindows(CloseHandle(*sem));
-  return 0;
+static __inline int sem_destroy(sem_t *sem)
+{
+	winPthreadAssertWindows(CloseHandle(*sem));
+	return 0;
 }
 
 #endif /* __STARPU_SEMAPHORE_H__ */
