@@ -1,7 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2013-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2013       Simon Archipoff
+ * Copyright (C) 2013-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2013-2013  Simon Archipoff
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -32,7 +32,7 @@ extern "C" {
    @defgroup API_Bitmap Bitmap
    @brief This is the interface for the bitmap utilities provided by StarPU.
    @{
- */
+*/
 #ifndef _STARPU_LONG_BIT
 #define _STARPU_LONG_BIT ((int)(sizeof(unsigned long) * 8))
 #endif
@@ -75,6 +75,9 @@ static inline int starpu_bitmap_has_next(struct starpu_bitmap *b, int e);
 
 /** @} */
 
+/**
+   todo
+*/
 struct starpu_bitmap
 {
 	unsigned long bits[_STARPU_BITMAP_SIZE];
