@@ -1,7 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2017                                     CNRS
- * Copyright (C) 2014                                     Université de Bordeaux
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -23,6 +22,10 @@
 #ifdef STARPU_SIMGRID
 #ifndef main
 #define main starpu_main
+#ifdef __cplusplus
+extern "C" int starpu_main(int argc, char *argv[]);
+extern "C" int starpu_main(int argc, char **argv);
+#endif
 #endif
 #endif
 
