@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010-2022  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2010-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -14,6 +14,8 @@
  * See the GNU Lesser General Public License in COPYING.LGPL for more details.
  */
 
+#include <starpu.h>
+
 #ifndef __STARPU_TASK_UTIL_H__
 #define __STARPU_TASK_UTIL_H__
 
@@ -21,7 +23,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <assert.h>
-#include <starpu.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -413,11 +414,11 @@ extern "C" {
    starpu_task_insert().
    If some arguments of type ::STARPU_VALUE are given, the parameter
    starpu_task::cl_arg_free will be set to 1.
-   See \ref Helpers for more details.
+   See \ref OtherTaskUtility for more details.
 */
 int starpu_task_set(struct starpu_task *task, struct starpu_codelet *cl, ...);
 #ifdef STARPU_USE_FXT
-#define starpu_task_set(task, cl, ...) starpu_task_set((task), (cl), STARPU_TASK_FILE, __FILE__, STARPU_TASK_LINE, __LINE__, ##__VA_ARGS__)
+#define starpu_task_set(task, cl, ...) starpu_task_set(task, cl, STARPU_TASK_FILE, __FILE__, STARPU_TASK_LINE, __LINE__, ##__VA_ARGS__)
 #endif
 
 /**
@@ -427,11 +428,11 @@ int starpu_task_set(struct starpu_task *task, struct starpu_codelet *cl, ...);
    starpu_task_insert().
    If some arguments of type ::STARPU_VALUE are given, the parameter
    starpu_task::cl_arg_free will be set to 1.
-   See \ref Helpers for more details.
+   See \ref OtherTaskUtility for more details.
 */
 struct starpu_task *starpu_task_build(struct starpu_codelet *cl, ...);
 #ifdef STARPU_USE_FXT
-#define starpu_task_build(cl, ...) starpu_task_build((cl), STARPU_TASK_FILE, __FILE__, STARPU_TASK_LINE, __LINE__, ##__VA_ARGS__)
+#define starpu_task_build(cl, ...) starpu_task_build(cl, STARPU_TASK_FILE, __FILE__, STARPU_TASK_LINE, __LINE__, ##__VA_ARGS__)
 #endif
 
 /**
@@ -474,7 +475,7 @@ struct starpu_task *starpu_task_build(struct starpu_codelet *cl, ...);
 */
 int starpu_task_insert(struct starpu_codelet *cl, ...);
 #ifdef STARPU_USE_FXT
-#define starpu_task_insert(cl, ...) starpu_task_insert((cl), STARPU_TASK_FILE, __FILE__, STARPU_TASK_LINE, __LINE__, ##__VA_ARGS__)
+#define starpu_task_insert(cl, ...) starpu_task_insert(cl, STARPU_TASK_FILE, __FILE__, STARPU_TASK_LINE, __LINE__, ##__VA_ARGS__)
 #endif
 
 /**
@@ -482,7 +483,7 @@ int starpu_task_insert(struct starpu_codelet *cl, ...);
 */
 int starpu_insert_task(struct starpu_codelet *cl, ...);
 #ifdef STARPU_USE_FXT
-#define starpu_insert_task(cl, ...) starpu_insert_task((cl), STARPU_TASK_FILE, __FILE__, STARPU_TASK_LINE, __LINE__, ##__VA_ARGS__)
+#define starpu_insert_task(cl, ...) starpu_insert_task(cl, STARPU_TASK_FILE, __FILE__, STARPU_TASK_LINE, __LINE__, ##__VA_ARGS__)
 #endif
 
 /**
@@ -496,7 +497,7 @@ int starpu_insert_task(struct starpu_codelet *cl, ...);
    make room by calling this function, then store handles with
    STARPU_TASK_SET_HANDLE(), make room again with this function, store
    yet more handles, etc.
-   See \ref Helpers for more details.
+   See \ref OtherTaskUtility for more details.
 */
 void starpu_task_insert_data_make_room(struct starpu_codelet *cl, struct starpu_task *task, int *allocated_buffers, int current_buffer, int room);
 
@@ -504,14 +505,14 @@ void starpu_task_insert_data_make_room(struct starpu_codelet *cl, struct starpu_
    Store data handle \p handle into task \p task with mode \p
    arg_type, updating \p *allocated_buffers and \p *current_buffer
    accordingly.
-   See \ref Helpers for more details.
+   See \ref OtherTaskUtility for more details.
 */
 void starpu_task_insert_data_process_arg(struct starpu_codelet *cl, struct starpu_task *task, int *allocated_buffers, int *current_buffer, int arg_type, starpu_data_handle_t handle);
 
 /**
    Store \p nb_handles data handles \p handles into task \p task,
    updating \p *allocated_buffers and \p *current_buffer accordingly.
-   See \ref Helpers for more details.
+   See \ref OtherTaskUtility for more details.
 */
 void starpu_task_insert_data_process_array_arg(struct starpu_codelet *cl, struct starpu_task *task, int *allocated_buffers, int *current_buffer, int nb_handles, starpu_data_handle_t *handles);
 
@@ -519,7 +520,7 @@ void starpu_task_insert_data_process_array_arg(struct starpu_codelet *cl, struct
    Store \p nb_descrs data handles described by \p descrs into task \p
    task, updating \p *allocated_buffers and \p *current_buffer
    accordingly.
-   See \ref Helpers for more details.
+   See \ref OtherTaskUtility for more details.
 */
 void starpu_task_insert_data_process_mode_array_arg(struct starpu_codelet *cl, struct starpu_task *task, int *allocated_buffers, int *current_buffer, int nb_descrs, struct starpu_data_descr *descrs);
 
