@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2015-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2015-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -25,13 +25,15 @@
 #define DATA0_TAG 12
 #define DATA1_TAG 22
 
+MPI_Comm newcomm;
+
 void func_cpu(void *descr[], void *_args)
 {
 	int *value = (int *)STARPU_VARIABLE_GET_PTR(descr[0]);
 	int rank;
 
 	starpu_codelet_unpack_args(_args, &rank);
-	FPRINTF_MPI(stderr, "Executing codelet with value %d and rank %d\n", *value, rank);
+	FPRINTF_MPI_COMM(stderr, newcomm, "Executing codelet with value %d and rank %d\n", *value, rank);
 	STARPU_ASSERT_MSG(*value == rank, "Received value %d is not the expected value %d\n", *value, rank);
 }
 
@@ -47,7 +49,6 @@ int main(int argc, char **argv)
 {
 	int size, x=789;
 	int color;
-	MPI_Comm newcomm;
 	int rank, newrank;
 	int ret;
 	starpu_data_handle_t data[2];
@@ -63,15 +64,15 @@ int main(int argc, char **argv)
 	if (thread_support < MPI_THREAD_FUNNELED)
 		fprintf(stderr,"Warning: MPI does not have thread support!\n");
 
-        MPI_Comm_rank(MPI_COMM_WORLD, &rank);
-        MPI_Comm_size(MPI_COMM_WORLD, &size);
+	MPI_Comm_rank(MPI_COMM_WORLD, &rank);
+	MPI_Comm_size(MPI_COMM_WORLD, &size);
 
-        if (size < 4)
-        {
+	if (size < 4)
+	{
 		FPRINTF(stderr, "We need at least 4 processes.\n");
-                MPI_Finalize();
-                return STARPU_TEST_SKIPPED;
-        }
+		MPI_Finalize();
+		return STARPU_TEST_SKIPPED;
+	}
 
 	color = rank%2;
 	MPI_Comm_split(MPI_COMM_WORLD, color, rank, &newcomm);
@@ -89,8 +90,8 @@ int main(int argc, char **argv)
 		FPRINTF(stderr, "[%d][%d] received %d\n", rank, newrank, x);
 	}
 
-        ret = starpu_mpi_init_conf(NULL, NULL, 0, newcomm, NULL);
-        STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_init_conf");
+	ret = starpu_mpi_init_conf(NULL, NULL, 0, newcomm, NULL);
+	STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_init_conf");
 
 	if (newrank == 0)
 	{
@@ -105,16 +106,21 @@ int main(int argc, char **argv)
 	if (newrank == 0)
 	{
 		starpu_mpi_req req[2];
-		starpu_mpi_issend(data[1], &req[0], 1, DATA1_TAG, newcomm);
-		starpu_mpi_isend(data[0], &req[1], 1, DATA0_TAG, newcomm);
-		starpu_mpi_wait(&req[0], MPI_STATUS_IGNORE);
-		starpu_mpi_wait(&req[1], MPI_STATUS_IGNORE);
+		ret = starpu_mpi_issend(data[1], &req[0], 1, DATA1_TAG, newcomm);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_issend");
+		ret = starpu_mpi_isend(data[0], &req[1], 1, DATA0_TAG, newcomm);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_isend");
+		ret = starpu_mpi_wait(&req[0], MPI_STATUS_IGNORE);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_wait");
+		ret = starpu_mpi_wait(&req[1], MPI_STATUS_IGNORE);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_wait");
 	}
 	else if (newrank == 1)
 	{
 		int *xx;
 
-		starpu_mpi_recv(data[0], 0, DATA0_TAG, newcomm, MPI_STATUS_IGNORE);
+		ret = starpu_mpi_recv(data[0], 0, DATA0_TAG, newcomm, MPI_STATUS_IGNORE);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_recv");
 		starpu_data_acquire(data[0], STARPU_R);
 		xx = (int *)starpu_variable_get_local_ptr(data[0]);
 		FPRINTF(stderr, "[%d][%d] received %d\n", rank, newrank, *xx);
@@ -123,7 +129,8 @@ int main(int argc, char **argv)
 
 		starpu_variable_data_register(&data[1], -1, (uintptr_t)NULL, sizeof(int));
 		starpu_mpi_data_register_comm(data[1], DATA1_TAG, 0, newcomm);
-		starpu_mpi_recv(data[0], 0, DATA1_TAG, newcomm, MPI_STATUS_IGNORE);
+		ret = starpu_mpi_recv(data[0], 0, DATA1_TAG, newcomm, MPI_STATUS_IGNORE);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_recv");
 		starpu_data_acquire(data[0], STARPU_R);
 		xx = (int *)starpu_variable_get_local_ptr(data[0]);
 		FPRINTF(stderr, "[%d][%d] received %d\n", rank, newrank, *xx);
@@ -144,8 +151,8 @@ int main(int argc, char **argv)
 		starpu_data_unregister(data[1]);
 	}
 
-	starpu_mpi_shutdown();
+	starpu_mpi_shutdown_comm(newcomm);
 	MPI_Comm_free(&newcomm);
-        MPI_Finalize();
+	MPI_Finalize();
 	return 0;
 }
