@@ -1,6 +1,6 @@
 ! StarPU --- Runtime system for heterogeneous multicore architectures.
 !
-! Copyright (C) 2016-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+! Copyright (C) 2016-2025   University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
 !
 ! StarPU is free software; you can redistribute it and/or modify
 ! it under the terms of the GNU Lesser General Public License as published by
@@ -304,6 +304,25 @@ module fstarpu_mpi_mod
                         integer(c_int), value, intent(in) :: prio
                 end subroutine fstarpu_mpi_redux_data_prio
 
+                ! void starpu_mpi_redux_data_tree(MPI_Comm comm, starpu_data_handle_t data_handle, int arity);
+                subroutine fstarpu_mpi_redux_data_tree(mpi_comm,dh, arity) bind(C)
+                        use iso_c_binding
+                        implicit none
+                        integer(c_int), value, intent(in) :: mpi_comm
+                        type(c_ptr), value, intent(in) :: dh
+                        integer(c_int), value, intent(in) :: arity
+                end subroutine fstarpu_mpi_redux_data_tree
+
+                ! void starpu_mpi_redux_data_prio_tree(MPI_Comm comm, starpu_data_handle_t data_handle, int prio, int arity);
+                subroutine fstarpu_mpi_redux_data_prio_tree(mpi_comm,dh, prio, arity) bind(C)
+                        use iso_c_binding
+                        implicit none
+                        integer(c_int), value, intent(in) :: mpi_comm
+                        type(c_ptr), value, intent(in) :: dh
+                        integer(c_int), value, intent(in) :: prio
+                        integer(c_int), value, intent(in) :: arity
+                end subroutine fstarpu_mpi_redux_data_prio_tree
+
                 ! int starpu_mpi_scatter_detached(starpu_data_handle_t *data_handles, int count, int root, MPI_Comm comm, void (*scallback)(void *), void *sarg, void (*rcallback)(void *), void *rarg);
                 function fstarpu_mpi_scatter_detached (dhs, cnt, root, mpi_comm, scallback, sarg, rcallback, rarg) bind(C)
                         use iso_c_binding
@@ -415,12 +434,12 @@ module fstarpu_mpi_mod
                         type(c_ptr), value, intent(in) :: starpu_tag
                 end function fstarpu_mpi_recv_array_detached_unlock_tag
 
-                ! void starpu_mpi_comm_amounts_retrieve(size_t *comm_amounts);
-                subroutine fstarpu_mpi_comm_amounts_retrieve (comm_amounts) bind(C,name="starpu_mpi_comm_amounts_retrieve")
+                ! void starpu_mpi_comm_stats_retrieve(size_t *comm_stats);
+                subroutine fstarpu_mpi_comm_stats_retrieve (comm_stats) bind(C,name="starpu_mpi_comm_stats_retrieve")
                         use iso_c_binding
                         implicit none
-                        integer(c_size_t), intent(in) :: comm_amounts(*)
-                end subroutine fstarpu_mpi_comm_amounts_retrieve
+                        integer(c_size_t), intent(in) :: comm_stats(*)
+                end subroutine fstarpu_mpi_comm_stats_retrieve
 
 
                 ! void starpu_mpi_cache_flush(MPI_Comm comm, starpu_data_handle_t data_handle);
@@ -478,6 +497,18 @@ module fstarpu_mpi_mod
                         integer(c_int) :: fstarpu_mpi_world_comm
                 end function fstarpu_mpi_world_comm
 
+                ! void starpu_mpi_comm_stats_enable()
+                subroutine fstarpu_mpi_comm_stats_enable() bind(C)
+                        use iso_c_binding
+                        implicit none
+                end subroutine fstarpu_mpi_comm_stats_enable
+
+                ! void starpu_mpi_comm_stats_disable()
+                subroutine fstarpu_mpi_comm_stats_disable() bind(C)
+                        use iso_c_binding
+                        implicit none
+                end subroutine fstarpu_mpi_comm_stats_disable
+
                 ! int starpu_mpi_get_communication_tag(void);
                 function fstarpu_mpi_get_communication_tag() bind(C,name="starpu_mpi_get_communication_tag")
                         use iso_c_binding
@@ -718,7 +749,8 @@ module fstarpu_mpi_mod
                         end interface
 
                         fargc = command_argument_count()
-                        write(*,*) "fargc",fargc
+                        !write(*,*) "fargc",fargc
+
                         if (present(mpi_comm)) then
                                 mpi_comm_present = 1
                                 mpi_comm_or_0 = mpi_comm
@@ -726,8 +758,8 @@ module fstarpu_mpi_mod
                                 mpi_comm_present = 0
                                 mpi_comm_or_0 = 0
                         end if
-                        write(*,*) "initialize_mpi",initialize_mpi
-                        write(*,*) "mpi_comm_present",mpi_comm_present
+                        !write(*,*) "initialize_mpi",initialize_mpi
+                        !write(*,*) "mpi_comm_present",mpi_comm_present
                         argcv = fstarpu_mpi_argcv_alloc(fargc, initialize_mpi, mpi_comm_present, mpi_comm_or_0)
                         do i=0,fargc-1
                                 call get_command_argument(i, farg_1, farg_len)
