@@ -1,7 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2023  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2017       Guillaume Beauchamp
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2017-2017  Guillaume Beauchamp
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -43,6 +43,7 @@
 #include <nm_mpi_nmad.h>
 #include <nm_mcast_interface.h>
 #include <nm_sendrecv_interface.h>
+#include <nm_core_interface.h>
 
 #include "starpu_mpi_nmad_coop.h"
 #include "starpu_mpi_nmad_backend.h"
@@ -606,7 +607,13 @@ static void *_starpu_mpi_progress_thread_func(void *arg)
 
 #ifdef STARPU_USE_FXT
 	_starpu_mpi_fxt_init(argc_argv);
+
+#ifdef HAVE_NM_TRACE_ADD_SYNCHRO_POINT
+	starpu_fxt_trace_user_meta_string("Clock_synchronize");
+	nm_trace_add_synchro_point();
 #endif
+#endif
+
 
 	if (_starpu_mpi_use_coop_sends)
 	{
