@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2023  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -41,31 +41,41 @@ static int _mpi_world_rank;
 static int _mpi_initialized_starpu;
 static int _starpu_mpi_gpudirect;	/* Whether GPU direct was explicitly requested (1) or disabled (0), or should be enabled if available (-1) */
 int _starpu_mpi_has_cuda;		/* Whether GPU direct is available */
+int _starpu_mpi_psm2;			/* Whether MPI has PSM2 or not. Useful when using old intel compilers, for which psm2 detection is buggy */
 int _starpu_mpi_cuda_devid = -1;	/* Which device GPU direct is enabled for (-1 = all) */
 
 static void _starpu_mpi_print_thread_level_support(int thread_level, char *msg)
 {
+	const char *level = NULL;
 	switch (thread_level)
 	{
 		case MPI_THREAD_SERIALIZED:
 		{
-			_STARPU_DISP("MPI%s MPI_THREAD_SERIALIZED; Multiple threads may make MPI calls, but only one at a time.\n", msg);
+			level = "MPI_THREAD_SERIALIZED";
+			_STARPU_DISP("MPI%s %s; Multiple threads may make MPI calls, but only one at a time.\n", msg, level);
 			break;
 		}
 		case MPI_THREAD_FUNNELED:
 		{
-			_STARPU_DISP("MPI%s MPI_THREAD_FUNNELED; The application can safely make calls to StarPU-MPI functions, but should not call directly MPI communication functions.\n", msg);
+			level = "MPI_THREAD_FUNNELED";
+			_STARPU_DISP("MPI%s %s; The application can safely make calls to StarPU-MPI functions, but should not call directly MPI communication functions.\n", msg, level);
 			break;
 		}
 		case MPI_THREAD_SINGLE:
 		{
-			_STARPU_DISP("MPI%s MPI_THREAD_SINGLE; MPI does not have multi-thread support, this might cause problems. The application can make calls to StarPU-MPI functions, but not call directly MPI Communication functions.\n", msg);
+			level = "MPI_THREAD_SINGLE";
+			_STARPU_DISP("MPI%s %s; MPI does not have multi-thread support, this might cause problems. The application can make calls to StarPU-MPI functions, but not call directly MPI Communication functions.\n", msg, level);
 			break;
 		}
 		case MPI_THREAD_MULTIPLE:
 			/* no problem */
 			break;
 	}
+	if (thread_level != MPI_THREAD_MULTIPLE && _starpu_mpi_thread_multiple_send)
+	{
+		_STARPU_DISP("STARPU_MPI_THREAD_MULTIPLE_SEND requested but MPI%s %s, disabling STARPU_MPI_THREAD_MULTIPLE_SEND\n", msg, level);
+		_starpu_mpi_thread_multiple_send = 0;
+	}
 }
 
 void _starpu_mpi_do_initialize(struct _starpu_mpi_argc_argv *argc_argv)
@@ -86,7 +96,7 @@ void _starpu_mpi_do_initialize(struct _starpu_mpi_argc_argv *argc_argv)
 		STARPU_ASSERT_MSG(argc_argv->comm == MPI_COMM_WORLD, "It does not make sense to ask StarPU-MPI to initialize MPI while a non-world communicator was given");
 		int thread_support;
 		_STARPU_DEBUG("Calling MPI_Init_thread\n");
-		if (MPI_Init_thread(argc_argv->argc, argc_argv->argv, MPI_THREAD_SERIALIZED, &thread_support) != MPI_SUCCESS)
+		if (MPI_Init_thread(argc_argv->argc, argc_argv->argv, _starpu_mpi_thread_multiple_send ? MPI_THREAD_MULTIPLE : MPI_THREAD_SERIALIZED, &thread_support) != MPI_SUCCESS)
 		{
 			_STARPU_ERROR("MPI_Init_thread failed\n");
 		}
@@ -113,14 +123,14 @@ void _starpu_mpi_do_initialize(struct _starpu_mpi_argc_argv *argc_argv)
 	if (MPIX_Query_cuda_support())
 		_starpu_mpi_has_cuda = 1;
 	else if (_starpu_mpi_gpudirect > 0)
-		_STARPU_DISP("Warning: MPI GPUDirect requested, but MPIX_Query_cuda_support reports that it is not supported.");
+		_STARPU_DISP("Warning: MPI GPUDirect requested, but MPIX_Query_cuda_support reports that it is not supported.\n");
 	_STARPU_DEBUG("MPI has CUDA: %d\n", _starpu_mpi_has_cuda);
 	if (!_starpu_mpi_gpudirect)
 	{
 		_STARPU_DEBUG("But disabled by user\n");
 		_starpu_mpi_has_cuda = 0;
 	}
-	if (_starpu_mpi_has_cuda)
+	if (_starpu_mpi_has_cuda && _starpu_mpi_psm2)
 	{
 #pragma weak psm2_init
 		extern int psm2_init(int *major, int *minor);
@@ -129,14 +139,15 @@ void _starpu_mpi_do_initialize(struct _starpu_mpi_argc_argv *argc_argv)
 			int cuda_worker = starpu_worker_get_by_type(STARPU_CUDA_WORKER, 0);
 			_starpu_mpi_cuda_devid = starpu_worker_get_devid(cuda_worker);
 
-			_STARPU_DISP("Warning: MPI GPUDirect is enabled using the PSM2 driver, but StarPU will be driving several CUDA GPUs.");
-			_STARPU_DISP("Since the PSM2 driver only supports one CUDA GPU at a time for GPU Direct (at least as of its version 11.2.185), StarPU-MPI will use GPU Direct only for CUDA%d.", _starpu_mpi_cuda_devid);
-			_STARPU_DISP("To get GPU Direct working with all CUDA GPUs with the PSM2 driver, you will unfortunately have to run one MPI rank per GPU.");
+			_STARPU_DISP("Warning: MPI GPUDirect is enabled using the PSM2 driver, but StarPU will be driving several CUDA GPUs.\n");
+			_STARPU_DISP("Since the PSM2 driver only supports one CUDA GPU at a time for GPU Direct (at least as of its version 11.2.185), StarPU-MPI will use GPU Direct only for CUDA%d.\n", _starpu_mpi_cuda_devid);
+			_STARPU_DISP("To get GPU Direct working with all CUDA GPUs with the PSM2 driver, you will unfortunately have to run one MPI rank per GPU.\n");
+			_STARPU_DISP("if you are sure you are not actually using PSM2, you can set STARPU_MPI_PSM2=0 to disable PSM2 detection.\n");
 		}
 	}
 #else
 	if (_starpu_mpi_gpudirect > 0)
-		_STARPU_DISP("Warning: MPI GPUDirect requested, but the MPIX_Query_cuda_support function is not provided by the MPI Implementation, did you compile it with CUDA support and the Cuda MPI extension?");
+		_STARPU_DISP("Warning: MPI GPUDirect requested, but the MPIX_Query_cuda_support function is not provided by the MPI Implementation, did you compile it with CUDA support and the Cuda MPI extension?\n");
 	_STARPU_DEBUG("No CUDA support in MPI\n");
 #endif
 #endif
@@ -186,6 +197,7 @@ int _starpu_mpi_initialize(int *argc, char ***argv, int initialize_mpi, MPI_Comm
 	_starpu_mpi_backend_check();
 
 	_starpu_mpi_gpudirect = starpu_getenv_number("STARPU_MPI_GPUDIRECT");
+	_starpu_mpi_psm2    = starpu_getenv_number_default("STARPU_MPI_PSM2", 1);
 #ifdef STARPU_SIMGRID
 	/* Call MPI_Init_thread as early as possible, to initialize simgrid
 	 * before working with mutexes etc. */
@@ -355,7 +367,7 @@ int starpu_mpi_shutdown_comm(MPI_Comm comm)
 
 	_starpu_mpi_comm_amounts_display(stderr, rank);
 	_starpu_mpi_comm_amounts_shutdown();
-	_starpu_mpi_cache_shutdown(world_size);
+	_starpu_mpi_cache_shutdown();
 
 	_mpi_backend._starpu_mpi_backend_shutdown();
 
