@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2019-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2019-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -63,14 +63,17 @@ void early_data()
 	_starpu_mpi_early_data_add(edh[0]);
 	_starpu_mpi_early_data_add(edh[1]);
 
-	hash = _starpu_mpi_early_data_extract(&node_tag[1]);
+	hash = _starpu_mpi_early_data_extract(&node_tag[0]);
 	STARPU_ASSERT(_starpu_mpi_early_data_handle_list_size(&hash->list) == 1);
 	early = _starpu_mpi_early_data_handle_list_pop_front(&hash->list);
-	STARPU_ASSERT(early->node_tag.node.comm == node_tag[1].node.comm && early->node_tag.node.rank == node_tag[1].node.rank && early->node_tag.data_tag == node_tag[1].data_tag);
-	STARPU_ASSERT(_starpu_mpi_early_data_handle_list_size(&hash->list) == 0);
-
-	early = _starpu_mpi_early_data_find(&node_tag[0]);
 	STARPU_ASSERT(early->node_tag.node.comm == node_tag[0].node.comm && early->node_tag.node.rank == node_tag[0].node.rank && early->node_tag.data_tag == node_tag[0].data_tag);
+	STARPU_ASSERT(_starpu_mpi_early_data_handle_list_size(&hash->list) == 0);
+	_starpu_mpi_early_data_delete(early);
+	free(hash);
+
+	early = _starpu_mpi_early_data_find(&node_tag[1]);
+	STARPU_ASSERT(early->node_tag.node.comm == node_tag[1].node.comm && early->node_tag.node.rank == node_tag[1].node.rank && early->node_tag.data_tag == node_tag[1].data_tag);
+	_starpu_mpi_early_data_delete(early);
 }
 
 void early_request()
@@ -100,16 +103,24 @@ void early_request()
 	early = _starpu_mpi_req_list_pop_front(&hash->list);
 	STARPU_ASSERT(_starpu_mpi_req_list_size(&hash->list) == 0);
 	STARPU_ASSERT(early->node_tag.data_tag == req[1].node_tag.data_tag && early->node_tag.node.rank == req[1].node_tag.node.rank && early->node_tag.node.comm == req[1].node_tag.node.comm);
+	free(hash);
 }
 
 int main(int argc, char **argv)
 {
-	int ret, rank, size, i;
-	starpu_data_handle_t tab_handle[4];
+	int ret;
 	int mpi_init;
+	struct starpu_conf conf;
 
 	MPI_INIT_THREAD(&argc, &argv, MPI_THREAD_SERIALIZED, &mpi_init);
-	ret = starpu_mpi_init_conf(&argc, &argv, mpi_init, MPI_COMM_WORLD, NULL);
+
+	starpu_conf_init(&conf);
+	starpu_conf_noworker(&conf);
+	conf.ncpus = -1;
+	conf.nmpi_ms = -1;
+	conf.ntcpip_ms = -1;
+
+	ret = starpu_mpi_init_conf(&argc, &argv, mpi_init, MPI_COMM_WORLD, &conf);
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_init_conf");
 
 	early_data();
