@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2011-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2011-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -41,7 +41,8 @@ struct starpu_codelet mycodelet =
 	.model = &starpu_perfmodel_nop,
 };
 
-#define N     1000
+#define NB_ELEMENTS 1000
+#define NB_DATA     2
 
 /* Returns the MPI node number where data indexes index is */
 int my_distrib(int x)
@@ -49,43 +50,52 @@ int my_distrib(int x)
 	return x;
 }
 
-void test_cache(int rank, char *enabled, size_t *comm_amount)
+void test_cache(int rank, starpu_mpi_tag_t initial_tag, char *enabled, size_t *comm_amount)
 {
 	int i;
 	int ret;
-	unsigned *v[2];
-	starpu_data_handle_t data_handles[2];
+	unsigned *v[NB_DATA];
+	starpu_data_handle_t data_handles[NB_DATA];
+	struct starpu_conf conf;
 
 	setenv("STARPU_MPI_CACHE", enabled, 1);
 
-	ret = starpu_mpi_init_conf(NULL, NULL, 0, MPI_COMM_WORLD, NULL);
+	starpu_conf_init(&conf);
+	starpu_conf_noworker(&conf);
+	conf.ncpus = -1;
+	conf.nmpi_ms = -1;
+	conf.ntcpip_ms = -1;
+
+	ret = starpu_mpi_init_conf(NULL, NULL, 0, MPI_COMM_WORLD, &conf);
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_init_conf");
 
-	for(i = 0; i < 2; i++)
+	starpu_mpi_coop_sends_set_use(0); // disable coop_sends to avoid having wrong results when cache is disabled
+
+	for(i = 0; i < NB_DATA; i++)
 	{
 		int j;
-		v[i] = malloc(N * sizeof(unsigned));
-		for(j=0 ; j<N ; j++)
+		starpu_malloc((void **)&v[i], NB_ELEMENTS * sizeof(unsigned));
+		for(j=0 ; j<NB_ELEMENTS ; j++)
 		{
 			v[i][j] = 12;
 		}
 	}
 
-	for(i = 0; i < 2; i++)
+	for(i = 0; i < NB_DATA; i++)
 	{
 		int mpi_rank = my_distrib(i);
 		if (mpi_rank == rank)
 		{
 			//FPRINTF(stderr, "[%d] Owning data[%d][%d]\n", rank, x, y);
-			starpu_vector_data_register(&data_handles[i], STARPU_MAIN_RAM, (uintptr_t)v[i], N, sizeof(unsigned));
+			starpu_vector_data_register(&data_handles[i], STARPU_MAIN_RAM, (uintptr_t)v[i], NB_ELEMENTS, sizeof(unsigned));
 		}
 		else
 		{
 			/* I don't own this index, but will need it for my computations */
 			//FPRINTF(stderr, "[%d] Neighbour of data[%d][%d]\n", rank, x, y);
-			starpu_vector_data_register(&data_handles[i], -1, (uintptr_t)NULL, N, sizeof(unsigned));
+			starpu_vector_data_register(&data_handles[i], -1, (uintptr_t)NULL, NB_ELEMENTS, sizeof(unsigned));
 		}
-		starpu_mpi_data_register(data_handles[i], i, mpi_rank);
+		starpu_mpi_data_register(data_handles[i], initial_tag+i, mpi_rank);
 	}
 
 	for(i = 0; i < 5; i++)
@@ -113,13 +123,13 @@ void test_cache(int rank, char *enabled, size_t *comm_amount)
 
 	starpu_task_wait_for_all();
 
-	for(i = 0; i < 2; i++)
+	for(i = 0; i < NB_DATA; i++)
 	{
 		starpu_data_unregister(data_handles[i]);
-		free(v[i]);
+		starpu_free_noflag(v[i], NB_DATA * sizeof(unsigned));
 	}
 
-	starpu_mpi_comm_amounts_retrieve(comm_amount);
+	starpu_mpi_comm_stats_retrieve(comm_amount);
 	starpu_mpi_shutdown();
 }
 
@@ -129,24 +139,26 @@ int main(int argc, char **argv)
 	int result=0;
 	size_t *comm_amount_with_cache;
 	size_t *comm_amount_without_cache;
+	starpu_mpi_tag_t initial_tag = 0;
 
 	MPI_INIT_THREAD_real(&argc, &argv, MPI_THREAD_SERIALIZED);
-	starpu_mpi_comm_rank(MPI_COMM_WORLD, &rank);
-	starpu_mpi_comm_size(MPI_COMM_WORLD, &size);
+	MPI_Comm_rank(MPI_COMM_WORLD, &rank);
+	MPI_Comm_size(MPI_COMM_WORLD, &size);
 
-	setenv("STARPU_COMM_STATS", "1", 1);
+	setenv("STARPU_MPI_STATS", "1", 1);
 
 	comm_amount_with_cache = malloc(size * sizeof(size_t));
 	comm_amount_without_cache = malloc(size * sizeof(size_t));
 
-	test_cache(rank, "0", comm_amount_with_cache);
-	test_cache(rank, "1", comm_amount_without_cache);
+	test_cache(rank, initial_tag, "0", comm_amount_with_cache);
+	initial_tag += NB_DATA;
+	test_cache(rank, initial_tag, "1", comm_amount_without_cache);
 
 	if (rank == 0 || rank == 1)
 	{
 		int dst = (rank == 0) ? 1 : 0;
 		result = (comm_amount_with_cache[dst] == comm_amount_without_cache[dst] * 5);
-		FPRINTF_MPI(stderr, "Communication cache mechanism is %sworking\n", result?"":"NOT ");
+		FPRINTF(stderr, "[%d] Communication cache mechanism is %sworking\n", rank, result?"":"NOT ");
 	}
 	else
 	{
