@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2012-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2012-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -37,7 +37,7 @@ static struct starpu_codelet init_codelet =
 static struct starpu_codelet redux_codelet =
 {
 	.cpu_funcs = {redux_cpu_func},
-	.modes = {STARPU_RW, STARPU_R},
+	.modes = {STARPU_RW|STARPU_COMMUTE, STARPU_R},
 	.nbuffers = 2,
 #ifdef STARPU_SIMGRID
 	.model = &starpu_perfmodel_nop,
@@ -80,18 +80,29 @@ int main(int argc, char **argv)
 	long int dot, sum=0;
 	starpu_data_handle_t *handles;
 	starpu_data_handle_t dot_handle;
+	struct starpu_conf conf;
 	int ret;
 
 	int nb_elements, step, loops;
+	int mpi_init;
 
 	STARPU_SKIP_IF_VALGRIND_RETURN_SKIP;
 
 	/* Not supported yet */
-	if (starpu_get_env_number_default("STARPU_GLOBAL_ARBITER", 0) > 0)
+	if (starpu_getenv_number_default("STARPU_GLOBAL_ARBITER", 0) > 0)
 		return STARPU_TEST_SKIPPED;
 
-	ret = starpu_mpi_init_conf(&argc, &argv, 1, MPI_COMM_WORLD, NULL);
+	MPI_INIT_THREAD(&argc, &argv, MPI_THREAD_SERIALIZED, &mpi_init);
+
+	starpu_conf_init(&conf);
+	starpu_conf_noworker(&conf);
+	conf.ncpus = -1;
+	conf.nmpi_ms = -1;
+	conf.ntcpip_ms = -1;
+
+	ret = starpu_mpi_init_conf(&argc, &argv, mpi_init, MPI_COMM_WORLD, &conf);
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_init_conf");
+
 	starpu_mpi_comm_rank(MPI_COMM_WORLD, &my_rank);
 	starpu_mpi_comm_size(MPI_COMM_WORLD, &size);
 
@@ -100,14 +111,16 @@ int main(int argc, char **argv)
 		if (my_rank == 0)
 			FPRINTF(stderr, "We need at least 1 CPU worker.\n");
 		starpu_mpi_shutdown();
-		return STARPU_TEST_SKIPPED;
+		if (!mpi_init)
+			MPI_Finalize();
+		return my_rank == 0 ? STARPU_TEST_SKIPPED : 0;
 	}
 
 	nb_elements = size*8000;
 	step = 4;
 	loops = 5;
 
-	vector = (long int *) malloc(nb_elements*sizeof(vector[0]));
+	starpu_malloc((void **)&vector, nb_elements*sizeof(long int));
 	for(x = 0; x < nb_elements; x+=step)
 	{
 		int mpi_rank = my_distrib(x/step, size);
@@ -164,9 +177,11 @@ int main(int argc, char **argv)
 					       &dot_codelet,
 					       STARPU_R, handles[x],
 					       STARPU_REDUX, dot_handle,
+					       STARPU_EXECUTE_ON_DATA, handles[x],
 					       0);
 		}
-		starpu_mpi_redux_data(MPI_COMM_WORLD, dot_handle);
+		ret = starpu_mpi_redux_data(MPI_COMM_WORLD, dot_handle);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_redux_data");
 		starpu_mpi_task_insert(MPI_COMM_WORLD, &display_codelet, STARPU_R, dot_handle, 0);
 	}
 
@@ -179,10 +194,12 @@ int main(int argc, char **argv)
 			starpu_data_unregister(handles[x]);
 	}
 	starpu_data_unregister(dot_handle);
-	free(vector);
+	starpu_free_noflag(vector, nb_elements*sizeof(long int));
 	free(handles);
 
 	starpu_mpi_shutdown();
+	if (!mpi_init)
+		MPI_Finalize();
 
 	if (my_rank == 0)
 	{
@@ -201,4 +218,3 @@ int main(int argc, char **argv)
 
 	return 0;
 }
-
