@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2015-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2015-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -43,12 +43,22 @@ int main(int argc, char **argv)
 {
 	int rank, size, n;
 	int ret;
-	int a;
 	int val0 = 0, val1 = 0;
 	starpu_data_handle_t data0, data1, tmp0, tmp, tmp2;
+	struct starpu_conf conf;
+	int mpi_init;
 
-	ret = starpu_mpi_init_conf(&argc, &argv, 1, MPI_COMM_WORLD, NULL);
+	MPI_INIT_THREAD(&argc, &argv, MPI_THREAD_SERIALIZED, &mpi_init);
+
+	starpu_conf_init(&conf);
+	starpu_conf_noworker(&conf);
+	conf.ncpus = -1;
+	conf.nmpi_ms = -1;
+	conf.ntcpip_ms = -1;
+
+	ret = starpu_mpi_init_conf(&argc, &argv, mpi_init, MPI_COMM_WORLD, &conf);
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_init_conf");
+
 	starpu_mpi_comm_rank(MPI_COMM_WORLD, &rank);
 	starpu_mpi_comm_size(MPI_COMM_WORLD, &size);
 
@@ -58,7 +68,9 @@ int main(int argc, char **argv)
 			FPRINTF(stderr, "We need at least 2 processes.\n");
 
 		starpu_mpi_shutdown();
-		return STARPU_TEST_SKIPPED;
+		if (!mpi_init)
+			MPI_Finalize();
+		return rank == 0 ? STARPU_TEST_SKIPPED : 0;
 	}
 
 	if (starpu_mpi_cache_is_enabled() == 0)
@@ -134,8 +146,11 @@ int main(int argc, char **argv)
 	if (rank == 1)
 		STARPU_ASSERT_MSG(val1 == 24, "[rank 1] %d should be %d\n", val1, 24);
 
- skip:
+skip:
 	starpu_mpi_shutdown();
 
+	if (!mpi_init)
+		MPI_Finalize();
+
 	return 0;
 }
