@@ -1,7 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2023  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2021       Federal University of Rio Grande do Sul (UFRGS)
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2021-2021  Federal University of Rio Grande do Sul (UFRGS)
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -327,11 +327,13 @@ static unsigned _submit_job_access_data(struct _starpu_job *j, unsigned start_bu
 	for (buf = start_buffer_index; buf < nbuffers; buf++)
 	{
 		starpu_data_handle_t handle = _STARPU_JOB_GET_ORDERED_BUFFER_HANDLE(j, buf);
+		int node = _STARPU_JOB_GET_ORDERED_BUFFER_ORIG_NODE(j, buf);
 
 		for (bufdup = (int) buf-1; bufdup >= 0; bufdup--)
 		{
 			starpu_data_handle_t handle_dup = _STARPU_JOB_GET_ORDERED_BUFFER_HANDLE(j, bufdup);
-			if (handle_dup == handle)
+			int node_dup = _STARPU_JOB_GET_ORDERED_BUFFER_ORIG_NODE(j, bufdup);
+			if (handle_dup == handle && node_dup == node)
 				/* We have already requested this data, skip it. This
 				 * depends on ordering putting writes before reads, see
 				 * _starpu_compar_handles.  */
@@ -387,11 +389,13 @@ static void _submit_job_take_data_deps(struct _starpu_job *j, unsigned start_buf
 	for (buf = start_buffer_index; buf < nbuffers; buf++)
 	{
 		starpu_data_handle_t handle = _STARPU_JOB_GET_ORDERED_BUFFER_HANDLE(j, buf);
+		int node = _STARPU_JOB_GET_ORDERED_BUFFER_ORIG_NODE(j, buf);
 
 		for (bufdup = (int) buf-1; bufdup >= 0; bufdup--)
 		{
 			starpu_data_handle_t handle_dup = _STARPU_JOB_GET_ORDERED_BUFFER_HANDLE(j, bufdup);
-			if (handle_dup == handle)
+			int node_dup = _STARPU_JOB_GET_ORDERED_BUFFER_ORIG_NODE(j, bufdup);
+			if (handle_dup == handle && node_dup == node)
 				/* We have already requested this data, skip it. This
 				 * depends on ordering putting writes before reads, see
 				 * _starpu_compar_handles.  */
@@ -470,6 +474,7 @@ void _starpu_job_set_ordered_buffers(struct _starpu_job *j)
 		buffers[i].index = i;
 		buffers[i].handle = STARPU_TASK_GET_HANDLE(task, i);
 		buffers[i].mode = STARPU_TASK_GET_MODE(task, i);
+		buffers[i].orig_node = task->cl ? STARPU_CODELET_GET_NODE(task->cl, i) : STARPU_SPECIFIC_NODE_NONE;
 		buffers[i].node = -1;
 	}
 	_starpu_sort_task_handles(buffers, nbuffers);
@@ -477,6 +482,21 @@ void _starpu_job_set_ordered_buffers(struct _starpu_job *j)
 	{
 		buffers[buffers[i].index].orderedindex = i;
 	}
+	if (task->cl && task->cl->specific_nodes)
+		for (i=1 ; i<nbuffers; i++)
+		{
+			if (buffers[i].handle == buffers[i-1].handle
+				&& STARPU_CODELET_GET_NODE(task->cl, buffers[i].index) !=
+				   STARPU_CODELET_GET_NODE(task->cl, buffers[i-1].index))
+			{
+				STARPU_ASSERT_MSG(!(buffers[i].mode & STARPU_W) &&
+						  !(buffers[i-1].mode & STARPU_W),
+						  "Cannot request the same data on different nodes with write mode");
+				STARPU_ASSERT_MSG(!(buffers[i].mode & STARPU_REDUX) &&
+						  !(buffers[i-1].mode & STARPU_REDUX),
+						  "Cannot request the same data on different nodes with redux mode");
+			}
+		}
 }
 
 /* Sort the data used by the given job by handle pointer value order, and
