@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010-2023  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2010-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -599,11 +599,13 @@ void _starpu_release_task_enforce_sequential_consistency(struct _starpu_job *j)
 	for (index = 0; index < nbuffers; index++)
 	{
 		starpu_data_handle_t handle = descrs[index].handle;
+		int node = descrs[index].orig_node;
 
 		for (indexdup = index+1; indexdup < (int) nbuffers; indexdup++)
 		{
 			starpu_data_handle_t handle_dup = descrs[indexdup].handle;
-			if (handle_dup == handle)
+			int node_dup = descrs[indexdup].orig_node;
+			if (handle_dup == handle && node_dup == node)
 				/* We will release this data, skip it for now. This
 				 * depends on ordering putting writes before reads, see
 				 * _starpu_compar_handles */
