@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2008-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2008-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -24,6 +24,8 @@
 #include <common/starpu_spinlock.h>
 #include <core/dependencies/cg.h>
 
+#pragma GCC visibility push(hidden)
+
 #define _STARPU_TAG_SIZE        (sizeof(starpu_tag_t)*8)
 
 enum _starpu_tag_state
@@ -74,8 +76,6 @@ void _starpu_tag_declare(starpu_tag_t id, struct _starpu_job *job);
 /** lock should be taken, and this releases it */
 void _starpu_tag_set_ready(struct _starpu_tag *tag);
 
-unsigned _starpu_submit_job_enforce_task_deps(struct _starpu_job *j);
-
-void _starpu_tag_clear(void);
+#pragma GCC visibility pop
 
 #endif // __TAGS_H__
