@@ -1,9 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2013,2017                                Inria
- * Copyright (C) 2015-2017, 2019                          CNRS
- * Copyright (C) 2013-2015,2017,2018-2019                 Université de Bordeaux
- * Copyright (C) 2013                                     Corentin Salingue
+ * Copyright (C) 2013-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2013-2013  Corentin Salingue
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -58,35 +56,36 @@ int starpu_disk_swap_node = -1;
 
 static void add_async_event(struct _starpu_async_channel * channel, void * event)
 {
-        if (!event)
-                return;
+	if (!event)
+		return;
 
-        if (channel->event.disk_event.requests == NULL)
-        {
-                channel->event.disk_event.requests = _starpu_disk_backend_event_list_new();
-        }
+	struct _starpu_disk_event *disk_event = _starpu_disk_get_event(&channel->event);
+	if (disk_event->requests == NULL)
+	{
+		disk_event->requests = _starpu_disk_backend_event_list_new();
+	}
 
-        struct _starpu_disk_backend_event * disk_event = _starpu_disk_backend_event_new();
-        disk_event->backend_event = event;
+	struct _starpu_disk_backend_event * backend_event = _starpu_disk_backend_event_new();
+	backend_event->backend_event = event;
 
-        /* Store event at the end of the list */
-        _starpu_disk_backend_event_list_push_back(channel->event.disk_event.requests, disk_event);
+	/* Store event at the end of the list */
+	_starpu_disk_backend_event_list_push_back(disk_event->requests, backend_event);
 }
 
 int starpu_disk_register(struct starpu_disk_ops *func, void *parameter, starpu_ssize_t size)
 {
 	STARPU_ASSERT_MSG(size < 0 || size >= STARPU_DISK_SIZE_MIN, "Minimum disk size is %d Bytes ! (Here %d) \n", (int) STARPU_DISK_SIZE_MIN, (int) size);
 	/* register disk */
-	unsigned disk_memnode = _starpu_memory_node_register(STARPU_DISK_RAM, 0, &_starpu_driver_disk_node_ops);
+	unsigned disk_memnode = _starpu_memory_node_register(STARPU_DISK_RAM, 0);
 
-        /* Connect the disk memory node to all numa memory nodes */
-        int nb_numa_nodes = starpu_memory_nodes_get_numa_count();
-        int numa_node;
-        for (numa_node = 0; numa_node < nb_numa_nodes; numa_node++)
-        {
-                _starpu_register_bus(disk_memnode, numa_node);
-                _starpu_register_bus(numa_node, disk_memnode);
-        }
+	/* Connect the disk memory node to all numa memory nodes */
+	int nb_numa_nodes = starpu_memory_nodes_get_numa_count();
+	int numa_node;
+	for (numa_node = 0; numa_node < nb_numa_nodes; numa_node++)
+	{
+		_starpu_register_bus(disk_memnode, numa_node);
+		_starpu_register_bus(numa_node, disk_memnode);
+	}
 
 	/* Any worker can manage disk memnode */
 	struct _starpu_machine_config *config = _starpu_get_machine_config();
@@ -148,6 +147,9 @@ int starpu_disk_register(struct starpu_disk_ops *func, void *parameter, starpu_s
 		return -ENOENT;
 	if (size >= 0)
 		_starpu_memory_manager_set_global_memory_size(disk_memnode, size);
+
+	_starpu_mem_chunk_disk_register(disk_memnode);
+
 	return disk_memnode;
 }
 
@@ -192,22 +194,22 @@ void _starpu_disk_free(unsigned node, void *obj, size_t size)
 /* src_node == disk node and dst_node == STARPU_MAIN_RAM */
 int _starpu_disk_read(unsigned src_node, unsigned dst_node STARPU_ATTRIBUTE_UNUSED, void *obj, void *buf, off_t offset, size_t size, struct _starpu_async_channel *channel)
 {
-        void *event = NULL;
+	void *event = NULL;
 
-        if (channel != NULL)
+	if (channel != NULL)
 	{
 		if (disk_register_list[src_node]->functions->async_read == NULL)
 			channel = NULL;
 		else
 		{
 			double start;
-			channel->event.disk_event.memory_node = src_node;
+			_starpu_disk_get_event(&channel->event)->memory_node = src_node;
 
 			starpu_interface_start_driver_copy_async(src_node, dst_node, &start);
 			event = disk_register_list[src_node]->functions->async_read(disk_register_list[src_node]->base, obj, buf, offset, size);
 			starpu_interface_end_driver_copy_async(src_node, dst_node, start);
 
-                        add_async_event(channel, event);
+			add_async_event(channel, event);
 		}
 	}
 	/* asynchronous request failed or synchronous request is asked */
@@ -222,43 +224,45 @@ int _starpu_disk_read(unsigned src_node, unsigned dst_node STARPU_ATTRIBUTE_UNUS
 /* src_node == STARPU_MAIN_RAM and dst_node == disk node */
 int _starpu_disk_write(unsigned src_node STARPU_ATTRIBUTE_UNUSED, unsigned dst_node, void *obj, void *buf, off_t offset, size_t size, struct _starpu_async_channel *channel)
 {
-        void *event = NULL;
+	void *event = NULL;
 
-        if (channel != NULL)
-        {
+	if (channel != NULL)
+	{
 		if (disk_register_list[dst_node]->functions->async_write == NULL)
 			channel = NULL;
 		else
-                {
+		{
 			double start;
-			channel->event.disk_event.memory_node = dst_node;
+			_starpu_disk_get_event(&channel->event)->memory_node = dst_node;
 
 			starpu_interface_start_driver_copy_async(src_node, dst_node, &start);
 			event = disk_register_list[dst_node]->functions->async_write(disk_register_list[dst_node]->base, obj, buf, offset, size);
 			starpu_interface_end_driver_copy_async(src_node, dst_node, start);
 
-                        add_async_event(channel, event);
+			add_async_event(channel, event);
 		}
-        }
-        /* asynchronous request failed or synchronous request is asked */
+	}
+	/* asynchronous request failed or synchronous request is asked */
 	if (channel == NULL || !event)
-        {
+	{
 		disk_register_list[dst_node]->functions->write(disk_register_list[dst_node]->base, obj, buf, offset, size);
-        	return 0;
-        }
-        return -EAGAIN;
+		return 0;
+	}
+	return -EAGAIN;
 }
 
 int _starpu_disk_copy(unsigned node_src, void *obj_src, off_t offset_src, unsigned node_dst, void *obj_dst, off_t offset_dst, size_t size, struct _starpu_async_channel *channel)
 {
 	/* both nodes have same copy function */
-        void * event = NULL;
+	void * event = NULL;
 
 	if (channel)
 	{
-		channel->event.disk_event.memory_node = node_src;
-		event = disk_register_list[node_src]->functions->copy(disk_register_list[node_src]->base, obj_src, offset_src,
-								disk_register_list[node_dst]->base, obj_dst, offset_dst, size);
+		_starpu_disk_get_event(&channel->event)->memory_node = node_src;
+		event = disk_register_list[node_src]->functions->copy(disk_register_list[node_src]->base,
+								      obj_src, offset_src,
+								      disk_register_list[node_dst]->base,
+								      obj_dst, offset_dst, size);
 		add_async_event(channel, event);
 	}
 
@@ -289,7 +293,7 @@ int _starpu_disk_copy(unsigned node_src, void *obj_src, off_t offset_src, unsign
 
 int _starpu_disk_full_read(unsigned src_node, unsigned dst_node, void *obj, void **ptr, size_t *size, struct _starpu_async_channel *channel)
 {
-        void *event = NULL;
+	void *event = NULL;
 
 	if (channel != NULL)
 	{
@@ -298,13 +302,13 @@ int _starpu_disk_full_read(unsigned src_node, unsigned dst_node, void *obj, void
 		else
 		{
 			double start;
-			channel->event.disk_event.memory_node = src_node;
+			_starpu_disk_get_event(&channel->event)->memory_node = src_node;
 
 			starpu_interface_start_driver_copy_async(src_node, dst_node, &start);
 			event = disk_register_list[src_node]->functions->async_full_read(disk_register_list[src_node]->base, obj, ptr, size, dst_node);
 			starpu_interface_end_driver_copy_async(src_node, dst_node, start);
 
-                        add_async_event(channel, event);
+			add_async_event(channel, event);
 		}
 	}
 	/* asynchronous request failed or synchronous request is asked */
@@ -318,7 +322,7 @@ int _starpu_disk_full_read(unsigned src_node, unsigned dst_node, void *obj, void
 
 int _starpu_disk_full_write(unsigned src_node STARPU_ATTRIBUTE_UNUSED, unsigned dst_node, void *obj, void *ptr, size_t size, struct _starpu_async_channel *channel)
 {
-        void *event = NULL;
+	void *event = NULL;
 
 	if (channel != NULL)
 	{
@@ -327,13 +331,13 @@ int _starpu_disk_full_write(unsigned src_node STARPU_ATTRIBUTE_UNUSED, unsigned
 		else
 		{
 			double start;
-			channel->event.disk_event.memory_node = dst_node;
+			_starpu_disk_get_event(&channel->event)->memory_node = dst_node;
 
 			starpu_interface_start_driver_copy_async(src_node, dst_node, &start);
 			event = disk_register_list[dst_node]->functions->async_full_write(disk_register_list[dst_node]->base, obj, ptr, size);
 			starpu_interface_end_driver_copy_async(src_node, dst_node, start);
 
-                        add_async_event(channel, event);
+			add_async_event(channel, event);
 		}
 	}
 	/* asynchronous request failed or synchronous request is asked */
@@ -357,82 +361,85 @@ void starpu_disk_close(unsigned node, void *obj, size_t size)
 
 void starpu_disk_wait_request(struct _starpu_async_channel *async_channel)
 {
-	unsigned node = async_channel->event.disk_event.memory_node;
+	struct _starpu_disk_event *disk_event = _starpu_disk_get_event(&async_channel->event);
+	unsigned node = disk_event->memory_node;
 
-        if (async_channel->event.disk_event.requests != NULL && !_starpu_disk_backend_event_list_empty(async_channel->event.disk_event.requests))
-        {
-                struct _starpu_disk_backend_event * event = _starpu_disk_backend_event_list_begin(async_channel->event.disk_event.requests);
-                struct _starpu_disk_backend_event * next;
+	if (disk_event->requests != NULL && !_starpu_disk_backend_event_list_empty(disk_event->requests))
+	{
+		struct _starpu_disk_backend_event * event = _starpu_disk_backend_event_list_begin(disk_event->requests);
+		struct _starpu_disk_backend_event * next;
 
-                /* Wait all events in the list and remove them */
-                while (event != _starpu_disk_backend_event_list_end(async_channel->event.disk_event.requests))
-                {
-                        next = _starpu_disk_backend_event_list_next(event);
+		/* Wait all events in the list and remove them */
+		while (event != _starpu_disk_backend_event_list_end(disk_event->requests))
+		{
+			next = _starpu_disk_backend_event_list_next(event);
 
-                        disk_register_list[node]->functions->wait_request(event->backend_event);
+			disk_register_list[node]->functions->wait_request(event->backend_event);
 
-                        disk_register_list[node]->functions->free_request(event->backend_event);
+			disk_register_list[node]->functions->free_request(event->backend_event);
 
-                        _starpu_disk_backend_event_list_erase(async_channel->event.disk_event.requests, event);
+			_starpu_disk_backend_event_list_erase(disk_event->requests, event);
 
-                        _starpu_disk_backend_event_delete(event);
+			_starpu_disk_backend_event_delete(event);
 
-                        event = next;
-                }
+			event = next;
+		}
 
-                /* Remove the list because it doesn't contain any event */
-                _starpu_disk_backend_event_list_delete(async_channel->event.disk_event.requests);
-                async_channel->event.disk_event.requests = NULL;
-        }
+		/* Remove the list because it doesn't contain any event */
+		_starpu_disk_backend_event_list_delete(disk_event->requests);
+		disk_event->requests = NULL;
+	}
 }
 
 int starpu_disk_test_request(struct _starpu_async_channel *async_channel)
 {
-	unsigned node = async_channel->event.disk_event.memory_node;
+	struct _starpu_disk_event *disk_event = _starpu_disk_get_event(&async_channel->event);
+	unsigned node = disk_event->memory_node;
 
-        if (async_channel->event.disk_event.requests != NULL && !_starpu_disk_backend_event_list_empty(async_channel->event.disk_event.requests))
-        {
-                struct _starpu_disk_backend_event * event = _starpu_disk_backend_event_list_begin(async_channel->event.disk_event.requests);
-                struct _starpu_disk_backend_event * next;
+	if (disk_event->requests != NULL && !_starpu_disk_backend_event_list_empty(disk_event->requests))
+	{
+		struct _starpu_disk_backend_event * event = _starpu_disk_backend_event_list_begin(disk_event->requests);
+		struct _starpu_disk_backend_event * next;
 
-                /* Wait all events in the list and remove them */
-                while (event != _starpu_disk_backend_event_list_end(async_channel->event.disk_event.requests))
-                {
-                        next = _starpu_disk_backend_event_list_next(event);
+		/* Wait all events in the list and remove them */
+		while (event != _starpu_disk_backend_event_list_end(disk_event->requests))
+		{
+			next = _starpu_disk_backend_event_list_next(event);
 
-                        int res = disk_register_list[node]->functions->test_request(event->backend_event);
+			int res = disk_register_list[node]->functions->test_request(event->backend_event);
 
-                                if (res)
-                                {
-                                        disk_register_list[node]->functions->free_request(event->backend_event);
+				if (res)
+				{
+					disk_register_list[node]->functions->free_request(event->backend_event);
 
-                                        _starpu_disk_backend_event_list_erase(async_channel->event.disk_event.requests, event);
+					_starpu_disk_backend_event_list_erase(disk_event->requests, event);
 
-                                        _starpu_disk_backend_event_delete(event);
-                                }
+					_starpu_disk_backend_event_delete(event);
+				}
 
-                        event = next;
-                }
+			event = next;
+		}
 
-                /* Remove the list because it doesn't contain any event */
-                if (_starpu_disk_backend_event_list_empty(async_channel->event.disk_event.requests))
-                {
-                        _starpu_disk_backend_event_list_delete(async_channel->event.disk_event.requests);
-                        async_channel->event.disk_event.requests = NULL;
-                }
-        }
+		/* Remove the list because it doesn't contain any event */
+		if (_starpu_disk_backend_event_list_empty(disk_event->requests))
+		{
+			_starpu_disk_backend_event_list_delete(disk_event->requests);
+			disk_event->requests = NULL;
+		}
+	}
 
-	return async_channel->event.disk_event.requests == NULL;
+	return disk_event->requests == NULL;
 }
 
 void starpu_disk_free_request(struct _starpu_async_channel *async_channe STARPU_ATTRIBUTE_UNUSED)
 {
 /* It does not have any sense to use this function currently because requests are freed in test of wait functions */
-        STARPU_ABORT();
+	STARPU_ABORT();
 
-/*	int position = get_location_with_node(async_channel->event.disk_event.memory_node);
-	if (async_channel->event.disk_event.backend_event)
-		disk_register_list[position]->functions->free_request(async_channel->event.disk_event.backend_event);
+/*	struct _starpu_disk_event *disk_event = _starpu_disk_get_event(&async_channel->event);
+	int position = get_location_with_node(disk_event->memory_node);
+	if (disk_event->backend_event)
+		disk_register_list[position]->functions->free_request(disk_event->backend_event);
 */
 }
 
@@ -449,7 +456,6 @@ static int add_disk_in_list(unsigned node,  struct starpu_disk_ops *func, void *
 	return n;
 }
 
-
 int _starpu_disk_can_copy(unsigned node1, unsigned node2)
 {
 	STARPU_ASSERT(starpu_node_get_kind(node1) == STARPU_DISK_RAM && starpu_node_get_kind(node2) == STARPU_DISK_RAM);
@@ -500,7 +506,7 @@ void _starpu_swap_init(void)
 #ifdef STARPU_LINUX_SYS
 		ops = &starpu_disk_unistd_o_direct_ops;
 #else
-		_STARPU_DISP("Warning: o_direct support is not compiled in, could not enable disk swap");
+		_STARPU_DISP("Warning: o_direct support is not compiled in, could not enable disk swap\n");
 		return;
 #endif
 
@@ -510,31 +516,31 @@ void _starpu_swap_init(void)
 #ifdef STARPU_HAVE_LEVELDB
 		ops = &starpu_disk_leveldb_ops;
 #else
-		_STARPU_DISP("Warning: leveldb support is not compiled in, could not enable disk swap");
+		_STARPU_DISP("Warning: leveldb support is not compiled in, could not enable disk swap\n");
 		return;
 #endif
 	}
-        else if (!strcmp(backend, "hdf5"))
-        {
+	else if (!strcmp(backend, "hdf5"))
+	{
 #ifdef STARPU_HAVE_HDF5
-                ops = &starpu_disk_hdf5_ops;
+		ops = &starpu_disk_hdf5_ops;
 #else
-		_STARPU_DISP("Warning: hdf5 support is not compiled in, could not enable disk swap");
+		_STARPU_DISP("Warning: hdf5 support is not compiled in, could not enable disk swap\n");
 		return;
 #endif
-        }
+	}
 	else
 	{
-		_STARPU_DISP("Warning: unknown disk swap backend %s, could not enable disk swap", backend);
+		_STARPU_DISP("Warning: unknown disk swap backend %s, could not enable disk swap\n", backend);
 		return;
 	}
 
-	size = starpu_get_env_number_default("STARPU_DISK_SWAP_SIZE", -1);
+	size = starpu_getenv_number_default("STARPU_DISK_SWAP_SIZE", -1);
 
 	starpu_disk_swap_node = starpu_disk_register(ops, path, ((size_t) size) << 20);
 	if (starpu_disk_swap_node < 0)
 	{
-		_STARPU_DISP("Warning: could not enable disk swap %s on %s with size %ld, could not enable disk swap", backend, path, (long) size);
+		_STARPU_DISP("Warning: could not enable disk swap %s on %s with size %ld, could not enable disk swap\n", backend, path, (long) size);
 		return;
 	}
 }
