@@ -1,7 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2013-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2013       Corentin Salingue
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2013-2013  Corentin Salingue
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -31,6 +31,8 @@ extern "C"
 #include <datawizard/copy_driver.h>
 #include <datawizard/malloc.h>
 
+#pragma GCC visibility push(hidden)
+
 /** interface to manipulate memory disk */
 void * _starpu_disk_alloc (unsigned node, size_t size) STARPU_ATTRIBUTE_MALLOC;
 
@@ -63,8 +65,18 @@ void _starpu_disk_unregister(void);
 
 void _starpu_swap_init(void);
 
+static inline struct _starpu_disk_event *_starpu_disk_get_event(union _starpu_async_channel_event *_event)
+{
+	struct _starpu_disk_event *event;
+	STARPU_STATIC_ASSERT(sizeof(*event) <= sizeof(*_event));
+	event = (struct _starpu_disk_event *) _event;
+	return event;
+}
+
 #ifdef __cplusplus
 }
 #endif
 
+#pragma GCC visibility pop
+
 #endif /* __DISK_H__ */
