@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -29,7 +29,7 @@ struct starpu_task *starpu_task_dup(struct starpu_task *task)
 
 	/* TODO perhaps this is a bit too much overhead and we should only copy
 	 * part of the structure ? */
-	memcpy(task_dup, task, sizeof(struct starpu_task));
+	*task_dup = *task;
 
 	return task_dup;
 }
