@@ -1,7 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2018       Umeà University
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2018-2018  Umeà University
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -109,78 +109,78 @@ static unsigned long find_long_list_size(struct starpu_perfmodel_history_list *l
 #ifdef STARPU_MLR_MODEL
 int dgels_multiple_reg_coeff(double *mpar, double *my, unsigned long nn, unsigned ncoeff, unsigned nparameters, double *coeff, unsigned **combinations)
 {
- /*  Arguments */
+/*  Arguments */
 /*  ========= */
 
 /*  TRANS   (input) CHARACTER*1 */
-/*          = 'N': the linear system involves A; */
-/*          = 'T': the linear system involves A**T. */
+/*	    = 'N': the linear system involves A; */
+/*	    = 'T': the linear system involves A**T. */
 
-/*  M       (input) INTEGER */
-/*          The number of rows of the matrix A.  M >= 0. */
+/*  M	    (input) INTEGER */
+/*	    The number of rows of the matrix A.	 M >= 0. */
 
-/*  N       (input) INTEGER */
-/*          The number of columns of the matrix A.  N >= 0. */
+/*  N	    (input) INTEGER */
+/*	    The number of columns of the matrix A.  N >= 0. */
 
 /*  NRHS    (input) INTEGER */
-/*          The number of right hand sides, i.e., the number of */
-/*          columns of the matrices B and X. NRHS >=0. */
+/*	    The number of right hand sides, i.e., the number of */
+/*	    columns of the matrices B and X. NRHS >=0. */
 
-/*  A       (input/output) DOUBLE PRECISION array, dimension (LDA,N) */
-/*          On entry, the M-by-N matrix A. */
-/*          On exit, */
-/*            if M >= N, A is overwritten by details of its QR */
-/*                       factorization as returned by DGEQRF; */
-/*            if M <  N, A is overwritten by details of its LQ */
-/*                       factorization as returned by DGELQF. */
+/*  A	    (input/output) DOUBLE PRECISION array, dimension (LDA,N) */
+/*	    On entry, the M-by-N matrix A. */
+/*	    On exit, */
+/*	      if M >= N, A is overwritten by details of its QR */
+/*			 factorization as returned by DGEQRF; */
+/*	      if M <  N, A is overwritten by details of its LQ */
+/*			 factorization as returned by DGELQF. */
 
-/*  LDA     (input) INTEGER */
-/*          The leading dimension of the array A.  LDA >= max(1,M). */
+/*  LDA	    (input) INTEGER */
+/*	    The leading dimension of the array A.  LDA >= max(1,M). */
 
-/*  B       (input/output) DOUBLE PRECISION array, dimension (LDB,NRHS) */
-/*          On entry, the matrix B of right hand side vectors, stored */
-/*          columnwise; B is M-by-NRHS if TRANS = 'N', or N-by-NRHS */
-/*          if TRANS = 'T'. */
-/*          On exit, if INFO = 0, B is overwritten by the solution */
-/*          vectors, stored columnwise: */
-/*          if TRANS = 'N' and m >= n, rows 1 to n of B contain the least */
-/*          squares solution vectors; the residual sum of squares for the */
-/*          solution in each column is given by the sum of squares of */
-/*          elements N+1 to M in that column; */
-/*          if TRANS = 'N' and m < n, rows 1 to N of B contain the */
-/*          minimum norm solution vectors; */
-/*          if TRANS = 'T' and m >= n, rows 1 to M of B contain the */
-/*          minimum norm solution vectors; */
-/*          if TRANS = 'T' and m < n, rows 1 to M of B contain the */
-/*          least squares solution vectors; the residual sum of squares */
-/*          for the solution in each column is given by the sum of */
-/*          squares of elements M+1 to N in that column. */
+/*  B	    (input/output) DOUBLE PRECISION array, dimension (LDB,NRHS) */
+/*	    On entry, the matrix B of right hand side vectors, stored */
+/*	    columnwise; B is M-by-NRHS if TRANS = 'N', or N-by-NRHS */
+/*	    if TRANS = 'T'. */
+/*	    On exit, if INFO = 0, B is overwritten by the solution */
+/*	    vectors, stored columnwise: */
+/*	    if TRANS = 'N' and m >= n, rows 1 to n of B contain the least */
+/*	    squares solution vectors; the residual sum of squares for the */
+/*	    solution in each column is given by the sum of squares of */
+/*	    elements N+1 to M in that column; */
+/*	    if TRANS = 'N' and m < n, rows 1 to N of B contain the */
+/*	    minimum norm solution vectors; */
+/*	    if TRANS = 'T' and m >= n, rows 1 to M of B contain the */
+/*	    minimum norm solution vectors; */
+/*	    if TRANS = 'T' and m < n, rows 1 to M of B contain the */
+/*	    least squares solution vectors; the residual sum of squares */
+/*	    for the solution in each column is given by the sum of */
+/*	    squares of elements M+1 to N in that column. */
 
-/*  LDB     (input) INTEGER */
-/*          The leading dimension of the array B. LDB >= MAX(1,M,N). */
+/*  LDB	    (input) INTEGER */
+/*	    The leading dimension of the array B. LDB >= MAX(1,M,N). */
 
 /*  WORK    (workspace/output) DOUBLE PRECISION array, dimension (MAX(1,LWORK)) */
-/*          On exit, if INFO = 0, WORK(1) returns the optimal LWORK. */
+/*	    On exit, if INFO = 0, WORK(1) returns the optimal LWORK. */
 
 /*  LWORK   (input) INTEGER */
-/*          The dimension of the array WORK. */
-/*          LWORK >= max( 1, MN + max( MN, NRHS ) ). */
-/*          For optimal performance, */
-/*          LWORK >= max( 1, MN + max( MN, NRHS )*NB ). */
-/*          where MN = min(M,N) and NB is the optimum block size. */
+/*	    The dimension of the array WORK. */
+/*	    LWORK >= max(1, MN + max(MN, NRHS)). */
+/*	    For optimal performance, */
+/*	    LWORK >= max(1, MN + max(MN, NRHS) * NB). */
+/*	    where MN = min(M,N) and NB is the optimum block size. */
 
-/*          If LWORK = -1, then a workspace query is assumed; the routine */
-/*          only calculates the optimal size of the WORK array, returns */
-/*          this value as the first entry of the WORK array, and no error */
-/*          message related to LWORK is issued by XERBLA. */
+/*	    If LWORK = -1, then a workspace query is assumed; the routine */
+/*	    only calculates the optimal size of the WORK array, returns */
+/*	    this value as the first entry of the WORK array, and no error */
+/*	    message related to LWORK is issued by XERBLA. */
 
 /*  INFO    (output) INTEGER */
-/*          = 0:  successful exit */
-/*          < 0:  if INFO = -i, the i-th argument had an illegal value */
-/*          > 0:  if INFO =  i, the i-th diagonal element of the */
-/*                triangular factor of A is zero, so that A does not have */
-/*                full rank; the least squares solution could not be */
-/*                computed. */
+/*	    = 0:  successful exit */
+/*	    < 0:  if INFO = -i, the i-th argument had an illegal value */
+/*	    > 0:  if INFO =  i, the i-th diagonal element of the */
+/*		  triangular factor of A is zero, so that A does not have */
+/*		  full rank; the least squares solution could not be */
+/*		  computed. */
 
 /*  ===================================================================== */
 
@@ -193,7 +193,7 @@ int dgels_multiple_reg_coeff(double *mpar, double *my, unsigned long nn, unsigne
 	char trans = 'N';
 	integer m = nn;
 	integer n = ncoeff;
-	integer nrhs = 1; // number of columns of B and X (wich are vectors therefore nrhs=1)
+	integer nrhs = 1; // number of columns of B and X (which are vectors therefore nrhs=1)
 	doublereal *X;
 	_STARPU_MALLOC(X, sizeof(double)*n*m); // (/!\ modified at the output) contain the model and the different values of pararmters
 	doublereal *Y;
@@ -233,9 +233,12 @@ int dgels_multiple_reg_coeff(double *mpar, double *my, unsigned long nn, unsigne
 #endif
 
 	/* Check for the full rank */
-	if( info != 0 )
+	if(info != 0)
 	{
 		_STARPU_DISP("Warning: Problems when executing dgels_ function. It seems like the diagonal element %ld is zero.\n Multiple linear regression model will not be written into perfmodel file.\n", info);
+		free(X);
+		free(Y);
+		free(work);
 		return 1;
 	}
 
@@ -252,9 +255,9 @@ int dgels_multiple_reg_coeff(double *mpar, double *my, unsigned long nn, unsigne
 #endif //STARPU_MLR_MODEL
 
 /*
-   Validating the accuracy of the coefficients.
-   For the the validation is extremely basic, but it should be improved.
- */
+ * Validating the accuracy of the coefficients.
+ * For the the validation is extremely basic, but it should be improved.
+*/
 void starpu_validate_mlr(double *coeff, unsigned ncoeff, const char *codelet_name)
 {
 	unsigned i;
@@ -263,18 +266,18 @@ void starpu_validate_mlr(double *coeff, unsigned ncoeff, const char *codelet_nam
 
 	for(i=1; i<ncoeff; i++)
 		if(fabs(coeff[i]) < 1E-10)
-			_STARPU_DISP("Warning: Coefficient computed by least square method is extremelly small (%f). The model %s is likely to be inaccurate.\n", coeff[i], codelet_name);
+			_STARPU_DISP("Warning: Coefficient computed by least square method is extremely small (%f). The model %s is likely to be inaccurate.\n", coeff[i], codelet_name);
 }
 
 int _starpu_multiple_regression(struct starpu_perfmodel_history_list *ptr, double *coeff, unsigned ncoeff, unsigned nparameters, const char **parameters_names, unsigned **combinations, const char *codelet_name)
 {
-        unsigned long i;
+	unsigned long i;
 	unsigned j;
 
 	/* Computing number of rows */
 	unsigned n=find_long_list_size(ptr);
 
-        /* Reading old calibrations if necessary */
+	/* Reading old calibrations if necessary */
 	FILE *f=NULL;
 
 	char directory[300];
@@ -326,15 +329,15 @@ int _starpu_multiple_regression(struct starpu_perfmodel_history_list *ptr, doubl
 		/* Basic validation of the model accuracy */
 		starpu_validate_mlr(coeff, ncoeff, codelet_name);
 #else
-		_STARPU_DISP("Warning: StarPU was compiled with '--disable-mlr' option or on Windows machine, thus multiple linear regression model will not be computed.\n");
+		_STARPU_DISP("Warning: StarPU was compiled without '--enable-mlr' option, thus multiple linear regression model will not be computed.\n");
 		for(i=0; i<ncoeff; i++)
 			coeff[i] = 0.;
 #endif //STARPU_MLR_MODEL
 	}
 
-	/* Preparing new output calibration file */
 	if (calibrate==1 || calibrate==2)
 	{
+		/* Preparing new output calibration file */
 		if (old_lines > 0)
 		{
 			f = fopen(filepath, "a+");
@@ -353,11 +356,8 @@ int _starpu_multiple_regression(struct starpu_perfmodel_history_list *ptr, doubl
 					fprintf(f, ", P%u", j);
 			}
 		}
-	}
 
-	/* Writing parameters to calibration file */
-	if (calibrate==1 || calibrate==2)
-	{
+		/* Writing parameters to calibration file */
 		for(i=old_lines; i<n; i++)
 		{
 			fprintf(f, "\n%f", my[i]);
