@@ -1,9 +1,9 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2008-2023  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2011       Télécom-SudParis
- * Copyright (C) 2013       Thibaut Lambert
- * Copyright (C) 2016       Uppsala University
+ * Copyright (C) 2008-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2016-2016  Uppsala University
+ * Copyright (C) 2013-2013  Thibaut Lambert
+ * Copyright (C) 2011-2011  Télécom Sud Paris
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -428,7 +428,7 @@ double starpu_data_expected_transfer_time(starpu_data_handle_t handle, unsigned
 {
 	/* FIXME: Fix write-only mode with _starpu_expected_transfer_time_writeback */
 	/* FIXME: count time_writeback only if the data is not dirty. Once it is dirty, we shouldn't
-	 * count the writeback penatly again. */
+	 * count the writeback penalty again. */
 
 	/* If we don't need to read the content of the handle */
 	if (!(mode & STARPU_R))
@@ -791,7 +791,7 @@ void _starpu_set_perf_model_dirs()
 		}
 	}
 
-	_perf_model_add_dir(_STARPU_STRINGIFY(STARPU_SAMPLING_DIR), 1, "by installation directory");
+	_perf_model_add_dir(STARPU_SAMPLING_DIR, 1, "by installation directory");
 }
 
 int _starpu_set_default_perf_model_bus()
