@@ -1,7 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2008-2011,2014                           Université de Bordeaux
- * Copyright (C) 2010-2012,2015,2017                      CNRS
+ * Copyright (C) 2008-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -18,12 +17,18 @@
 #ifndef __REGRESSION_H__
 #define __REGRESSION_H__
 
+/** @file */
+
 #include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <core/perfmodel/perfmodel.h>
 #include <starpu.h>
 
+#pragma GCC visibility push(hidden)
+
 int _starpu_regression_non_linear_power(struct starpu_perfmodel_history_list *ptr, double *a, double *b, double *c);
 
-#endif // __REGRESSION_H__ 
+#pragma GCC visibility pop
+
+#endif // __REGRESSION_H__
