@@ -1,10 +1,8 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2011-2018                                Inria
- * Copyright (C) 2017                                     Arthur Chevalier
- * Copyright (C) 2012-2019                                CNRS
- * Copyright (C) 2012-2019                                Université de Bordeaux
- * Copyright (C) 2016                                     Uppsala University
+ * Copyright (C) 2011-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2016-2016  Uppsala University
+ * Copyright (C) 2017-2017  Arthur Chevalier
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -23,6 +21,7 @@
 #include <common/utils.h>
 #include <stdarg.h>
 #include <core/task.h>
+#include <core/workers.h>
 
 enum _starpu_ctx_change_op
 {
@@ -33,7 +32,7 @@ enum _starpu_ctx_change_op
 static starpu_pthread_mutex_t sched_ctx_manag = STARPU_PTHREAD_MUTEX_INITIALIZER;
 static starpu_pthread_mutex_t finished_submit_mutex = STARPU_PTHREAD_MUTEX_INITIALIZER;
 static struct starpu_task stop_submission_task = STARPU_TASK_INITIALIZER;
-starpu_pthread_key_t sched_ctx_key;
+static starpu_pthread_key_t sched_ctx_key;
 static unsigned with_hypervisor = 0;
 static double hyp_start_sample[STARPU_NMAX_SCHED_CTXS];
 static double hyp_start_allow_sample[STARPU_NMAX_SCHED_CTXS];
@@ -533,13 +532,13 @@ struct _starpu_sched_ctx* _starpu_create_sched_ctx(struct starpu_sched_policy *p
 						   int min_prio_set, int min_prio,
 						   int max_prio_set, int max_prio,
 						   unsigned awake_workers,
-						   void (*sched_policy_init)(unsigned),
+						   void (*sched_policy_callback)(unsigned),
 						   void * user_data,
 						   int nsub_ctxs, int *sub_ctxs, int nsms)
 {
 	struct _starpu_machine_config *config = _starpu_get_machine_config();
 
-	STARPU_ASSERT(config->topology.nsched_ctxs < STARPU_NMAX_SCHED_CTXS);
+	STARPU_ASSERT_MSG_ALWAYS(config->topology.nsched_ctxs < STARPU_NMAX_SCHED_CTXS, "There is too many sched_ctx %d, only %d are configured", config->topology.nsched_ctxs, STARPU_NMAX_SCHED_CTXS);
 
 	unsigned id = _starpu_get_first_free_sched_ctx(config);
 
@@ -566,7 +565,7 @@ struct _starpu_sched_ctx* _starpu_create_sched_ctx(struct starpu_sched_policy *p
 	}
 	sched_ctx->is_initial_sched = is_initial_sched;
 	sched_ctx->name = sched_ctx_name;
-	sched_ctx->inheritor = STARPU_NMAX_SCHED_CTXS;
+	sched_ctx->inheritor = STARPU_GLOBAL_SCHED_CTX;
 	sched_ctx->finished_submit = 0;
 	sched_ctx->min_priority_is_set = min_prio_set;
 	if (sched_ctx->min_priority_is_set)
@@ -590,7 +589,7 @@ struct _starpu_sched_ctx* _starpu_create_sched_ctx(struct starpu_sched_policy *p
 	sched_ctx->main_master = -1;
 	sched_ctx->perf_arch.devices = NULL;
 	sched_ctx->perf_arch.ndevices = 0;
-	sched_ctx->init_sched = sched_policy_init;
+	sched_ctx->callback_sched = sched_policy_callback;
 	sched_ctx->user_data = user_data;
 	sched_ctx->sms_start_idx = 0;
 	sched_ctx->sms_end_idx = STARPU_NMAXSMS;
@@ -604,16 +603,17 @@ struct _starpu_sched_ctx* _starpu_create_sched_ctx(struct starpu_sched_policy *p
 		sched_ctx->sms_start_idx = occupied_sms;
 		sched_ctx->sms_end_idx = occupied_sms+nsms;
 		occupied_sms += nsms;
-		_STARPU_DEBUG("ctx %u: stream worker %d nsms %d ocupied sms %d\n", sched_ctx->id, workerids[0], nsms, occupied_sms);
-		STARPU_ASSERT_MSG(occupied_sms <= STARPU_NMAXSMS , "STARPU:requested more sms than available");
+		_STARPU_DEBUG("ctx %u: stream worker %d nsms %d occupied sms %d\n", sched_ctx->id, workerids[0], nsms, occupied_sms);
+		STARPU_ASSERT_MSG_ALWAYS(occupied_sms <= STARPU_NMAXSMS , "STARPU:requested more sms than available");
 		_starpu_worker_set_stream_ctx(workerids[0], sched_ctx);
 		sched_ctx->stream_worker = workerids[0];
 	}
 
+	sched_ctx->nesting_sched_ctx = STARPU_NMAX_SCHED_CTXS;
 	sched_ctx->nsub_ctxs = 0;
 	sched_ctx->parallel_view = 0;
 
-	/*init the strategy structs and the worker_collection of the ressources of the context */
+	/*init the strategy structs and the worker_collection of the resources of the context */
 	if(policy)
 	{
 		_starpu_init_sched_policy(config, sched_ctx, policy);
@@ -625,7 +625,7 @@ struct _starpu_sched_ctx* _starpu_create_sched_ctx(struct starpu_sched_policy *p
 		starpu_sched_ctx_create_worker_collection(sched_ctx->id, STARPU_WORKER_LIST);
 	}
 
-        /*add sub_ctxs before add workers, in order to be able to associate them if necessary */
+	/*add sub_ctxs before add workers, in order to be able to associate them if necessary */
 	if(nsub_ctxs != 0)
 	{
 		for(i = 0; i < nsub_ctxs; i++)
@@ -712,8 +712,8 @@ unsigned starpu_sched_ctx_create(int *workerids, int nworkers, const char *sched
 	int min_prio = 0;
 	int max_prio = 0;
 	int nsms = 0;
-        int *sub_ctxs = NULL;
-        int nsub_ctxs = 0;
+	int *sub_ctxs = NULL;
+	int nsub_ctxs = 0;
 	void *user_data = NULL;
 	struct starpu_sched_policy *sched_policy = NULL;
 	unsigned hierarchy_level = 0;
@@ -758,7 +758,11 @@ unsigned starpu_sched_ctx_create(int *workerids, int nworkers, const char *sched
 		}
 		else if (arg_type == STARPU_SCHED_CTX_POLICY_INIT)
 		{
+#ifdef __NVCOMPILER
+			init_sched = (void(*)(unsigned))va_arg(varg_list, void *);
+#else
 			init_sched = va_arg(varg_list, void(*)(unsigned));
+#endif
 		}
 		else if (arg_type == STARPU_SCHED_CTX_USER_DATA)
 		{
@@ -824,8 +828,8 @@ int fstarpu_sched_ctx_create(int *workerids, int nworkers, const char *sched_ctx
 	int min_prio = 0;
 	int max_prio = 0;
 	int nsms = 0;
-        int *sub_ctxs = NULL;
-        int nsub_ctxs = 0;
+	int *sub_ctxs = NULL;
+	int nsub_ctxs = 0;
 	void *user_data = NULL;
 	struct starpu_sched_policy *sched_policy = NULL;
 	unsigned hierarchy_level = 0;
@@ -962,8 +966,10 @@ void starpu_sched_ctx_set_perf_counters(unsigned sched_ctx_id, void* perf_counte
 }
 #endif
 
-/* free all structures for the context
-   Must be called with sched_ctx_manag mutex held */
+/*
+ * free all structures for the context
+ * Must be called with sched_ctx_manag mutex held
+*/
 static void _starpu_delete_sched_ctx(struct _starpu_sched_ctx *sched_ctx)
 {
 	STARPU_ASSERT(sched_ctx->id != STARPU_NMAX_SCHED_CTXS);
@@ -1039,8 +1045,8 @@ void starpu_sched_ctx_delete(unsigned sched_ctx_id)
 	sort_workerid_array(nworkers_ctx, backup_workerids);
 	notify_workers_about_changing_ctx_pending(nworkers_ctx, backup_workerids);
 
-	/*if both of them have all the ressources is pointless*/
-	/*trying to transfer ressources from one ctx to the other*/
+	/*if both of them have all the resources is pointless*/
+	/*trying to transfer resources from one ctx to the other*/
 	struct _starpu_machine_config *config = _starpu_get_machine_config();
 	unsigned nworkers = config->topology.nworkers;
 
@@ -1070,6 +1076,7 @@ void starpu_sched_ctx_delete(unsigned sched_ctx_id)
 		_starpu_sched_ctx_unlock_write(sched_ctx_id);
 		_starpu_sched_ctx_unlock_write(inheritor_sched_ctx_id);
 		STARPU_PTHREAD_RWLOCK_DESTROY(&sched_ctx->rwlock);
+		STARPU_PTHREAD_RWLOCK_INIT(&sched_ctx->rwlock, NULL);
 		_starpu_delete_sched_ctx(sched_ctx);
 	}
 	else
@@ -1137,8 +1144,8 @@ static void fetch_tasks_from_empty_ctx_list(struct _starpu_sched_ctx *sched_ctx)
 
 		/* if no workers are able to execute the task, it will be put
 		 * in the empty_ctx_tasks list forever again */
-		unsigned nworkers = _starpu_nworkers_able_to_execute_task(old_task, sched_ctx);
-		STARPU_ASSERT(nworkers > 0);
+		unsigned able = _starpu_workers_able_to_execute_task(old_task, sched_ctx);
+		STARPU_ASSERT(able);
 
 		int ret =  _starpu_push_task_to_workers(old_task);
 		/* if we should stop poping from empty ctx tasks */
@@ -1421,9 +1428,9 @@ void starpu_sched_ctx_remove_workers(int *workers_to_remove, unsigned nworkers_t
 	}
 }
 
-int _starpu_nworkers_able_to_execute_task(struct starpu_task *task, struct _starpu_sched_ctx *sched_ctx)
+int _starpu_workers_able_to_execute_task(struct starpu_task *task, struct _starpu_sched_ctx *sched_ctx)
 {
-	unsigned nworkers = 0;
+	unsigned able = 0;
 
 	_starpu_sched_ctx_lock_read(sched_ctx->id);
 	struct starpu_worker_collection *workers = sched_ctx->workers;
@@ -1436,31 +1443,35 @@ int _starpu_nworkers_able_to_execute_task(struct starpu_task *task, struct _star
 		unsigned worker = workers->get_next(workers, &it);
 		STARPU_ASSERT_MSG(worker < STARPU_NMAXWORKERS, "worker id %u", worker);
 		if (starpu_worker_can_execute_task_first_impl(worker, task, NULL))
-			nworkers++;
+		{
+			able++;
+			break;
+		}
 	}
 	_starpu_sched_ctx_unlock_read(sched_ctx->id);
 
-	return nworkers;
+	return able;
 }
 
 /* unused sched_ctx have the id STARPU_NMAX_SCHED_CTXS */
 void _starpu_init_all_sched_ctxs(struct _starpu_machine_config *config)
 {
 	STARPU_PTHREAD_KEY_CREATE(&sched_ctx_key, NULL);
-	window_size = starpu_get_env_float_default("STARPU_WINDOW_TIME_SIZE", 0.0);
-	nobind = starpu_get_env_number("STARPU_WORKERS_NOBIND");
+	window_size = starpu_getenv_float_default("STARPU_WINDOW_TIME_SIZE", 0.0);
+	nobind = starpu_getenv_number("STARPU_WORKERS_NOBIND");
 
 	unsigned i;
 	for(i = 0; i <= STARPU_NMAX_SCHED_CTXS; i++)
 	{
 		config->sched_ctxs[i].do_schedule = 0;
 		config->sched_ctxs[i].id = STARPU_NMAX_SCHED_CTXS;
+		STARPU_PTHREAD_RWLOCK_INIT0(&config->sched_ctxs[i].rwlock, NULL);
 	}
 
 	return;
 }
 
-/* sched_ctx aren't necessarly one next to another */
+/* sched_ctx aren't necessary one next to another */
 /* for eg when we remove one its place is free */
 /* when we add  new one we reuse its place */
 static unsigned _starpu_get_first_free_sched_ctx(struct _starpu_machine_config *config)
@@ -1502,11 +1513,11 @@ void _starpu_decrement_nsubmitted_tasks_of_sched_ctx(unsigned sched_ctx_id)
 #endif
 
 	struct _starpu_sched_ctx *sched_ctx = _starpu_get_sched_ctx_struct(sched_ctx_id);
-	int reached = _starpu_barrier_counter_get_reached_start(&sched_ctx->tasks_barrier);
+	int reached = _starpu_barrier_counter_get_reached_exit(&sched_ctx->tasks_barrier);
 	int finished = reached == 1;
 
-        /* when finished decrementing the tasks if the user signaled he will not submit tasks anymore
-           we can move all its workers to the inheritor context */
+	/* when finished decrementing the tasks if the user signaled he will not submit tasks anymore
+	   we can move all its workers to the inheritor context */
 	if(finished && sched_ctx->inheritor != STARPU_NMAX_SCHED_CTXS)
 	{
 		STARPU_PTHREAD_MUTEX_LOCK(&finished_submit_mutex);
@@ -1535,7 +1546,7 @@ void _starpu_decrement_nsubmitted_tasks_of_sched_ctx(unsigned sched_ctx_id)
 	}
 
 	/* We also need to check for config->submitting = 0 (i.e. the
-	 * user calle starpu_drivers_request_termination()), in which
+	 * user called starpu_drivers_request_termination()), in which
 	 * case we need to set config->running to 0 and wake workers,
 	 * so they can terminate, just like
 	 * starpu_drivers_request_termination() does.
@@ -1771,33 +1782,33 @@ struct starpu_worker_collection* starpu_sched_ctx_create_worker_collection(unsig
 	{
 #ifdef STARPU_HAVE_HWLOC
 	case STARPU_WORKER_TREE:
-		sched_ctx->workers->has_next = worker_tree.has_next;
-		sched_ctx->workers->get_next = worker_tree.get_next;
-		sched_ctx->workers->add = worker_tree.add;
-		sched_ctx->workers->remove = worker_tree.remove;
-		sched_ctx->workers->init = worker_tree.init;
-		sched_ctx->workers->deinit = worker_tree.deinit;
-		sched_ctx->workers->init_iterator = worker_tree.init_iterator;
-		sched_ctx->workers->init_iterator_for_parallel_tasks = worker_tree.init_iterator_for_parallel_tasks;
+		sched_ctx->workers->has_next = starpu_worker_tree.has_next;
+		sched_ctx->workers->get_next = starpu_worker_tree.get_next;
+		sched_ctx->workers->add = starpu_worker_tree.add;
+		sched_ctx->workers->remove = starpu_worker_tree.remove;
+		sched_ctx->workers->init = starpu_worker_tree.init;
+		sched_ctx->workers->deinit = starpu_worker_tree.deinit;
+		sched_ctx->workers->init_iterator = starpu_worker_tree.init_iterator;
+		sched_ctx->workers->init_iterator_for_parallel_tasks = starpu_worker_tree.init_iterator_for_parallel_tasks;
 		sched_ctx->workers->type = STARPU_WORKER_TREE;
 		break;
 #endif
 //	case STARPU_WORKER_LIST:
 	default:
-		sched_ctx->workers->has_next = worker_list.has_next;
-		sched_ctx->workers->get_next = worker_list.get_next;
-		sched_ctx->workers->add = worker_list.add;
-		sched_ctx->workers->remove = worker_list.remove;
-		sched_ctx->workers->init = worker_list.init;
-		sched_ctx->workers->deinit = worker_list.deinit;
-		sched_ctx->workers->init_iterator = worker_list.init_iterator;
-		sched_ctx->workers->init_iterator_for_parallel_tasks = worker_list.init_iterator_for_parallel_tasks;
+		sched_ctx->workers->has_next = starpu_worker_list.has_next;
+		sched_ctx->workers->get_next = starpu_worker_list.get_next;
+		sched_ctx->workers->add = starpu_worker_list.add;
+		sched_ctx->workers->remove = starpu_worker_list.remove;
+		sched_ctx->workers->init = starpu_worker_list.init;
+		sched_ctx->workers->deinit = starpu_worker_list.deinit;
+		sched_ctx->workers->init_iterator = starpu_worker_list.init_iterator;
+		sched_ctx->workers->init_iterator_for_parallel_tasks = starpu_worker_list.init_iterator_for_parallel_tasks;
 		sched_ctx->workers->type = STARPU_WORKER_LIST;
 		break;
 
 	}
 
-        /* construct the collection of workers(list/tree/etc.) */
+	/* construct the collection of workers(list/tree/etc.) */
 	sched_ctx->workers->init(sched_ctx->workers);
 
 	return sched_ctx->workers;
@@ -1895,35 +1906,35 @@ unsigned starpu_sched_ctx_get_nworkers(unsigned sched_ctx_id)
 
 unsigned starpu_sched_ctx_get_nshared_workers(unsigned sched_ctx_id, unsigned sched_ctx_id2)
 {
-        struct _starpu_sched_ctx *sched_ctx = _starpu_get_sched_ctx_struct(sched_ctx_id);
-        struct _starpu_sched_ctx *sched_ctx2 = _starpu_get_sched_ctx_struct(sched_ctx_id2);
+	struct _starpu_sched_ctx *sched_ctx = _starpu_get_sched_ctx_struct(sched_ctx_id);
+	struct _starpu_sched_ctx *sched_ctx2 = _starpu_get_sched_ctx_struct(sched_ctx_id2);
 
-        struct starpu_worker_collection *workers = sched_ctx->workers;
-        struct starpu_worker_collection *workers2 = sched_ctx2->workers;
-        int shared_workers = 0;
+	struct starpu_worker_collection *workers = sched_ctx->workers;
+	struct starpu_worker_collection *workers2 = sched_ctx2->workers;
+	int shared_workers = 0;
 	struct starpu_sched_ctx_iterator it1, it2;
 
 	workers->init_iterator(workers, &it1);
 	workers2->init_iterator(workers2, &it2);
-        while(workers->has_next(workers, &it1))
-        {
-                int worker = workers->get_next(workers, &it1);
-                while(workers2->has_next(workers2, &it2))
+	while(workers->has_next(workers, &it1))
+	{
+		int worker = workers->get_next(workers, &it1);
+		while(workers2->has_next(workers2, &it2))
 		{
-                        int worker2 = workers2->get_next(workers2, &it2);
-                        if(worker == worker2)
+			int worker2 = workers2->get_next(workers2, &it2);
+			if(worker == worker2)
 				shared_workers++;
-                }
-        }
+		}
+	}
 
 	return shared_workers;
 }
 
 unsigned starpu_sched_ctx_contains_worker(int workerid, unsigned sched_ctx_id)
 {
-        struct _starpu_sched_ctx *sched_ctx = _starpu_get_sched_ctx_struct(sched_ctx_id);
+	struct _starpu_sched_ctx *sched_ctx = _starpu_get_sched_ctx_struct(sched_ctx_id);
 
-        struct starpu_worker_collection *workers = sched_ctx->workers;
+	struct starpu_worker_collection *workers = sched_ctx->workers;
 	if(workers)
 	{
 		unsigned i;
@@ -2168,8 +2179,7 @@ unsigned _starpu_sched_ctx_last_worker_awake(struct _starpu_worker *worker)
 	 * awake. In the worst case, both workers will follow this pessimistic
 	 * path and perform one more scheduling loop */
 	STARPU_HG_DISABLE_CHECKING(_starpu_config.workers[worker->workerid].status);
-	STARPU_ASSERT(_starpu_config.workers[worker->workerid].status == STATUS_SLEEPING
-	           || _starpu_config.workers[worker->workerid].status == STATUS_SLEEPING_SCHEDULING);
+	STARPU_ASSERT(_starpu_config.workers[worker->workerid].status & STATUS_SLEEPING);
 	STARPU_HG_ENABLE_CHECKING(_starpu_config.workers[worker->workerid].status);
 	struct _starpu_sched_ctx_list_iterator list_it;
 
@@ -2203,8 +2213,7 @@ unsigned _starpu_sched_ctx_last_worker_awake(struct _starpu_worker *worker)
 					 * pessimistic path and assume that they are
 					 * the last worker awake */
 					STARPU_HG_DISABLE_CHECKING(_starpu_config.workers[workerid].status);
-					const int cond = _starpu_config.workers[workerid].status != STATUS_SLEEPING
-					              && _starpu_config.workers[workerid].status != STATUS_SLEEPING_SCHEDULING;
+					const int cond = !(_starpu_config.workers[workerid].status & STATUS_SLEEPING);
 					STARPU_HG_ENABLE_CHECKING(_starpu_config.workers[workerid].status);
 
 					if (cond)
@@ -2284,14 +2293,14 @@ struct _starpu_sched_ctx *__starpu_sched_ctx_get_sched_ctx_for_worker_and_job(st
 
 void starpu_sched_ctx_revert_task_counters_ctx_locked(unsigned sched_ctx_id, double ready_flops)
 {
-        _starpu_decrement_nsubmitted_tasks_of_sched_ctx(sched_ctx_id);
-        _starpu_decrement_nready_tasks_of_sched_ctx_locked(sched_ctx_id, ready_flops);
+	_starpu_decrement_nsubmitted_tasks_of_sched_ctx(sched_ctx_id);
+	_starpu_decrement_nready_tasks_of_sched_ctx_locked(sched_ctx_id, ready_flops);
 }
 
 void starpu_sched_ctx_revert_task_counters(unsigned sched_ctx_id, double ready_flops)
 {
-        _starpu_decrement_nsubmitted_tasks_of_sched_ctx(sched_ctx_id);
-        _starpu_decrement_nready_tasks_of_sched_ctx(sched_ctx_id, ready_flops);
+	_starpu_decrement_nsubmitted_tasks_of_sched_ctx(sched_ctx_id);
+	_starpu_decrement_nready_tasks_of_sched_ctx(sched_ctx_id, ready_flops);
 }
 
 void starpu_sched_ctx_move_task_to_ctx_locked(struct starpu_task *task, unsigned sched_ctx, unsigned with_repush)
@@ -2671,10 +2680,10 @@ int starpu_sched_ctx_get_worker_rank(unsigned sched_ctx_id)
 	return -1;
 }
 
-void (*starpu_sched_ctx_get_sched_policy_init(unsigned sched_ctx_id))(unsigned)
+void (*starpu_sched_ctx_get_sched_policy_callback(unsigned sched_ctx_id))(unsigned)
 {
 	struct _starpu_sched_ctx *sched_ctx = _starpu_get_sched_ctx_struct(sched_ctx_id);
-	return sched_ctx->init_sched;
+	return sched_ctx->callback_sched;
 }
 
 unsigned starpu_sched_ctx_has_starpu_scheduler(unsigned sched_ctx_id, unsigned *awake_workers)
@@ -2767,8 +2776,9 @@ void _starpu_worker_apply_deferred_ctx_changes(void)
 
 }
 
-/* TODO: verify starpu_sched_ctx_create_inside_interval correctness before re-enabling the functions below
-   */
+/*
+ * TODO: verify starpu_sched_ctx_create_inside_interval correctness before re-enabling the functions below
+ */
 #if 0
 static void _get_workers(int min, int max, int *workers, int *nw, enum starpu_worker_archtype arch, unsigned allow_overlap)
 {
@@ -2780,30 +2790,30 @@ static void _get_workers(int min, int max, int *workers, int *nw, enum starpu_wo
 	if(config->topology.nsched_ctxs == 1)
 	{
 		/*we have all available resources */
-		npus = starpu_worker_get_nids_by_type(arch, pus, max);
+		npus = _starpu_worker_get_nids_by_type(arch, pus, max);
 /*TODO: hierarchical ctxs: get max good workers: close one to another */
 		for(i = 0; i < npus; i++)
 			workers[(*nw)++] = pus[i];
 	}
 	else
 	{
-		unsigned enough_ressources = 0;
-		npus = starpu_worker_get_nids_ctx_free_by_type(arch, pus, max);
+		unsigned enough_resources = 0;
+		npus = _starpu_worker_get_nids_ctx_free_by_type(arch, pus, max);
 
 		for(i = 0; i < npus; i++)
 			workers[(*nw)++] = pus[i];
 
 		if(npus == max)
 			/*we have enough available resources */
-			enough_ressources = 1;
+			enough_resources = 1;
 
-		if(!enough_ressources && npus >= min)
+		if(!enough_resources && npus >= min)
 			/*we have enough available resources */
-			enough_ressources = 1;
+			enough_resources = 1;
 
-		if(!enough_ressources)
+		if(!enough_resources)
 		{
-			/* try to get ressources from ctx who have more than the min of workers they need */
+			/* try to get resources from ctx who have more than the min of workers they need */
 			int s;
 			for(s = 1; s < STARPU_NMAX_SCHED_CTXS; s++)
 			{
@@ -2830,10 +2840,10 @@ static void _get_workers(int min, int max, int *workers, int *nw, enum starpu_wo
 			}
 
 			if(npus >= min)
-				enough_ressources = 1;
+				enough_resources = 1;
 		}
 
-		if(!enough_ressources)
+		if(!enough_resources)
 		{
 			/* if there is no available workers to satisfy the  minimum required
 			 give them workers proportional to their requirements*/
