@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -21,6 +21,8 @@
 
 #include <starpu_thread.h>
 
+#pragma GCC visibility push(hidden)
+
 /** struct _starpu_task_bundle_entry
  * ================================
  * Purpose
@@ -76,7 +78,7 @@ struct _starpu_task_bundle
  * =======
  * Structure describing a list of handles sorted by address to speed-up
  * when looking for an element.
- * The list cannot containes duplicate handles.
+ * The list cannot contain duplicate handles.
  *
  * Fields
  * ======
@@ -99,7 +101,7 @@ struct _starpu_handle_list
  * Purpose
  * =======
  * Destroy and deinitialize a bundle,
- * memory previoulsy allocated is freed.
+ * memory previously allocated is freed.
  *
  * Arguments
  * =========
@@ -133,4 +135,6 @@ void _starpu_task_bundle_destroy(starpu_task_bundle_t bundle);
  */
 void _starpu_insertion_handle_sorted(struct _starpu_handle_list **listp, starpu_data_handle_t handle, enum starpu_data_access_mode mode);
 
+#pragma GCC visibility pop
+
 #endif // __CORE_TASK_BUNDLE_H__
