@@ -1,10 +1,10 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2008-2023  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2011       Télécom-SudParis
- * Copyright (C) 2013       Thibaut Lambert
- * Copyright (C) 2016       Uppsala University
- * Copyright (C) 2021       Federal University of Rio Grande do Sul (UFRGS)
+ * Copyright (C) 2008-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2016-2016  Uppsala University
+ * Copyright (C) 2013-2013  Thibaut Lambert
+ * Copyright (C) 2011-2011  Télécom Sud Paris
+ * Copyright (C) 2021-2021  Federal University of Rio Grande do Sul (UFRGS)
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -1843,6 +1843,12 @@ int starpu_initialize(struct starpu_conf *user_conf, int *argc, char ***argv)
 
 		_starpu_destroy_machine_config(&_starpu_config, is_a_sink);
 
+		free((char*) _starpu_config.conf.sched_policy_name);
+		if (_starpu_config.conf.n_cuda_opengl_interoperability)
+			free(_starpu_config.conf.cuda_opengl_interoperability);
+		if (_starpu_config.conf.n_not_launched_drivers)
+			free(_starpu_config.conf.not_launched_drivers);
+
 #ifdef STARPU_USE_MPI_MASTER_SLAVE
 		if (_starpu_mpi_common_is_mp_initialized())
 			_starpu_mpi_common_mp_deinit();
@@ -2227,7 +2233,7 @@ void starpu_shutdown(void)
 	_starpu_job_fini();
 
 	/* Drop all remaining tags */
-	_starpu_tag_clear();
+	starpu_tag_clear();
 
 #ifdef STARPU_OPENMP
 	_starpu_omp_dummy_shutdown();
