@@ -1,8 +1,8 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2008-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2013       Thibaut Lambert
- * Copyright (C) 2016       Uppsala University
+ * Copyright (C) 2008-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2016-2016  Uppsala University
+ * Copyright (C) 2013-2013  Thibaut Lambert
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -41,40 +41,126 @@
 #ifdef STARPU_HAVE_HWLOC
 #include <hwloc.h>
 #endif
+#include <common/knobs.h>
 
 #include <core/drivers.h>
 #include <drivers/cuda/driver_cuda.h>
+#include <drivers/hip/driver_hip.h>
 #include <drivers/opencl/driver_opencl.h>
 
-#ifdef STARPU_USE_MIC
-#include <drivers/mic/driver_mic_source.h>
-#endif /* STARPU_USE_MIC */
-
 #ifdef STARPU_USE_MPI_MASTER_SLAVE
 #include <drivers/mpi/driver_mpi_source.h>
 #endif
 
+#ifdef STARPU_USE_TCPIP_MASTER_SLAVE
+#include <drivers/tcpip/driver_tcpip_source.h>
+#endif
+
 #include <drivers/cpu/driver_cpu.h>
 
 #include <datawizard/datawizard.h>
+#include <datawizard/malloc.h>
 
-#include <starpu_parameters.h>
+#pragma GCC visibility push(hidden)
 
 #define STARPU_MAX_PIPELINE 4
 
-enum initialization { UNINITIALIZED = 0, CHANGING, INITIALIZED };
+struct mc_cache_entry;
+struct _starpu_node
+{
+	/*
+	 * used by memalloc.c
+	 */
+	/** This per-node RW-locks protect mc_list and memchunk_cache entries */
+	/* Note: handle header lock is always taken before this (normal add/remove case) */
+	struct _starpu_spinlock mc_lock;
+
+	/** Potentially in use memory chunks. The beginning of the list is clean (home
+	 * node has a copy of the data, or the data is being transferred there), the
+	 * remainder of the list may not be clean. */
+	struct _starpu_mem_chunk_list mc_list;
+	/** This is a shortcut inside the mc_list to the first potentially dirty MC. All
+	 * MC before this are clean, MC before this only *may* be clean. */
+	struct _starpu_mem_chunk *mc_dirty_head;
+	/* TODO: introduce head of data to be evicted */
+	/** Number of elements in mc_list, number of elements in the clean part of
+	 * mc_list plus the non-automatically allocated elements (which are thus always
+	 * considered as clean) */
+	unsigned mc_nb, mc_clean_nb;
+
+	struct mc_cache_entry *mc_cache;
+	int mc_cache_nb;
+	starpu_ssize_t mc_cache_size;
+
+	/** Whether some thread is currently tidying this node */
+	unsigned tidying;
+	/** Whether some thread is currently reclaiming memory for this node */
+	unsigned reclaiming;
+
+	/** This records that we tried to prefetch data but went out of memory, so will
+	 * probably fail again to prefetch data, thus not trace each and every
+	 * attempt. */
+	volatile int prefetch_out_of_memory;
+
+	/** Whether this memory node can evict data to another node */
+	unsigned evictable;
+
+	/*
+	 * used by data_request.c
+	 */
+	/** requests that have not been treated at all */
+	struct _starpu_data_request_prio_list data_requests[STARPU_MAXNODES][2];
+	struct _starpu_data_request_prio_list prefetch_requests[STARPU_MAXNODES][2]; /* Contains both task_prefetch and prefetch */
+	struct _starpu_data_request_prio_list idle_requests[STARPU_MAXNODES][2];
+	starpu_pthread_mutex_t data_requests_list_mutex[STARPU_MAXNODES][2];
+
+	/** requests that are not terminated (eg. async transfers) */
+	struct _starpu_data_request_prio_list data_requests_pending[STARPU_MAXNODES][2];
+	unsigned data_requests_npending[STARPU_MAXNODES][2];
+	starpu_pthread_mutex_t data_requests_pending_list_mutex[STARPU_MAXNODES][2];
+
+	/*
+	 * used by malloc.c
+	 */
+	int malloc_on_node_default_flags;
+	/** One list of chunks per node */
+	struct _starpu_chunk_list chunks;
+	/** Number of completely free chunks */
+	int nfreechunks;
+	/** This protects chunks and nfreechunks */
+	starpu_pthread_mutex_t chunk_mutex;
+
+	/*
+	 * used by memory_manager.c
+	 */
+	size_t global_size;
+	size_t used_size;
+
+	/* This is used as an optimization to avoid to wake up allocating threads for
+	 * each and every deallocation, only to find that there is still not enough
+	 * room.  */
+	/* Minimum amount being waited for */
+	size_t waiting_size;
+
+	starpu_pthread_mutex_t lock_nodes;
+	starpu_pthread_cond_t cond_nodes;
+
+	/** Keep this last, to make sure to separate node data in separate
+	cache lines. */
+	char padding[STARPU_CACHELINE_SIZE];
+};
 
 struct _starpu_ctx_change_list;
-
 /** This is initialized by _starpu_worker_init() */
 LIST_TYPE(_starpu_worker,
 	struct _starpu_machine_config *config;
-        starpu_pthread_mutex_t mutex;
+	starpu_pthread_mutex_t mutex;
 	enum starpu_worker_archtype arch; /**< what is the type of worker ? */
 	uint32_t worker_mask; /**< what is the type of worker ? */
 	struct starpu_perfmodel_arch perf_arch; /**< in case there are different models of the same arch */
 	starpu_pthread_t worker_thread; /**< the thread which runs the worker */
 	unsigned devid; /**< which cpu/gpu/etc is controlled by the worker ? */
+	unsigned devnum; /**< number of the device controlled by the worker, i.e. ranked from 0 and contiguous */
 	unsigned subworkerid; /**< which sub-worker this one is for the cpu/gpu */
 	int bindid; /**< which cpu is the driver bound to ? (logical index) */
 	int workerid; /**< uniquely identify the worker among all processing units types */
@@ -90,7 +176,7 @@ LIST_TYPE(_starpu_worker,
 	   * STARPU_PTHREAD_COND_BROADCAST must be used instead of STARPU_PTHREAD_COND_SIGNAL,
 	   * since the condition is shared for multiple purpose */
 	starpu_pthread_cond_t sched_cond;
-        starpu_pthread_mutex_t sched_mutex; /**< mutex protecting sched_cond */
+	starpu_pthread_mutex_t sched_mutex; /**< mutex protecting sched_cond */
 	unsigned state_relax_refcnt; /**< mark scheduling sections where other workers can safely access the worker state */
 #ifdef STARPU_SPINLOCK_CHECK
 	const char *relax_on_file;
@@ -126,8 +212,8 @@ LIST_TYPE(_starpu_worker,
 	     * subsequent processing once worker completes the ongoing scheduling
 	     * operation */
 	struct _starpu_ctx_change_list ctx_change_list;
-	struct starpu_task_list local_tasks; /**< this queue contains tasks that have been explicitely submitted to that queue */
-	struct starpu_task **local_ordered_tasks; /**< this queue contains tasks that have been explicitely submitted to that queue with an explicit order */
+	struct starpu_task_prio_list local_tasks; /**< this queue contains tasks that have been explicitly submitted to that queue */
+	struct starpu_task **local_ordered_tasks; /**< this queue contains tasks that have been explicitly submitted to that queue with an explicit order */
 	unsigned local_ordered_tasks_size; /**< this records the size of local_ordered_tasks */
 	unsigned current_ordered_task; /**< this records the index (within local_ordered_tasks) of the next ordered task to be executed */
 	unsigned current_ordered_task_order; /**< this records the order of the next ordered task to be executed */
@@ -138,20 +224,23 @@ LIST_TYPE(_starpu_worker,
 #endif
 
 	struct timespec cl_start; /**< Codelet start time of the task currently running */
+	struct timespec cl_expend; /**< Codelet expected end time of the task currently running */
 	struct timespec cl_end; /**< Codelet end time of the last task running */
 	unsigned char first_task; /**< Index of first task in the pipeline */
 	unsigned char ntasks; /**< number of tasks in the pipeline */
 	unsigned char pipeline_length; /**< number of tasks to be put in the pipeline */
 	unsigned char pipeline_stuck; /**< whether a task prevents us from pipelining */
-	struct _starpu_worker_set *set; /**< in case this worker belongs to a set */
+	struct _starpu_worker_set *set; /**< in case this worker belongs to a worker set */
+	struct _starpu_worker_set *driver_worker_set; /**< in case this worker belongs to a driver worker set */
 	unsigned worker_is_running;
 	unsigned worker_is_initialized;
+	unsigned wait_for_worker_initialization;
 	enum _starpu_worker_status status; /**< what is the worker doing now ? (eg. CALLBACK) */
 	unsigned state_keep_awake; /**< !0 if a task has been pushed to the worker and the task has not yet been seen by the worker, the worker should no go to sleep before processing this task*/
 	char name[128];
 	char short_name[32];
 	unsigned run_by_starpu; /**< Is this run by StarPU or directly by the application ? */
-	struct _starpu_driver_ops *driver_ops;
+	const struct _starpu_driver_ops *driver_ops;
 
 	struct _starpu_sched_ctx_list *sched_ctx_list;
 	int tmp_sched_ctx;
@@ -170,11 +259,11 @@ LIST_TYPE(_starpu_worker,
 
 	  /**
 	   * indicate whether the workers shares tasks lists with other workers
-	   * in this case when removing him from a context it disapears instantly
+	   * in this case when removing him from a context it disappears instantly
 	   */
 	unsigned shares_tasks_lists[STARPU_NMAX_SCHED_CTXS+1];
 
-	unsigned poped_in_ctx[STARPU_NMAX_SCHED_CTXS+1]; 	  /**< boolean to chose the next ctx a worker will pop into */
+	unsigned poped_in_ctx[STARPU_NMAX_SCHED_CTXS+1];	  /**< boolean to chose the next ctx a worker will pop into */
 
 	  /**
 	   * boolean indicating at which moment we checked all ctxs and change phase for the booleab poped_in_ctx
@@ -182,8 +271,8 @@ LIST_TYPE(_starpu_worker,
 	   */
 	unsigned reverse_phase[2];
 
-	unsigned pop_ctx_priority; 	  /**< indicate which priority of ctx is currently active: the values are 0 or 1*/
-	unsigned is_slave_somewhere; 	  /**< bool to indicate if the worker is slave in a ctx */
+	unsigned pop_ctx_priority;	  /**< indicate which priority of ctx is currently active: the values are 0 or 1*/
+	unsigned is_slave_somewhere;	  /**< bool to indicate if the worker is slave in a ctx */
 
 	struct _starpu_sched_ctx *stream_ctx;
 
@@ -195,16 +284,35 @@ LIST_TYPE(_starpu_worker,
 	hwloc_obj_t hwloc_obj;
 #endif
 
-	/** Keep this last, to make sure to separate worker data in separate cache lines. */
+	struct starpu_profiling_worker_info profiling_info;
+	/* TODO: rather use rwlock? */
+	starpu_pthread_mutex_t profiling_info_mutex;
+
+	/* In case the worker is still sleeping when the user request profiling info,
+	 * we need to account for the time elapsed while sleeping. */
+	unsigned profiling_registered_start[STATUS_INDEX_NR];
+	struct timespec profiling_registered_start_date[STATUS_INDEX_NR];
+	enum _starpu_worker_status profiling_status;
+	struct timespec profiling_status_start_date;
+
+	struct starpu_perf_counter_sample perf_counter_sample;
+	int64_t __w_total_executed__value;
+	double __w_cumul_execution_time__value;
+
+	int enable_knob;
+	int bindid_requested;
+
+	  /** Keep this last, to make sure to separate worker data in separate
+	  cache lines. */
 	char padding[STARPU_CACHELINE_SIZE];
 );
 
 struct _starpu_combined_worker
 {
-	struct starpu_perfmodel_arch perf_arch; 	 /**< in case there are different models of the same arch */
+	struct starpu_perfmodel_arch perf_arch;		 /**< in case there are different models of the same arch */
 	uint32_t worker_mask; /**< what is the type of workers ? */
 	int worker_size;
-	unsigned memory_node; 	 /**< which memory node is associated that worker to ? */
+	unsigned memory_node;	 /**< which memory node is associated that worker to ? */
 	int combined_workerid[STARPU_NMAXWORKERS];
 #ifdef STARPU_USE_MP
 	int count;
@@ -229,20 +337,17 @@ struct _starpu_combined_worker
 */
 struct _starpu_worker_set
 {
-        starpu_pthread_mutex_t mutex;
+	starpu_pthread_mutex_t mutex;
 	starpu_pthread_t worker_thread; /**< the thread which runs the worker */
 	unsigned nworkers;
 	unsigned started; /**< Only one thread for the whole set */
 	void *retval;
 	struct _starpu_worker *workers;
-        starpu_pthread_cond_t ready_cond; /**< indicate when the set is ready */
+	starpu_pthread_cond_t ready_cond; /**< indicate when the set is ready */
 	unsigned set_is_initialized;
+	unsigned wait_for_set_initialization;
 };
 
-#ifdef STARPU_USE_MPI_MASTER_SLAVE
-extern struct _starpu_worker_set mpi_worker_set[STARPU_MAXMPIDEVS];
-#endif
-
 struct _starpu_machine_topology
 {
 	/** Total number of workers. */
@@ -256,61 +361,57 @@ struct _starpu_machine_topology
 #ifdef STARPU_HAVE_HWLOC
 	/** Topology as detected by hwloc. */
 	hwloc_topology_t hwtopology;
+	hwloc_bitmap_t log_cpuset;
+	hwloc_bitmap_t log_coreset;
 #endif
 	/** custom hwloc tree*/
 	struct starpu_tree *tree;
 
-	/** Total number of CPU cores, as detected by the topology code. May
-	 * be different from the actual number of CPU workers.
-	 */
-	unsigned nhwcpus;
-
 	/** Total number of PUs (i.e. threads), as detected by the topology code. May
-	 * be different from the actual number of PU workers.
+	 * be different from the actual number of CPU workers.
 	 */
 	unsigned nhwpus;
 
-	/** Total number of CUDA devices, as detected. May be different
-	 * from the actual number of CUDA workers.
+	/** First PU to be used. May be different from 0 for administrative reasons
+	 * (e.g. from job scheduler).
 	 */
-	unsigned nhwcudagpus;
+	unsigned firstusedpu;
 
-	/** Total number of OpenCL devices, as detected. May be
-	 * different from the actual number of OpenCL workers.
+	/** Number of PUs (i.e. threads) to be used. May be different from nhwpus for
+	 * administrative reasons (e.g. from job scheduler).
 	 */
-	unsigned nhwopenclgpus;
+	unsigned nusedpus;
 
-	/** Total number of MPI nodes, as detected. May be different
-	 * from the actual number of node workers.
+	/** Total number of devices, as detected. May be different from the
+	 * actual number of devices run by StarPU.
 	 */
-	unsigned nhwmpi;
+	unsigned nhwdevices[STARPU_NARCH];
+	/** Total number of worker for each device, as detected. May be different from the
+	 * actual number of workers run by StarPU.
+	 */
+	unsigned nhwworker[STARPU_NARCH][STARPU_NMAXDEVS];
 
-	/** Actual number of CPU workers used by StarPU. */
-	unsigned ncpus;
+	/** Actual number of devices used by StarPU.
+	 */
+	unsigned ndevices[STARPU_NARCH];
 
-	/** Actual number of CUDA GPUs used by StarPU. */
-	unsigned ncudagpus;
-	unsigned nworkerpercuda;
+	/** Number of worker per device
+	 */
+	unsigned nworker[STARPU_NARCH][STARPU_NMAXDEVS];
+
+	/** Device ids actually used
+	 */
+	int devid[STARPU_NARCH][STARPU_NMAXDEVS];
+
+	/** Whether we should have one thread per stream */
 	int cuda_th_per_stream;
+	/** Whether we should have one thread per device */
 	int cuda_th_per_dev;
 
-	/** Actual number of OpenCL workers used by StarPU. */
-	unsigned nopenclgpus;
-
-	/** Actual number of MPI workers used by StarPU. */
-	unsigned nmpidevices;
-        unsigned nhwmpidevices;
-
-	unsigned nhwmpicores[STARPU_MAXMPIDEVS]; /**< Each MPI node has its set of cores. */
-	unsigned nmpicores[STARPU_MAXMPIDEVS];
-
-	/** Topology of MP nodes (MIC) as well as necessary
-	 * objects to communicate with them. */
-	unsigned nhwmicdevices;
-	unsigned nmicdevices;
-
-	unsigned nhwmiccores[STARPU_MAXMICDEVS]; /**< Each MIC node has its set of cores. */
-	unsigned nmiccores[STARPU_MAXMICDEVS];
+	/** Whether we should have one thread per stream (for hip) */
+	int hip_th_per_stream;
+	/** Whether we should have one thread per device (for hip) */
+	int hip_th_per_dev;
 
 	/** Indicates the successive logical PU identifier that should be used
 	 * to bind the workers. It is either filled according to the
@@ -321,31 +422,19 @@ struct _starpu_machine_topology
 	 */
 	unsigned workers_bindid[STARPU_NMAXWORKERS];
 
-	/** Indicates the successive CUDA identifier that should be
-	 * used by the CUDA driver.  It is either filled according to
+	/** Indicates how many different values there are in
+	 * _starpu_machine_topology::workers_bindid, i.e. the length of the
+	 * cycle of the values there.
+	 */
+	unsigned workers_nbindid;
+
+	/** Indicates the successive device identifiers that should be
+	 * used by the driver.	It is either filled according to
 	 * the user's explicit parameters (from starpu_conf) or
-	 * according to the STARPU_WORKERS_CUDAID env. variable.
+	 * according to the corresponding env. variable.
 	 * Otherwise, they are taken in ID order.
 	 */
-	unsigned workers_cuda_gpuid[STARPU_NMAXWORKERS];
-
-	/** Indicates the successive OpenCL identifier that should be
-	 * used by the OpenCL driver.  It is either filled according
-	 * to the user's explicit parameters (from starpu_conf) or
-	 * according to the STARPU_WORKERS_OPENCLID env. variable.
-	 * Otherwise, they are taken in ID order.
-	 */
-	unsigned workers_opencl_gpuid[STARPU_NMAXWORKERS];
-
-	/*** Indicates the successive MIC devices that should be used
-	 * by the MIC driver.  It is either filled according to the
-	 * user's explicit parameters (from starpu_conf) or according
-	 * to the STARPU_WORKERS_MICID env. variable. Otherwise, they
-	 * are taken in ID order. */
-	/** TODO */
-	/** unsigned workers_mic_deviceid[STARPU_NMAXWORKERS]; */
-
-	unsigned workers_mpi_ms_deviceid[STARPU_NMAXWORKERS];
+	unsigned workers_devid[STARPU_NARCH][STARPU_NMAXWORKERS];
 };
 
 struct _starpu_machine_config
@@ -362,28 +451,14 @@ struct _starpu_machine_config
 	char currently_bound[STARPU_NMAXWORKERS];
 	char currently_shared[STARPU_NMAXWORKERS];
 
-	/** Which GPU(s) do we use for CUDA ? */
-	int current_cuda_gpuid;
+	/** Which next device will we use for each arch? */
+	int current_devid[STARPU_NARCH];
 
-	/** Which GPU(s) do we use for OpenCL ? */
-	int current_opencl_gpuid;
+	/** Which TCPIP do we use? */
+	int current_tcpip_deviceid;
 
-	/** Which MIC do we use? */
-	int current_mic_deviceid;
-
-	/** Which MPI do we use? */
-	int current_mpi_deviceid;
-
-	/** Memory node for cpus, if only one */
-	int cpus_nodeid;
-	/** Memory node for CUDA, if only one */
-	int cuda_nodeid;
-	/** Memory node for OpenCL, if only one */
-	int opencl_nodeid;
-	/** Memory node for MIC, if only one */
-	int mic_nodeid;
-	/** Memory node for MPI, if only one */
-	int mpi_nodeid;
+	/** Memory node for different worker types, if only one */
+	int arch_nodeid [STARPU_NARCH];
 
 	/** Separate out previous variables from per-worker data. */
 	char padding1[STARPU_CACHELINE_SIZE];
@@ -392,6 +467,9 @@ struct _starpu_machine_config
 	 * can be combined with other basic workers. */
 	struct _starpu_worker workers[STARPU_NMAXWORKERS];
 
+	/** Memory nodes */
+	struct _starpu_node nodes[STARPU_MAXNODES];
+
 	/** Combined workers: these worker are a combination of basic workers
 	 * that can run parallel tasks together. */
 	struct _starpu_combined_worker combined_workers[STARPU_NMAX_COMBINEDWORKERS];
@@ -414,7 +492,7 @@ struct _starpu_machine_config
 	 * the result of (worker_mask & STARPU_CUDA). */
 	uint32_t worker_mask;
 
-        /** either the user given configuration passed to starpu_init or a default configuration */
+	/** either the user given configuration passed to starpu_init or a default configuration */
 	struct starpu_conf conf;
 
 	/** this flag is set until the runtime is stopped */
@@ -433,14 +511,58 @@ struct _starpu_machine_config
 	unsigned submitting;
 
 	int watchdog_ok;
+
+	/** When >0, StarPU should stop performance counters collection. */
+	int perf_counter_pause_depth;
 };
 
+struct _starpu_machine_topology;
+
+/** Provides information for a device driver */
+struct _starpu_driver_info
+{
+	const char *name_upper;	/**< Name of worker type in upper case */
+	const char *name_var;	/**< Name of worker type for environment variables */
+	const char *name_lower;	/**< Name of worker type in lower case */
+	enum starpu_node_kind memory_kind;	/**< Kind of memory in device */
+	double alpha;	/**< Typical relative speed compared to a CPU core */
+	unsigned wait_for_worker_initialization;	/**< Whether we should make the core wait for worker initialization before starting other workers initialization */
+	const struct _starpu_driver_ops *driver_ops;	/**< optional: Driver operations */
+	void *(*run_worker)(void *);	/**< Actually run the worker */
+	void (*init_worker_binding)(struct _starpu_machine_config *config, int no_mp_config STARPU_ATTRIBUTE_UNUSED, struct _starpu_worker *workerarg); /**< Setup worker CPU binding */
+	void (*init_worker_memory)(struct _starpu_machine_config *config, int no_mp_config STARPU_ATTRIBUTE_UNUSED, struct _starpu_worker *workerarg); /**< Setup worker memory node */
+#ifdef STARPU_HAVE_HWLOC
+	hwloc_obj_t (*get_hwloc_obj)(hwloc_topology_t topology, int devid);
+					/**< optional: Return the hwloc object corresponding to this device */
+#endif
+};
+
+/** Device driver information, indexed by enum starpu_worker_archtype */
+extern struct _starpu_driver_info starpu_driver_info[STARPU_NARCH];
+
+void _starpu_driver_info_register(enum starpu_worker_archtype archtype, const struct _starpu_driver_info *info);
+
+/** Provides information for a memory node driver */
+struct _starpu_memory_driver_info
+{
+	const char *name_upper;	/**< Name of memory in upper case */
+	enum starpu_worker_archtype worker_archtype;	/**< Kind of device */
+	const struct _starpu_node_ops *ops; /**< Memory node operations */
+};
+
+/** Memory driver information, indexed by enum starpu_node_kind */
+extern struct _starpu_memory_driver_info starpu_memory_driver_info[STARPU_MAX_RAM+1];
+
+void _starpu_memory_driver_info_register(enum starpu_node_kind kind, const struct _starpu_memory_driver_info *info);
+
 extern int _starpu_worker_parallel_blocks;
 
-extern struct _starpu_machine_config _starpu_config STARPU_ATTRIBUTE_INTERNAL;
-extern int _starpu_keys_initialized STARPU_ATTRIBUTE_INTERNAL;
-extern starpu_pthread_key_t _starpu_worker_key STARPU_ATTRIBUTE_INTERNAL;
-extern starpu_pthread_key_t _starpu_worker_set_key STARPU_ATTRIBUTE_INTERNAL;
+extern struct _starpu_machine_config _starpu_config;
+extern int _starpu_keys_initialized;
+extern starpu_pthread_key_t _starpu_worker_key;
+extern starpu_pthread_key_t _starpu_worker_set_key;
+
+void _starpu_set_catch_signals(int do_catch_signal);
 
 /** Three functions to manage argv, argc */
 void _starpu_set_argc_argv(int *argc, char ***argv);
@@ -471,11 +593,17 @@ static inline unsigned _starpu_machine_is_running(void)
 void _starpu_worker_init(struct _starpu_worker *workerarg, struct _starpu_machine_config *pconfig);
 
 /** Check if there is a worker that may execute the task. */
-uint32_t _starpu_worker_exists(struct starpu_task *);
+uint32_t _starpu_worker_exists(struct starpu_task *) STARPU_ATTRIBUTE_VISIBILITY_DEFAULT;
+
+/** Is there a worker that can execute MS code ? */
+uint32_t _starpu_can_submit_ms_task(void);
 
 /** Is there a worker that can execute CUDA code ? */
 uint32_t _starpu_can_submit_cuda_task(void);
 
+/** Is there a worker that can execute HIP code ? */
+uint32_t _starpu_can_submit_hip_task(void);
+
 /** Is there a worker that can execute CPU code ? */
 uint32_t _starpu_can_submit_cpu_task(void);
 
@@ -486,15 +614,10 @@ uint32_t _starpu_can_submit_opencl_task(void);
  * sleeping (waiting on something to happen). */
 unsigned _starpu_worker_can_block(unsigned memnode, struct _starpu_worker *worker);
 
-/** This function must be called to block a worker. It puts the worker in a
- * sleeping state until there is some event that forces the worker to wake up.
- * */
-void _starpu_block_worker(int workerid, starpu_pthread_cond_t *cond, starpu_pthread_mutex_t *mutex);
-
 /** This function initializes the current driver for the given worker */
-void _starpu_driver_start(struct _starpu_worker *worker, unsigned fut_key, unsigned sync);
+void _starpu_driver_start(struct _starpu_worker *worker, enum starpu_worker_archtype archtype, unsigned sync);
 /** This function initializes the current thread for the given worker */
-void _starpu_worker_start(struct _starpu_worker *worker, unsigned fut_key, unsigned sync);
+void _starpu_worker_start(struct _starpu_worker *worker, enum starpu_worker_archtype archtype, unsigned sync);
 
 static inline unsigned _starpu_worker_get_count(void)
 {
@@ -542,10 +665,18 @@ static inline struct _starpu_worker_set *_starpu_get_local_worker_set_key(void)
  * specified worker. */
 static inline struct _starpu_worker *_starpu_get_worker_struct(unsigned id)
 {
-	STARPU_ASSERT(id < starpu_worker_get_count());
+	STARPU_ASSERT(id < STARPU_NMAXWORKERS);
 	return &_starpu_config.workers[id];
 }
 
+/** Returns the _starpu_node structure that describes the state of the
+ * specified node. */
+static inline struct _starpu_node *_starpu_get_node_struct(unsigned id)
+{
+	STARPU_ASSERT(id < STARPU_MAXNODES);
+	return &_starpu_config.nodes[id];
+}
+
 /** Returns the starpu_sched_ctx structure that describes the state of the
  * specified ctx */
 static inline struct _starpu_sched_ctx *_starpu_get_sched_ctx_struct(unsigned id)
@@ -576,9 +707,22 @@ static inline enum _starpu_worker_status _starpu_worker_get_status(int workerid)
 
 /** Change the status of the worker which indicates what the worker is currently
  * doing (eg. executing a callback). */
-static inline void _starpu_worker_set_status(int workerid, enum _starpu_worker_status status)
+static inline void _starpu_worker_add_status(int workerid, enum _starpu_worker_status_index status)
 {
-	_starpu_config.workers[workerid].status = status;
+	STARPU_ASSERT(!(_starpu_config.workers[workerid].status & (1 << status)));
+	if (starpu_profiling_status_get())
+		_starpu_worker_start_state(workerid, status, NULL);
+	_starpu_config.workers[workerid].status |= (1 << status);
+}
+
+/** Change the status of the worker which indicates what the worker is currently
+ * doing (eg. executing a callback). */
+static inline void _starpu_worker_clear_status(int workerid, enum _starpu_worker_status_index status)
+{
+	STARPU_ASSERT((_starpu_config.workers[workerid].status & (1 << status)));
+	if (starpu_profiling_status_get())
+		_starpu_worker_stop_state(workerid, status, NULL);
+	_starpu_config.workers[workerid].status &= ~(1 << status);
 }
 
 /** We keep an initial sched ctx which might be used in case no other ctx is available */
@@ -587,11 +731,13 @@ static inline struct _starpu_sched_ctx* _starpu_get_initial_sched_ctx(void)
 	return &_starpu_config.sched_ctxs[STARPU_GLOBAL_SCHED_CTX];
 }
 
-int starpu_worker_get_nids_by_type(enum starpu_worker_archtype type, int *workerids, int maxsize);
+int _starpu_worker_get_nids_by_type(enum starpu_worker_archtype type, int *workerids, int maxsize);
 
-/** returns workers not belonging to any context, be careful no mutex is used,
-   the list might not be updated */
-int starpu_worker_get_nids_ctx_free_by_type(enum starpu_worker_archtype type, int *workerids, int maxsize);
+/**
+ * returns workers not belonging to any context, be careful no mutex is used,
+ * the list might not be updated
+ */
+int _starpu_worker_get_nids_ctx_free_by_type(enum starpu_worker_archtype type, int *workerids, int maxsize);
 
 static inline unsigned _starpu_worker_mutex_is_sched_mutex(int workerid, starpu_pthread_mutex_t *mutex)
 {
@@ -643,8 +789,6 @@ static inline unsigned __starpu_worker_get_id_check(const char *f, int l)
 }
 #define _starpu_worker_get_id_check(f,l) __starpu_worker_get_id_check(f,l)
 
-enum starpu_node_kind _starpu_worker_get_node_kind(enum starpu_worker_archtype type);
-
 void _starpu_worker_set_stream_ctx(unsigned workerid, struct _starpu_sched_ctx *sched_ctx);
 
 struct _starpu_sched_ctx* _starpu_worker_get_ctx_stream(unsigned stream_workerid);
@@ -709,7 +853,7 @@ static inline void _starpu_worker_request_unblocking_in_parallel(struct _starpu_
 	while (worker->state_block_in_parallel_req)
 		STARPU_PTHREAD_COND_WAIT(&worker->sched_cond, &worker->sched_mutex);
 
-	/* unblocking may be requested unconditionnally
+	/* unblocking may be requested unconditionally
 	 * thus, check is unblocking is really needed */
 	if (worker->state_blocked_in_parallel)
 	{
@@ -788,6 +932,10 @@ static inline void _starpu_worker_process_block_in_parallel_requests(struct _sta
 	}
 }
 
+#ifdef STARPU_SPINLOCK_CHECK
+#define _starpu_worker_enter_sched_op(worker) __starpu_worker_enter_sched_op((worker), __FILE__, __LINE__, __starpu_func__)
+static inline void __starpu_worker_enter_sched_op(struct _starpu_worker * const worker, const char*file, int line, const char* func)
+#else
 /** Mark the beginning of a scheduling operation by the worker. No worker
  * blocking operations on parallel tasks and no scheduling context change
  * operations must be performed on contexts containing the worker, on
@@ -804,9 +952,6 @@ static inline void _starpu_worker_process_block_in_parallel_requests(struct _sta
  *
  * Must be called with worker's sched_mutex held.
  */
-#ifdef STARPU_SPINLOCK_CHECK
-static inline void __starpu_worker_enter_sched_op(struct _starpu_worker * const worker, const char*file, int line, const char* func)
-#else
 static inline void _starpu_worker_enter_sched_op(struct _starpu_worker * const worker)
 #endif
 {
@@ -849,18 +994,17 @@ static inline void _starpu_worker_enter_sched_op(struct _starpu_worker * const w
 	worker->relax_on_func = func;
 #endif
 }
-#ifdef STARPU_SPINLOCK_CHECK
-#define _starpu_worker_enter_sched_op(worker) __starpu_worker_enter_sched_op((worker), __FILE__, __LINE__, __starpu_func__)
-#endif
 
+void _starpu_worker_apply_deferred_ctx_changes(void);
+
+#ifdef STARPU_SPINLOCK_CHECK
+#define _starpu_worker_leave_sched_op(worker) __starpu_worker_leave_sched_op((worker), __FILE__, __LINE__, __starpu_func__)
+static inline void __starpu_worker_leave_sched_op(struct _starpu_worker * const worker, const char*file, int line, const char* func)
+#else
 /** Mark the end of a scheduling operation by the worker.
  *
  * Must be called with worker's sched_mutex held.
  */
-void _starpu_worker_apply_deferred_ctx_changes(void);
-#ifdef STARPU_SPINLOCK_CHECK
-static inline void __starpu_worker_leave_sched_op(struct _starpu_worker * const worker, const char*file, int line, const char* func)
-#else
 static inline void _starpu_worker_leave_sched_op(struct _starpu_worker * const worker)
 #endif
 {
@@ -875,9 +1019,6 @@ static inline void _starpu_worker_leave_sched_op(struct _starpu_worker * const w
 	STARPU_PTHREAD_COND_BROADCAST(&worker->sched_cond);
 	_starpu_worker_apply_deferred_ctx_changes();
 }
-#ifdef STARPU_SPINLOCK_CHECK
-#define _starpu_worker_leave_sched_op(worker) __starpu_worker_leave_sched_op((worker), __FILE__, __LINE__, __starpu_func__)
-#endif
 
 static inline int _starpu_worker_sched_op_pending(void)
 {
@@ -931,7 +1072,7 @@ static inline void _starpu_worker_enter_changing_ctx_op(struct _starpu_worker *
 		}
 		while (worker->state_sched_op_pending);
 
-		/* reset flag so other sched_ops wont have to broadcast state */
+		/* reset flag so other sched_ops won't have to broadcast state */
 		worker->state_changing_ctx_waiting = 0;
 	}
 }
@@ -947,11 +1088,12 @@ static inline void _starpu_worker_leave_changing_ctx_op(struct _starpu_worker *
 	STARPU_PTHREAD_COND_BROADCAST(&worker->sched_cond);
 }
 
-/** Temporarily allow other worker to access current worker state, when still scheduling,
- * but the scheduling has not yet been made or is already done */
 #ifdef STARPU_SPINLOCK_CHECK
+#define _starpu_worker_relax_on() __starpu_worker_relax_on(__FILE__, __LINE__, __starpu_func__)
 static inline void __starpu_worker_relax_on(const char*file, int line, const char* func)
 #else
+/** Temporarily allow other worker to access current worker state, when still scheduling,
+ * but the scheduling has not yet been made or is already done */
 static inline void _starpu_worker_relax_on(void)
 #endif
 {
@@ -975,15 +1117,13 @@ static inline void _starpu_worker_relax_on(void)
 	STARPU_PTHREAD_COND_BROADCAST(&worker->sched_cond);
 	STARPU_PTHREAD_MUTEX_UNLOCK_SCHED(&worker->sched_mutex);
 }
-#ifdef STARPU_SPINLOCK_CHECK
-#define _starpu_worker_relax_on() __starpu_worker_relax_on(__FILE__, __LINE__, __starpu_func__)
-#endif
 #define starpu_worker_relax_on _starpu_worker_relax_on
 
-/** Same, but with current worker mutex already held */
 #ifdef STARPU_SPINLOCK_CHECK
+#define _starpu_worker_relax_on_locked(worker) __starpu_worker_relax_on_locked(worker,__FILE__, __LINE__, __starpu_func__)
 static inline void __starpu_worker_relax_on_locked(struct _starpu_worker *worker, const char*file, int line, const char* func)
 #else
+/** Same, but with current worker mutex already held */
 static inline void _starpu_worker_relax_on_locked(struct _starpu_worker *worker)
 #endif
 {
@@ -1002,11 +1142,9 @@ static inline void _starpu_worker_relax_on_locked(struct _starpu_worker *worker)
 #endif
 	STARPU_PTHREAD_COND_BROADCAST(&worker->sched_cond);
 }
-#ifdef STARPU_SPINLOCK_CHECK
-#define _starpu_worker_relax_on_locked(worker) __starpu_worker_relax_on_locked(worker,__FILE__, __LINE__, __starpu_func__)
-#endif
 
 #ifdef STARPU_SPINLOCK_CHECK
+#define _starpu_worker_relax_off() __starpu_worker_relax_off(__FILE__, __LINE__, __starpu_func__)
 static inline void __starpu_worker_relax_off(const char*file, int line, const char* func)
 #else
 static inline void _starpu_worker_relax_off(void)
@@ -1033,12 +1171,10 @@ static inline void _starpu_worker_relax_off(void)
 #endif
 	STARPU_PTHREAD_MUTEX_UNLOCK_SCHED(&worker->sched_mutex);
 }
-#ifdef STARPU_SPINLOCK_CHECK
-#define _starpu_worker_relax_off() __starpu_worker_relax_off(__FILE__, __LINE__, __starpu_func__)
-#endif
 #define starpu_worker_relax_off _starpu_worker_relax_off
 
 #ifdef STARPU_SPINLOCK_CHECK
+#define _starpu_worker_relax_off_locked() __starpu_worker_relax_off_locked(__FILE__, __LINE__, __starpu_func__)
 static inline void __starpu_worker_relax_off_locked(const char*file, int line, const char* func)
 #else
 static inline void _starpu_worker_relax_off_locked(void)
@@ -1063,9 +1199,6 @@ static inline void _starpu_worker_relax_off_locked(void)
 	worker->relax_off_func = func;
 #endif
 }
-#ifdef STARPU_SPINLOCK_CHECK
-#define _starpu_worker_relax_off_locked() __starpu_worker_relax_off_locked(__FILE__, __LINE__, __starpu_func__)
-#endif
 
 static inline int _starpu_worker_get_relax_state(void)
 {
@@ -1102,10 +1235,12 @@ static inline void _starpu_worker_lock(int workerid)
 		STARPU_PTHREAD_MUTEX_LOCK_SCHED(&worker->sched_mutex);
 	}
 }
+#define starpu_worker_lock _starpu_worker_lock
 
 static inline int _starpu_worker_trylock(int workerid)
 {
 	struct _starpu_worker *cur_worker = _starpu_get_local_worker_key();
+	STARPU_ASSERT(cur_worker != NULL);
 	int cur_workerid = cur_worker->workerid;
 	struct _starpu_worker *worker = _starpu_get_worker_struct(workerid);
 	STARPU_ASSERT(worker != NULL);
@@ -1132,6 +1267,7 @@ static inline int _starpu_worker_trylock(int workerid)
 	STARPU_PTHREAD_MUTEX_UNLOCK_SCHED(&cur_worker->sched_mutex);
 	return ret;
 }
+#define starpu_worker_trylock _starpu_worker_trylock
 
 static inline void _starpu_worker_unlock(int workerid)
 {
@@ -1144,6 +1280,7 @@ static inline void _starpu_worker_unlock(int workerid)
 		starpu_worker_relax_off();
 	}
 }
+#define starpu_worker_unlock _starpu_worker_unlock
 
 static inline void _starpu_worker_lock_self(void)
 {
@@ -1152,6 +1289,7 @@ static inline void _starpu_worker_lock_self(void)
 	STARPU_ASSERT(worker != NULL);
 	STARPU_PTHREAD_MUTEX_LOCK_SCHED(&worker->sched_mutex);
 }
+#define starpu_worker_lock_self _starpu_worker_lock_self
 
 static inline void _starpu_worker_unlock_self(void)
 {
@@ -1160,6 +1298,7 @@ static inline void _starpu_worker_unlock_self(void)
 	STARPU_ASSERT(worker != NULL);
 	STARPU_PTHREAD_MUTEX_UNLOCK_SCHED(&worker->sched_mutex);
 }
+#define starpu_worker_unlock_self _starpu_worker_unlock_self
 
 static inline int _starpu_wake_worker_relax(int workerid)
 {
@@ -1168,8 +1307,9 @@ static inline int _starpu_wake_worker_relax(int workerid)
 	_starpu_worker_unlock(workerid);
 	return ret;
 }
+#define starpu_wake_worker_relax _starpu_wake_worker_relax
 
-int starpu_wake_worker_relax_light(int workerid);
+int starpu_wake_worker_relax_light(int workerid) STARPU_ATTRIBUTE_VISIBILITY_DEFAULT;
 
 /**
  * Allow a worker pulling a task it cannot execute to properly refuse it and
@@ -1177,6 +1317,23 @@ int starpu_wake_worker_relax_light(int workerid);
  */
 void _starpu_worker_refuse_task(struct _starpu_worker *worker, struct starpu_task *task);
 
+void _starpu_set_catch_signals(int do_catch_signal);
+int _starpu_get_catch_signals(void);
+
+/** Performance Monitoring */
+static inline int _starpu_perf_counter_paused(void)
+{
+	STARPU_RMB();
+	return STARPU_UNLIKELY(_starpu_config.perf_counter_pause_depth > 0);
+}
+
+void _starpu_crash_add_hook(void (*hook_func)(void));
+void _starpu_crash_call_hooks();
+
+uint32_t _starpu_worker_exists(struct starpu_task *task);
+
 /* @}*/
 
+#pragma GCC visibility pop
+
 #endif // __WORKERS_H__
