@@ -1,7 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2008-2011,2014                           Université de Bordeaux
- * Copyright (C) 2010,2013,2015                           CNRS
+ * Copyright (C) 2008-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2021-2021  Federal University of Rio Grande do Sul (UFRGS)
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -18,6 +18,8 @@
 #ifndef __DATAWIZARD_H__
 #define __DATAWIZARD_H__
 
+/** @file */
+
 #include <starpu.h>
 #include <common/config.h>
 
@@ -33,7 +35,23 @@
 
 #include <core/dependencies/implicit_data_deps.h>
 
-int __starpu_datawizard_progress(unsigned memory_node, unsigned may_alloc, unsigned push_requests);
-void _starpu_datawizard_progress(unsigned memory_node, unsigned may_alloc);
+#pragma GCC visibility push(hidden)
+
+/** Make data transfers progress on all memory nodes driven by the current worker.
+ *
+ * If \p push_requests is 1, it can start new transfers
+ *
+ * If \p may_alloc is _STARPU_DATAWIZARD_DO_ALLOC, it can allocate destination data for transfers
+ * (this is not possible e.g. when spinning for a handle lock)
+ */
+int __starpu_datawizard_progress(enum _starpu_may_alloc may_alloc, unsigned push_requests);
+/** Call __starpu_datawizard_progress with push_requests = 1 */
+void _starpu_datawizard_progress(enum _starpu_may_alloc may_alloc);
+
+/* Only used at starpu_shutdown */
+/** Check for all pending data request progress on node \p memory_node */
+void _starpu_datawizard_handle_all_pending_node_data_requests(unsigned memnode);
+
+#pragma GCC visibility pop
 
 #endif // __DATAWIZARD_H__
