@@ -1,9 +1,9 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2008-2023  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2010       Mehdi Juhoor
- * Copyright (C) 2013       Thibaut Lambert
- * Copyright (C) 2021       Federal University of Rio Grande do Sul (UFRGS)
+ * Copyright (C) 2008-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2021-2021  Federal University of Rio Grande do Sul (UFRGS)
+ * Copyright (C) 2013-2013  Thibaut Lambert
+ * Copyright (C) 2010-2010  Mehdi Juhoor
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -488,7 +488,7 @@ void starpu_data_unpartition(starpu_data_handle_t root_handle, unsigned gatherin
 			 * whole data, it's not valid */
 			isvalid = 0;
 
-		if (!isvalid && local->mc && local->allocated && local->automatically_allocated)
+		if (!isvalid && local->mc && local->allocated && local->automatically_allocated && !local->refcnt)
 			/* free the data copy in a lazy fashion */
 			_starpu_request_mem_chunk_removal(root_handle, local, node, _starpu_data_get_alloc_size(root_handle));
 
