@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2024  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -985,6 +985,10 @@ static void _starpu_data_invalidate(void *data)
 	{
 		struct _starpu_data_replicate *local = &handle->per_node[node];
 
+		if (local->refcnt > 1)
+			/* Avoid freeing chunk still in use by others than this function */
+			continue;
+
 		if (local->mc && local->allocated && local->automatically_allocated)
 		{
 			unsigned mapping;
@@ -1008,7 +1012,7 @@ static void _starpu_data_invalidate(void *data)
 		{
 			struct _starpu_data_replicate *local = &handle->per_worker[worker];
 
-			if (local->mc && local->allocated && local->automatically_allocated)
+			if (local->mc && local->allocated && local->automatically_allocated && local->refcnt <= 1)
 				/* free the data copy in a lazy fashion */
 				_starpu_request_mem_chunk_removal(handle, local, starpu_worker_get_memory_node(worker), size);
 		}
