@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2008-2023  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2008-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  * Copyright (C) 2018,2021  Federal University of Rio Grande do Sul (UFRGS)
  *
  * StarPU is free software; you can redistribute it and/or modify
@@ -546,7 +546,8 @@ int starpu_data_can_evict(starpu_data_handle_t handle, unsigned node, enum starp
 			return 0;
 
 	/* This data cannot be pushed outside CPU memory */
-	if (!handle->ooc && starpu_node_get_kind(node) == STARPU_CPU_RAM
+	if (!handle->ooc && handle->home_node == -1
+		&& starpu_node_get_kind(node) == STARPU_CPU_RAM
 		&& starpu_memory_nodes_get_numa_count() == 1)
 		return 0;
 
@@ -585,12 +586,16 @@ static size_t try_to_throw_mem_chunk(struct _starpu_mem_chunk *mc, unsigned node
 	 * memchunk that could be used with filters. */
 	if (mc->relaxed_coherency == 1)
 	{
-		STARPU_ASSERT(mc->replicate);
-
 		if (_starpu_spin_trylock(&handle->header_lock))
 			/* Handle is busy, abort */
 			return 0;
 
+		if (!mc->replicate) {
+			/* _starpu_request_mem_chunk_removal removed it before us */
+			_starpu_spin_unlock(&handle->header_lock);
+			return 0;
+		}
+
 		if (mc->replicate->refcnt == 0)
 		{
 			/* Note that there is no need to transfer any data or
@@ -1066,7 +1071,7 @@ size_t _starpu_memory_reclaim_generic(unsigned node, unsigned force, size_t recl
 			{
 				char name[32];
 				starpu_memory_node_get_name(node, name, sizeof(name));
-				_STARPU_DISP("Not enough memory left on node %s. Your application data set seems too huge to fit on the device, StarPU will cope by trying to purge %lu MiB out. This message will not be printed again for further purges\n", name, (unsigned long) ((reclaim+1048575) / 1048576));
+				_STARPU_DISP("Not enough memory left on node %s. Your application data set seems too huge to fit on the device, StarPU will cope by trying to purge %lu MiB out. This message will not be printed again for further purges. You may want to tune the STARPU_MINIMUM_CLEAN_BUFFERS and STARPU_TARGET_CLEAN_BUFFERS environment variables up a bit to make StarPU maintain more clean memory available, to avoid ending up in this situation.\n", name, (unsigned long) ((reclaim+1048575) / 1048576));
 			}
 		}
 	}
@@ -1178,7 +1183,9 @@ void starpu_memchunk_tidy(unsigned node)
 			STARPU_ASSERT(handle);
 
 			/* This data cannot be pushed outside CPU memory */
-			if (!handle->ooc && starpu_node_get_kind(node) == STARPU_CPU_RAM)
+			if (!handle->ooc && handle->home_node == -1
+				&& starpu_node_get_kind(node) == STARPU_CPU_RAM
+				&& starpu_memory_nodes_get_numa_count() == 1)
 				continue;
 
 			if (_starpu_spin_trylock(&handle->header_lock))
@@ -1514,7 +1521,7 @@ static starpu_ssize_t _starpu_allocate_interface(starpu_data_handle_t handle, st
 
 	/* If this is RAM and pinned this will be slow
 	   In case we only want fast allocations return here */
-	if(only_fast_alloc && starpu_node_get_kind(dst_node) == STARPU_CPU_RAM && _starpu_malloc_willpin_on_node(dst_node))
+	if (only_fast_alloc && (starpu_node_get_kind(dst_node) != STARPU_CPU_RAM || _starpu_malloc_willpin_on_node(dst_node)))
 		return -ENOMEM;
 
 	STARPU_ASSERT(handle->ops);
@@ -1743,6 +1750,29 @@ void _starpu_memchunk_wont_use(struct _starpu_mem_chunk *mc, unsigned node)
 	_starpu_spin_unlock(&node_struct->mc_lock);
 }
 
+/* This memchunk content was dropped, and thus becomes clean */
+void _starpu_memchunk_clean(struct _starpu_mem_chunk *mc, unsigned node)
+{
+	if (!mc)
+		/* user-allocated memory */
+		return;
+	if (mc->home)
+		/* Home is always clean */
+		return;
+	STARPU_ASSERT(node < STARPU_MAXNODES);
+	if (!can_evict(node))
+		/* Don't bother */
+		return;
+	struct _starpu_node *node_struct = _starpu_get_node_struct(node);
+	_starpu_spin_lock(&node_struct->mc_lock);
+	if (!mc->clean)
+	{
+		node_struct->mc_clean_nb++;
+		mc->clean = 1;
+	}
+	_starpu_spin_unlock(&node_struct->mc_lock);
+}
+
 /* This memchunk is being written to, and thus becomes dirty */
 void _starpu_memchunk_dirty(struct _starpu_mem_chunk *mc, unsigned node)
 {
@@ -1877,8 +1907,10 @@ choose_target(starpu_data_handle_t handle, unsigned node)
 			unsigned nb_numa_nodes = starpu_memory_nodes_get_numa_count();
 			for (i=0; i<nb_numa_nodes; i++)
 			{
+				struct _starpu_node *node_struct = _starpu_get_node_struct(i);
 				if (handle->per_node[i].allocated ||
-				    _starpu_memory_manager_test_allocate_size(i, size_handle) == 1)
+				    (starpu_ssize_t) size_handle < node_struct->mc_cache_size ||
+				    _starpu_memory_manager_test_allocate_size(i, size_handle - node_struct->mc_cache_size) == 1)
 				{
 					target = i;
 					break;
@@ -1909,8 +1941,10 @@ choose_target(starpu_data_handle_t handle, unsigned node)
 			unsigned nb_numa_nodes = starpu_memory_nodes_get_numa_count();
 			for (i=0; i<nb_numa_nodes; i++)
 			{
+				struct _starpu_node *node_struct = _starpu_get_node_struct(i);
 				if (handle->per_node[i].allocated ||
-				    _starpu_memory_manager_test_allocate_size(i, size_handle) == 1)
+				    (starpu_ssize_t) size_handle < node_struct->mc_cache_size ||
+				    _starpu_memory_manager_test_allocate_size(i, size_handle - node_struct->mc_cache_size) == 1)
 				{
 					target = i;
 					break;
