@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -39,7 +39,7 @@ void _starpu_fxt_dag_init(char *out_path)
 	{
 		_STARPU_MSG("error while opening %s\n", out_path);
 		perror("fopen");
-		exit(1);
+		_exit(EXIT_FAILURE);
 	}
 	cluster_cnt = 0;
 
@@ -97,17 +97,42 @@ void _starpu_fxt_dag_add_task_deps(const char *prefix, unsigned long dep_prev, u
 	}
 }
 
-void _starpu_fxt_dag_set_tag_done(const char *prefix, uint64_t tag, const char *color)
+void _starpu_fxt_dag_set_tag_done(const char *prefix, uint64_t tag, const char *color, const char *fontcolor)
 {
 	if (out_file)
-		fprintf(out_file, "\t \"tag_%s%llx\" [ style=filled, fillcolor=\"%s\"]\n",
-			prefix, (unsigned long long)tag, color);
+		fprintf(out_file, "\t \"tag_%s%llx\" [ style=filled, fillcolor=\"%s\", fontcolor=\"%s\"]\n",
+			prefix, (unsigned long long)tag, color, fontcolor);
 }
 
-void _starpu_fxt_dag_set_task_name(const char *prefix, unsigned long job_id, const char *label, const char *color)
+void _starpu_fxt_dag_add_task_end_dep(const char *prefix, unsigned long prev, unsigned long succ)
 {
 	if (out_file)
-		fprintf(out_file, "\t \"task_%s%lu\" [ style=filled, label=\"%s\", fillcolor=\"%s\"]\n", prefix, job_id, label, color);
+		fprintf(out_file, "\t \"task_%s%lu\" [ end_dep=\"%lu\"]\n", prefix, prev, succ);
+}
+
+void _starpu_fxt_dag_set_task_name(const char *prefix, unsigned long job_id, const char *label, const char *color, const char *fontcolor)
+{
+	if (out_file)
+		fprintf(out_file, "\t \"task_%s%lu\" [ style=filled, label=\"%s\", fillcolor=\"%s\", fontcolor=\"%s\"]\n", prefix, job_id, label, color, fontcolor);
+}
+
+#ifdef STARPU_BUBBLE
+void _starpu_fxt_dag_set_task_bubble(const char *prefix, unsigned long job_id, int is_bubble, unsigned long bubble_parent)
+{
+	if (out_file)
+	{
+		fprintf(out_file, "\t \"task_%s%lu\" [ bubble=\"%d\" ", prefix, job_id, is_bubble);
+		if (bubble_parent)
+			fprintf(out_file, ", bubble_parent=\"%lu\"", bubble_parent);
+		fprintf(out_file, "]\n");
+	}
+}
+#endif
+
+void _starpu_fxt_dag_set_task_line(const char *prefix, unsigned long job_id, const char *file, int line)
+{
+	if (out_file)
+		fprintf(out_file, "\t \"task_%s%lu\" [ href=\"%s#%d\" ]\n", prefix, job_id, file, line);
 }
 
 void _starpu_fxt_dag_add_send(int src, unsigned long dep_prev, unsigned long tag, unsigned long id)
