@@ -1,12 +1,12 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2008-2023  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2010       Mehdi Juhoor
- * Copyright (C) 2011       Télécom-SudParis
- * Copyright (C) 2013       Thibaut Lambert
- * Copyright (C) 2016       Uppsala University
- * Copyright (C) 2021       Federal University of Rio Grande do Sul (UFRGS)
- * Copyright (C) 2022	    Camille Coti
+ * Copyright (C) 2008-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2022,2023  École de Technologie Supérieure (ETS, Montréal)
+ * Copyright (C) 2016-2016  Uppsala University
+ * Copyright (C) 2013-2013  Thibaut Lambert
+ * Copyright (C) 2011-2011  Télécom Sud Paris
+ * Copyright (C) 2010-2010  Mehdi Juhoor
+ * Copyright (C) 2021-2021  Federal University of Rio Grande do Sul (UFRGS)
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -77,9 +77,6 @@
 /* Consider a rough 10% overhead cost */
 #define FREE_MARGIN 0.9
 
-/* the number of CUDA devices */
-static int ncudagpus = -1;
-
 static size_t global_mem[STARPU_MAXCUDADEVS];
 #ifdef STARPU_HAVE_NVML_H
 static nvmlDevice_t nvmlDev[STARPU_MAXCUDADEVS];
@@ -91,7 +88,7 @@ __typeof__(nvmlDeviceGetHandleByPciBusId) *_starpu_nvmlDeviceGetHandleByPciBusId
 __typeof__(nvmlDeviceGetIndex) *_starpu_nvmlDeviceGetIndex;
 __typeof__(nvmlDeviceGetPciInfo) *_starpu_nvmlDeviceGetPciInfo;
 __typeof__(nvmlDeviceGetUUID) *_starpu_nvmlDeviceGetUUID;
-#ifdef HAVE_DECL_NVMLDEVICEGETTOTALENERGYCONSUMPTION
+#if HAVE_DECL_NVMLDEVICEGETTOTALENERGYCONSUMPTION
 __typeof__(nvmlDeviceGetTotalEnergyConsumption) *_starpu_nvmlDeviceGetTotalEnergyConsumption;
 #endif
 #endif
@@ -130,6 +127,8 @@ static unsigned cuda_memory_nodes[STARPU_MAXCUDADEVS];
 static int cuda_globalbindid;
 #endif
 
+static int _starpu_cuda_peer_access(int devid, int peer_devid);
+
 int _starpu_nworker_per_cuda;
 
 static size_t _starpu_cuda_get_global_mem_size(unsigned devid)
@@ -226,11 +225,6 @@ unsigned _starpu_get_cuda_device_count(void)
 /* This is run from initialize to determine the number of CUDA devices */
 void _starpu_init_cuda(void)
 {
-	if (ncudagpus < 0)
-	{
-		ncudagpus = _starpu_get_cuda_device_count();
-		STARPU_ASSERT(ncudagpus <= STARPU_MAXCUDADEVS);
-	}
 }
 
 /* This is called to really discover the hardware */
@@ -276,7 +270,7 @@ void _starpu_cuda_discover_devices(struct _starpu_machine_config *config)
 		if (!_starpu_nvmlDeviceGetPciInfo)
 			_starpu_nvmlDeviceGetPciInfo = dlsym(nvml, "nvmlDeviceGetPciInfo");
 		_starpu_nvmlDeviceGetUUID = dlsym(nvml, "nvmlDeviceGetUUID");
-#ifdef HAVE_DECL_NVMLDEVICEGETTOTALENERGYCONSUMPTION
+#if HAVE_DECL_NVMLDEVICEGETTOTALENERGYCONSUMPTION
 		_starpu_nvmlDeviceGetTotalEnergyConsumption = dlsym(nvml, "nvmlDeviceGetTotalEnergyConsumption");
 #endif
 		_starpu_nvmlInit();
@@ -425,7 +419,7 @@ void _starpu_init_cuda_config(struct _starpu_machine_topology *topology, struct
 	int nworker_per_cuda = starpu_getenv_number_default("STARPU_NWORKER_PER_CUDA", 1);
 
 	STARPU_ASSERT_MSG(nworker_per_cuda > 0, "STARPU_NWORKER_PER_CUDA has to be > 0");
-	STARPU_ASSERT_MSG(nworker_per_cuda < STARPU_NMAXWORKERS, "STARPU_NWORKER_PER_CUDA (%d) cannot be higher than STARPU_NMAXWORKERS (%d)\n", nworker_per_cuda, STARPU_NMAXWORKERS);
+	STARPU_ASSERT_MSG_ALWAYS(nworker_per_cuda < STARPU_NMAXWORKERS, "STARPU_NWORKER_PER_CUDA (%d) cannot be higher than STARPU_NMAXWORKERS (%d)\n", nworker_per_cuda, STARPU_NMAXWORKERS);
 
 #ifndef STARPU_NON_BLOCKING_DRIVERS
 	if (nworker_per_cuda > 1)
@@ -788,6 +782,8 @@ static void _starpu_cuda_limit_gpu_mem_if_needed(unsigned devid)
 /* Really initialize one device */
 static void init_device_context(unsigned devid, unsigned memnode)
 {
+	STARPU_ASSERT(devid < STARPU_MAXCUDADEVS);
+
 #ifndef STARPU_SIMGRID
 	cudaError_t cures;
 
@@ -820,7 +816,7 @@ static void init_device_context(unsigned devid, unsigned memnode)
 		for (workerid = 0; workerid < nworkers; workerid++)
 		{
 			struct _starpu_worker *worker = _starpu_get_worker_struct(workerid);
-			if (worker->arch == STARPU_CUDA_WORKER && worker->devid != devid)
+			if (worker->arch == STARPU_CUDA_WORKER && worker->subworkerid == 0 && worker->devid != devid)
 			{
 				int can;
 				cures = cudaDeviceCanAccessPeer(&can, devid, worker->devid);
@@ -874,12 +870,17 @@ static void init_device_context(unsigned devid, unsigned memnode)
 	if (STARPU_UNLIKELY(cures))
 		STARPU_CUDA_REPORT_ERROR(cures);
 
-	int i;
-	for (i = 0; i < ncudagpus; i++)
+	int nworkers = starpu_worker_get_count();
+	int workerid;
+	for (workerid = 0; workerid < nworkers; workerid++)
 	{
-		cures = starpu_cudaStreamCreate(&in_peer_transfer_streams[i][devid]);
-		if (STARPU_UNLIKELY(cures))
-			STARPU_CUDA_REPORT_ERROR(cures);
+		struct _starpu_worker *worker = _starpu_get_worker_struct(workerid);
+		if (worker->arch == STARPU_CUDA_WORKER && worker->subworkerid == 0)
+		{
+			cures = starpu_cudaStreamCreate(&in_peer_transfer_streams[worker->devid][devid]);
+			if (STARPU_UNLIKELY(cures))
+				STARPU_CUDA_REPORT_ERROR(cures);
+		}
 	}
 #endif /* !STARPU_SIMGRID */
 
@@ -896,15 +897,20 @@ static void init_device_context(unsigned devid, unsigned memnode)
 static void deinit_device_context(unsigned devid STARPU_ATTRIBUTE_UNUSED)
 {
 #ifndef STARPU_SIMGRID
-	int i;
 	starpu_cuda_set_device(devid);
 
 	cudaStreamDestroy(in_transfer_streams[devid]);
 	cudaStreamDestroy(out_transfer_streams[devid]);
 
-	for (i = 0; i < ncudagpus; i++)
+	int nworkers = starpu_worker_get_count();
+	int workerid;
+	for (workerid = 0; workerid < nworkers; workerid++)
 	{
-		cudaStreamDestroy(in_peer_transfer_streams[i][devid]);
+		struct _starpu_worker *worker = _starpu_get_worker_struct(workerid);
+		if (worker->arch == STARPU_CUDA_WORKER && worker->subworkerid == 0)
+		{
+			cudaStreamDestroy(in_peer_transfer_streams[worker->devid][devid]);
+		}
 	}
 #endif /* !STARPU_SIMGRID */
 }
@@ -967,7 +973,7 @@ nvmlDevice_t starpu_cuda_get_nvmldev(unsigned devid)
 #endif
 
 /* This is run from the driver thread to initialize the driver CUDA context */
-int _starpu_cuda_driver_init(struct _starpu_worker *worker)
+static int _starpu_cuda_driver_init(struct _starpu_worker *worker)
 {
 	struct _starpu_worker_set *worker_set = worker->set;
 	struct _starpu_worker *worker0 = &worker_set->workers[0];
@@ -1099,7 +1105,7 @@ int _starpu_cuda_driver_init(struct _starpu_worker *worker)
 	return 0;
 }
 
-int _starpu_cuda_driver_deinit(struct _starpu_worker *worker)
+static int _starpu_cuda_driver_deinit(struct _starpu_worker *worker)
 {
 	struct _starpu_worker_set *worker_set = worker->set;
 	int lastdevid = -1;
@@ -1161,7 +1167,7 @@ int _starpu_cuda_driver_deinit(struct _starpu_worker *worker)
 	return 0;
 }
 
-uintptr_t _starpu_cuda_malloc_on_node(unsigned dst_node, size_t size, int flags)
+static uintptr_t _starpu_cuda_malloc_on_node(unsigned dst_node, size_t size, int flags)
 {
 	uintptr_t addr = 0;
 	(void) flags;
@@ -1215,7 +1221,7 @@ uintptr_t _starpu_cuda_malloc_on_node(unsigned dst_node, size_t size, int flags)
 	return addr;
 }
 
-void _starpu_cuda_free_on_node(unsigned dst_node, uintptr_t addr, size_t size, int flags)
+static void _starpu_cuda_free_on_node(unsigned dst_node, uintptr_t addr, size_t size, int flags)
 {
 	(void) dst_node;
 	(void) addr;
@@ -1531,7 +1537,7 @@ static inline cudaEvent_t *_starpu_cuda_event(union _starpu_async_channel_event
 	return event;
 }
 
-unsigned _starpu_cuda_test_request_completion(struct _starpu_async_channel *async_channel)
+static unsigned _starpu_cuda_test_request_completion(struct _starpu_async_channel *async_channel)
 {
 	cudaEvent_t event;
 	cudaError_t cures;
@@ -1549,7 +1555,8 @@ unsigned _starpu_cuda_test_request_completion(struct _starpu_async_channel *asyn
 	return success;
 }
 
-void _starpu_cuda_wait_request_completion(struct _starpu_async_channel *async_channel)
+/* Only used at starpu_shutdown */
+static void _starpu_cuda_wait_request_completion(struct _starpu_async_channel *async_channel)
 {
 	cudaEvent_t event;
 	cudaError_t cures;
@@ -1586,7 +1593,7 @@ starpu_cuda_set_copy_device(unsigned src_node, unsigned dst_node)
 }
 #endif
 
-int _starpu_cuda_copy_interface_from_cuda_to_cuda(starpu_data_handle_t handle, void *src_interface, unsigned src_node, void *dst_interface, unsigned dst_node, struct _starpu_data_request *req)
+static int _starpu_cuda_copy_interface_from_cuda_to_cuda(starpu_data_handle_t handle, void *src_interface, unsigned src_node, void *dst_interface, unsigned dst_node, struct _starpu_data_request *req)
 {
 	int src_kind = starpu_node_get_kind(src_node);
 	int dst_kind = starpu_node_get_kind(dst_node);
@@ -1633,7 +1640,7 @@ int _starpu_cuda_copy_interface_from_cuda_to_cuda(starpu_data_handle_t handle, v
 	return ret;
 }
 
-int _starpu_cuda_copy_interface_from_cuda_to_cpu(starpu_data_handle_t handle, void *src_interface, unsigned src_node, void *dst_interface, unsigned dst_node, struct _starpu_data_request *req)
+static int _starpu_cuda_copy_interface_from_cuda_to_cpu(starpu_data_handle_t handle, void *src_interface, unsigned src_node, void *dst_interface, unsigned dst_node, struct _starpu_data_request *req)
 {
 	int src_kind = starpu_node_get_kind(src_node);
 	int dst_kind = starpu_node_get_kind(dst_node);
@@ -1682,7 +1689,7 @@ int _starpu_cuda_copy_interface_from_cuda_to_cpu(starpu_data_handle_t handle, vo
 	return ret;
 }
 
-int _starpu_cuda_copy_interface_from_cpu_to_cuda(starpu_data_handle_t handle, void *src_interface, unsigned src_node, void *dst_interface, unsigned dst_node, struct _starpu_data_request *req)
+static int _starpu_cuda_copy_interface_from_cpu_to_cuda(starpu_data_handle_t handle, void *src_interface, unsigned src_node, void *dst_interface, unsigned dst_node, struct _starpu_data_request *req)
 {
 	int src_kind = starpu_node_get_kind(src_node);
 	int dst_kind = starpu_node_get_kind(dst_node);
@@ -1735,7 +1742,7 @@ int _starpu_cuda_copy_interface_from_cpu_to_cuda(starpu_data_handle_t handle, vo
 	return ret;
 }
 
-int _starpu_cuda_copy_data_from_cuda_to_cpu(uintptr_t src, size_t src_offset, unsigned src_node, uintptr_t dst, size_t dst_offset, unsigned dst_node, size_t size, struct _starpu_async_channel *async_channel)
+static int _starpu_cuda_copy_data_from_cuda_to_cpu(uintptr_t src, size_t src_offset, unsigned src_node, uintptr_t dst, size_t dst_offset, unsigned dst_node, size_t size, struct _starpu_async_channel *async_channel)
 {
 	int src_kind = starpu_node_get_kind(src_node);
 	int dst_kind = starpu_node_get_kind(dst_node);
@@ -1749,7 +1756,7 @@ int _starpu_cuda_copy_data_from_cuda_to_cpu(uintptr_t src, size_t src_offset, un
 					   cudaMemcpyDeviceToHost);
 }
 
-int _starpu_cuda_copy_data_from_cuda_to_cuda(uintptr_t src, size_t src_offset, unsigned src_node, uintptr_t dst, size_t dst_offset, unsigned dst_node, size_t size, struct _starpu_async_channel *async_channel)
+static int _starpu_cuda_copy_data_from_cuda_to_cuda(uintptr_t src, size_t src_offset, unsigned src_node, uintptr_t dst, size_t dst_offset, unsigned dst_node, size_t size, struct _starpu_async_channel *async_channel)
 {
 	int src_kind = starpu_node_get_kind(src_node);
 	int dst_kind = starpu_node_get_kind(dst_node);
@@ -1766,7 +1773,7 @@ int _starpu_cuda_copy_data_from_cuda_to_cuda(uintptr_t src, size_t src_offset, u
 					   cudaMemcpyDeviceToDevice);
 }
 
-int _starpu_cuda_copy_data_from_cpu_to_cuda(uintptr_t src, size_t src_offset, unsigned src_node, uintptr_t dst, size_t dst_offset, unsigned dst_node, size_t size, struct _starpu_async_channel *async_channel)
+static int _starpu_cuda_copy_data_from_cpu_to_cuda(uintptr_t src, size_t src_offset, unsigned src_node, uintptr_t dst, size_t dst_offset, unsigned dst_node, size_t size, struct _starpu_async_channel *async_channel)
 {
 	int src_kind = starpu_node_get_kind(src_node);
 	int dst_kind = starpu_node_get_kind(dst_node);
@@ -1780,7 +1787,7 @@ int _starpu_cuda_copy_data_from_cpu_to_cuda(uintptr_t src, size_t src_offset, un
 					   cudaMemcpyHostToDevice);
 }
 
-int _starpu_cuda_copy2d_data_from_cuda_to_cpu(uintptr_t src, size_t src_offset, unsigned src_node,
+static int _starpu_cuda_copy2d_data_from_cuda_to_cpu(uintptr_t src, size_t src_offset, unsigned src_node,
 					      uintptr_t dst, size_t dst_offset, unsigned dst_node,
 					      size_t blocksize, size_t numblocks, size_t ld_src, size_t ld_dst,
 					      struct _starpu_async_channel *async_channel)
@@ -1797,7 +1804,7 @@ int _starpu_cuda_copy2d_data_from_cuda_to_cpu(uintptr_t src, size_t src_offset,
 					     cudaMemcpyDeviceToHost);
 }
 
-int _starpu_cuda_copy2d_data_from_cuda_to_cuda(uintptr_t src, size_t src_offset, unsigned src_node,
+static int _starpu_cuda_copy2d_data_from_cuda_to_cuda(uintptr_t src, size_t src_offset, unsigned src_node,
 					       uintptr_t dst, size_t dst_offset, unsigned dst_node,
 					       size_t blocksize, size_t numblocks, size_t ld_src, size_t ld_dst,
 					       struct _starpu_async_channel *async_channel)
@@ -1817,7 +1824,7 @@ int _starpu_cuda_copy2d_data_from_cuda_to_cuda(uintptr_t src, size_t src_offset,
 					     cudaMemcpyDeviceToDevice);
 }
 
-int _starpu_cuda_copy2d_data_from_cpu_to_cuda(uintptr_t src, size_t src_offset, unsigned src_node,
+static int _starpu_cuda_copy2d_data_from_cpu_to_cuda(uintptr_t src, size_t src_offset, unsigned src_node,
 					      uintptr_t dst, size_t dst_offset, unsigned dst_node,
 					      size_t blocksize, size_t numblocks, size_t ld_src, size_t ld_dst,
 					      struct _starpu_async_channel *async_channel)
@@ -1835,7 +1842,7 @@ int _starpu_cuda_copy2d_data_from_cpu_to_cuda(uintptr_t src, size_t src_offset,
 }
 
 #ifdef STARPU_USE_CUDA_MAP
-uintptr_t _starpu_cuda_map_ram(uintptr_t src_ptr STARPU_ATTRIBUTE_UNUSED, size_t src_offset, unsigned src_node STARPU_ATTRIBUTE_UNUSED,
+static uintptr_t _starpu_cuda_map_ram(uintptr_t src_ptr STARPU_ATTRIBUTE_UNUSED, size_t src_offset, unsigned src_node STARPU_ATTRIBUTE_UNUSED,
 			       unsigned dst_node STARPU_ATTRIBUTE_UNUSED,
 			       size_t size STARPU_ATTRIBUTE_UNUSED, int *ret STARPU_ATTRIBUTE_UNUSED)
 {
@@ -1956,7 +1963,7 @@ uintptr_t _starpu_cuda_map_ram(uintptr_t src_ptr STARPU_ATTRIBUTE_UNUSED, size_t
 	return dst_addr;
 }
 
-int _starpu_cuda_unmap_ram(uintptr_t src_ptr STARPU_ATTRIBUTE_UNUSED, size_t src_offset STARPU_ATTRIBUTE_UNUSED, unsigned src_node STARPU_ATTRIBUTE_UNUSED,
+static int _starpu_cuda_unmap_ram(uintptr_t src_ptr STARPU_ATTRIBUTE_UNUSED, size_t src_offset STARPU_ATTRIBUTE_UNUSED, unsigned src_node STARPU_ATTRIBUTE_UNUSED,
 			   uintptr_t dst_ptr STARPU_ATTRIBUTE_UNUSED, unsigned dst_node STARPU_ATTRIBUTE_UNUSED,
 			   size_t size STARPU_ATTRIBUTE_UNUSED)
 {
@@ -1968,7 +1975,7 @@ int _starpu_cuda_unmap_ram(uintptr_t src_ptr STARPU_ATTRIBUTE_UNUSED, size_t src
 #endif
 }
 
-int _starpu_cuda_update_map(uintptr_t src, size_t src_offset, unsigned src_node, uintptr_t dst, size_t dst_offset, unsigned dst_node, size_t size)
+static int _starpu_cuda_update_map(uintptr_t src, size_t src_offset, unsigned src_node, uintptr_t dst, size_t dst_offset, unsigned dst_node, size_t size)
 {
 	(void) src;
 	(void) src_offset;
@@ -1987,7 +1994,7 @@ int _starpu_cuda_update_map(uintptr_t src, size_t src_offset, unsigned src_node,
 
 #endif /* STARPU_USE_CUDA */
 
-int _starpu_cuda_is_direct_access_supported(unsigned node, unsigned handling_node)
+static int _starpu_cuda_is_direct_access_supported(unsigned node, unsigned handling_node)
 {
 	/* GPUs not always allow direct remote access: if CUDA4
 	 * is enabled, we allow two CUDA devices to communicate. */
@@ -2196,7 +2203,7 @@ static void finish_job_on_cuda(struct _starpu_job *j, struct _starpu_worker *wor
 }
 
 /* One iteration of the main driver loop */
-int _starpu_cuda_driver_run_once(struct _starpu_worker *worker)
+static int _starpu_cuda_driver_run_once(struct _starpu_worker *worker)
 {
 	struct _starpu_worker_set *worker_set = worker->set;
 	struct _starpu_worker *worker0 = &worker_set->workers[0];
@@ -2540,7 +2547,7 @@ void starpu_cusolver_report_error(const char *func, const char *file, int line,
 
 #endif /* STARPU_USE_CUDA */
 
-int _starpu_cuda_run_from_worker(struct _starpu_worker *worker)
+static int _starpu_cuda_run_from_worker(struct _starpu_worker *worker)
 {
 	/* Let's go ! */
 	_starpu_cuda_worker(worker);
@@ -2548,13 +2555,13 @@ int _starpu_cuda_run_from_worker(struct _starpu_worker *worker)
 	return 0;
 }
 
-int _starpu_cuda_driver_set_devid(struct starpu_driver *driver, struct _starpu_worker *worker)
+static int _starpu_cuda_driver_set_devid(struct starpu_driver *driver, struct _starpu_worker *worker)
 {
 	driver->id.cuda_id = worker->devid;
 	return 0;
 }
 
-int _starpu_cuda_driver_is_devid(struct starpu_driver *driver, struct _starpu_worker *worker)
+static int _starpu_cuda_driver_is_devid(struct starpu_driver *driver, struct _starpu_worker *worker)
 {
 	return driver->id.cuda_id == worker->devid;
 }
