@@ -1,11 +1,11 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2008-2024  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2010       Mehdi Juhoor
- * Copyright (C) 2011       Télécom-SudParis
- * Copyright (C) 2013       Thibaut Lambert
- * Copyright (C) 2016       Uppsala University
- * Copyright (C) 2021       Federal University of Rio Grande do Sul (UFRGS)
+ * Copyright (C) 2008-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2021-2021  Federal University of Rio Grande do Sul (UFRGS)
+ * Copyright (C) 2016-2016  Uppsala University
+ * Copyright (C) 2013-2013  Thibaut Lambert
+ * Copyright (C) 2011-2011  Télécom Sud Paris
+ * Copyright (C) 2010-2010  Mehdi Juhoor
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -53,9 +53,6 @@
 /* Consider a rough 10% overhead cost */
 #define FREE_MARGIN 0.9
 
-/* the number of CUDA devices */
-static int ncudagpus = -1;
-
 static size_t global_mem[STARPU_MAXCUDADEVS];
 int _starpu_cuda_bus_ids[STARPU_MAXCUDADEVS+STARPU_MAXNUMANODES][STARPU_MAXCUDADEVS+STARPU_MAXNUMANODES];
 /* Note: streams are not thread-safe, so we define them for each CUDA worker
@@ -97,7 +94,7 @@ void _starpu_cuda_init(void)
 /* Return the number of devices usable in the system.
  * The value returned cannot be greater than MAXCUDADEVS */
 
-unsigned _starpu_get_cuda_device_count(void)
+static unsigned _starpu_get_cuda_device_count(void)
 {
 	int cnt;
 	cudaError_t cures;
@@ -116,11 +113,6 @@ unsigned _starpu_get_cuda_device_count(void)
 /* This is run from initialize to determine the number of CUDA devices */
 void _starpu_init_cuda(void)
 {
-	if (ncudagpus < 0)
-	{
-		ncudagpus = _starpu_get_cuda_device_count();
-		STARPU_ASSERT(ncudagpus <= STARPU_MAXCUDADEVS);
-	}
 }
 
 /* This is called to return the real (non-clamped) number of devices */
@@ -279,6 +271,8 @@ static void _starpu_cuda_limit_gpu_mem_if_needed(unsigned devid)
 /* Really initialize one device */
 static void init_device_context(unsigned devid, unsigned memnode)
 {
+	STARPU_ASSERT(devid < STARPU_MAXCUDADEVS);
+
 	cudaError_t cures;
 
 	starpu_cuda_set_device(devid);
@@ -309,7 +303,7 @@ static void deinit_device_context(unsigned devid STARPU_ATTRIBUTE_UNUSED)
 }
 
 /* This is run from the driver thread to initialize the driver CUDA context */
-int _starpu_cuda_driver_init(struct _starpu_worker *worker)
+static int _starpu_cuda_driver_init(struct _starpu_worker *worker)
 {
 	_starpu_driver_start(worker, STARPU_CUDA_WORKER, 0);
 	_starpu_set_local_worker_key(worker);
@@ -349,7 +343,7 @@ int _starpu_cuda_driver_init(struct _starpu_worker *worker)
 	return 0;
 }
 
-int _starpu_cuda_driver_deinit(struct _starpu_worker *worker)
+static int _starpu_cuda_driver_deinit(struct _starpu_worker *worker)
 {
 	_STARPU_TRACE_WORKER_DEINIT_START;
 
@@ -374,7 +368,7 @@ int _starpu_cuda_driver_deinit(struct _starpu_worker *worker)
 	return 0;
 }
 
-uintptr_t _starpu_cuda_malloc_on_node(unsigned dst_node, size_t size, int flags)
+static uintptr_t _starpu_cuda_malloc_on_node(unsigned dst_node, size_t size, int flags)
 {
 	uintptr_t addr = 0;
 	(void) flags;
@@ -404,7 +398,7 @@ uintptr_t _starpu_cuda_malloc_on_node(unsigned dst_node, size_t size, int flags)
 	return addr;
 }
 
-void _starpu_cuda_free_on_node(unsigned dst_node, uintptr_t addr, size_t size, int flags)
+static void _starpu_cuda_free_on_node(unsigned dst_node, uintptr_t addr, size_t size, int flags)
 {
 	(void) dst_node;
 	(void) addr;
@@ -468,7 +462,7 @@ starpu_cuda_copy2d_async_sync(void *src_ptr, unsigned src_node,
 	return 0;
 }
 
-int _starpu_cuda_copy_interface(starpu_data_handle_t handle, void *src_interface, unsigned src_node, void *dst_interface, unsigned dst_node, struct _starpu_data_request *req)
+static int _starpu_cuda_copy_interface(starpu_data_handle_t handle, void *src_interface, unsigned src_node, void *dst_interface, unsigned dst_node, struct _starpu_data_request *req)
 {
 	(void) req;
 
@@ -480,7 +474,7 @@ int _starpu_cuda_copy_interface(starpu_data_handle_t handle, void *src_interface
 	return ret;
 }
 
-int _starpu_cuda_copy_data_from_cuda_to_cpu(uintptr_t src, size_t src_offset, unsigned src_node, uintptr_t dst, size_t dst_offset, unsigned dst_node, size_t size, struct _starpu_async_channel *async_channel STARPU_ATTRIBUTE_UNUSED)
+static int _starpu_cuda_copy_data_from_cuda_to_cpu(uintptr_t src, size_t src_offset, unsigned src_node, uintptr_t dst, size_t dst_offset, unsigned dst_node, size_t size, struct _starpu_async_channel *async_channel STARPU_ATTRIBUTE_UNUSED)
 {
 	int src_kind = starpu_node_get_kind(src_node);
 	int dst_kind = starpu_node_get_kind(dst_node);
@@ -494,7 +488,7 @@ int _starpu_cuda_copy_data_from_cuda_to_cpu(uintptr_t src, size_t src_offset, un
 					   cudaMemcpyDeviceToHost);
 }
 
-int _starpu_cuda_copy_data_from_cuda_to_cuda(uintptr_t src, size_t src_offset, unsigned src_node, uintptr_t dst, size_t dst_offset, unsigned dst_node, size_t size, struct _starpu_async_channel *async_channel STARPU_ATTRIBUTE_UNUSED)
+static int _starpu_cuda_copy_data_from_cuda_to_cuda(uintptr_t src, size_t src_offset, unsigned src_node, uintptr_t dst, size_t dst_offset, unsigned dst_node, size_t size, struct _starpu_async_channel *async_channel STARPU_ATTRIBUTE_UNUSED)
 {
 	int src_kind = starpu_node_get_kind(src_node);
 	int dst_kind = starpu_node_get_kind(dst_node);
@@ -511,7 +505,7 @@ int _starpu_cuda_copy_data_from_cuda_to_cuda(uintptr_t src, size_t src_offset, u
 					   cudaMemcpyDeviceToDevice);
 }
 
-int _starpu_cuda_copy_data_from_cpu_to_cuda(uintptr_t src, size_t src_offset, unsigned src_node, uintptr_t dst, size_t dst_offset, unsigned dst_node, size_t size, struct _starpu_async_channel *async_channel STARPU_ATTRIBUTE_UNUSED)
+static int _starpu_cuda_copy_data_from_cpu_to_cuda(uintptr_t src, size_t src_offset, unsigned src_node, uintptr_t dst, size_t dst_offset, unsigned dst_node, size_t size, struct _starpu_async_channel *async_channel STARPU_ATTRIBUTE_UNUSED)
 {
 	int src_kind = starpu_node_get_kind(src_node);
 	int dst_kind = starpu_node_get_kind(dst_node);
@@ -526,7 +520,7 @@ int _starpu_cuda_copy_data_from_cpu_to_cuda(uintptr_t src, size_t src_offset, un
 }
 
 /* Driver porters: these are optional but really recommended */
-int _starpu_cuda_copy2d_data_from_cuda_to_cpu(uintptr_t src, size_t src_offset, unsigned src_node,
+static int _starpu_cuda_copy2d_data_from_cuda_to_cpu(uintptr_t src, size_t src_offset, unsigned src_node,
 					      uintptr_t dst, size_t dst_offset, unsigned dst_node,
 					      size_t blocksize, size_t numblocks, size_t ld_src, size_t ld_dst,
 					      struct _starpu_async_channel *async_channel STARPU_ATTRIBUTE_UNUSED)
@@ -543,7 +537,7 @@ int _starpu_cuda_copy2d_data_from_cuda_to_cpu(uintptr_t src, size_t src_offset,
 					   cudaMemcpyDeviceToHost);
 }
 
-int _starpu_cuda_copy2d_data_from_cuda_to_cuda(uintptr_t src, size_t src_offset, unsigned src_node,
+static int _starpu_cuda_copy2d_data_from_cuda_to_cuda(uintptr_t src, size_t src_offset, unsigned src_node,
 					       uintptr_t dst, size_t dst_offset, unsigned dst_node,
 					       size_t blocksize, size_t numblocks, size_t ld_src, size_t ld_dst,
 					       struct _starpu_async_channel *async_channel STARPU_ATTRIBUTE_UNUSED)
@@ -563,7 +557,7 @@ int _starpu_cuda_copy2d_data_from_cuda_to_cuda(uintptr_t src, size_t src_offset,
 					   cudaMemcpyDeviceToDevice);
 }
 
-int _starpu_cuda_copy2d_data_from_cpu_to_cuda(uintptr_t src, size_t src_offset, unsigned src_node,
+static int _starpu_cuda_copy2d_data_from_cpu_to_cuda(uintptr_t src, size_t src_offset, unsigned src_node,
 					      uintptr_t dst, size_t dst_offset, unsigned dst_node,
 					      size_t blocksize, size_t numblocks, size_t ld_src, size_t ld_dst,
 					      struct _starpu_async_channel *async_channel STARPU_ATTRIBUTE_UNUSED)
@@ -580,7 +574,7 @@ int _starpu_cuda_copy2d_data_from_cpu_to_cuda(uintptr_t src, size_t src_offset,
 					   cudaMemcpyHostToDevice);
 }
 
-int _starpu_cuda_is_direct_access_supported(unsigned node, unsigned handling_node)
+static int _starpu_cuda_is_direct_access_supported(unsigned node, unsigned handling_node)
 {
 	/* Direct GPU-GPU transfers are not allowed in general */
 	(void) node;
@@ -673,7 +667,7 @@ static void finish_job_on_cuda(struct _starpu_job *j, struct _starpu_worker *wor
 }
 
 /* One iteration of the main driver loop */
-int _starpu_cuda_driver_run_once(struct _starpu_worker *worker)
+static int _starpu_cuda_driver_run_once(struct _starpu_worker *worker)
 {
 	struct starpu_task *task;
 	struct _starpu_job *j;
@@ -823,7 +817,7 @@ void starpu_cusolver_report_error(const char *func, const char *file, int line,
 }
 #endif
 
-int _starpu_cuda_run_from_worker(struct _starpu_worker *worker)
+static int _starpu_cuda_run_from_worker(struct _starpu_worker *worker)
 {
 	/* Let's go ! */
 	_starpu_cuda_worker(worker);
