@@ -1,8 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2013                                     Inria
- * Copyright (C) 2014-2015,2017                           CNRS
- * Copyright (C) 2014-2015,2017-2018                      Université de Bordeaux
+ * Copyright (C) 2013-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -48,6 +46,7 @@ static int perfmodel_select_push_task(struct starpu_sched_component * component,
 		if(isnan(length))
 		{
 			static int warned;
+			STARPU_HG_DISABLE_CHECKING(warned);
 			if (!warned)
 			{
 				warned = 1;
@@ -90,11 +89,13 @@ struct starpu_sched_component * starpu_sched_component_perfmodel_select_create(s
 
 	struct _starpu_perfmodel_select_data *data;
 	_STARPU_MALLOC(data, sizeof(*data));
+
 	data->calibrator_component = params->calibrator_component;
 	data->no_perfmodel_component = params->no_perfmodel_component;
 	data->perfmodel_component = params->perfmodel_component;
 
 	component->data = data;
+	component->can_pull = starpu_sched_component_send_can_push_to_parents;
 	component->push_task = perfmodel_select_push_task;
 	component->pull_task = perfmodel_select_pull_task;
 	component->deinit_data = perfmodel_select_component_deinit_data;
