@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2016-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2016-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -27,9 +27,11 @@ static const intptr_t fstarpu_w	= STARPU_W;
 static const intptr_t fstarpu_rw	= STARPU_RW;
 static const intptr_t fstarpu_scratch	= STARPU_SCRATCH;
 static const intptr_t fstarpu_redux	= STARPU_REDUX;
+static const intptr_t fstarpu_mpi_redux	= STARPU_MPI_REDUX;
 static const intptr_t fstarpu_commute	= STARPU_COMMUTE;
 static const intptr_t fstarpu_ssend	= STARPU_SSEND;
 static const intptr_t fstarpu_locality	= STARPU_LOCALITY;
+static const intptr_t fstarpu_nofootprint	= STARPU_NOFOOTPRINT;
 
 static const intptr_t fstarpu_data_array	= STARPU_DATA_ARRAY;
 static const intptr_t fstarpu_data_mode_array	= STARPU_DATA_MODE_ARRAY;
@@ -70,6 +72,8 @@ static const intptr_t fstarpu_sequential_consistency = STARPU_SEQUENTIAL_CONSIST
 static const intptr_t fstarpu_task_profiling_info = STARPU_TASK_PROFILING_INFO;
 static const intptr_t fstarpu_task_no_submitorder = STARPU_TASK_NO_SUBMITORDER;
 static const intptr_t fstarpu_task_sched_data = STARPU_TASK_SCHED_DATA;
+static const intptr_t fstarpu_task_file = STARPU_TASK_FILE;
+static const intptr_t fstarpu_task_line = STARPU_TASK_LINE;
 
 static const intptr_t fstarpu_value = STARPU_VALUE;
 static const intptr_t fstarpu_sched_ctx = STARPU_SCHED_CTX;
@@ -77,8 +81,8 @@ static const intptr_t fstarpu_sched_ctx = STARPU_SCHED_CTX;
 static const intptr_t fstarpu_cpu_worker = STARPU_CPU_WORKER;
 static const intptr_t fstarpu_cuda_worker = STARPU_CUDA_WORKER;
 static const intptr_t fstarpu_opencl_worker = STARPU_OPENCL_WORKER;
-static const intptr_t fstarpu_mic_worker = STARPU_MIC_WORKER;
 static const intptr_t fstarpu_any_worker = STARPU_ANY_WORKER;
+static const intptr_t fstarpu_narch = STARPU_NARCH;
 
 static const intptr_t fstarpu_nmaxbufs = STARPU_NMAXBUFS;
 
@@ -96,7 +100,6 @@ static const intptr_t fstarpu_starpu_nowhere	= STARPU_NOWHERE;
 static const intptr_t fstarpu_starpu_cpu	= STARPU_CPU;
 static const intptr_t fstarpu_starpu_cuda	= STARPU_CUDA;
 static const intptr_t fstarpu_starpu_opencl	= STARPU_OPENCL;
-static const intptr_t fstarpu_starpu_mic	= STARPU_MIC;
 
 static const intptr_t fstarpu_starpu_codelet_simgrid_execute	= STARPU_CODELET_SIMGRID_EXECUTE;
 static const intptr_t fstarpu_starpu_codelet_simgrid_execute_and_inject	= STARPU_CODELET_SIMGRID_EXECUTE_AND_INJECT;
@@ -111,6 +114,12 @@ static const intptr_t fstarpu_regression_based	= STARPU_REGRESSION_BASED;
 static const intptr_t fstarpu_nl_regression_based	= STARPU_NL_REGRESSION_BASED;
 static const intptr_t fstarpu_multiple_regression_based	= STARPU_MULTIPLE_REGRESSION_BASED;
 
+static const intptr_t fstarpu_seq	= STARPU_SEQ;
+static const intptr_t fstarpu_spmd	= STARPU_SPMD;
+static const intptr_t fstarpu_forkjoin	= STARPU_FORKJOIN;
+
+static const intptr_t fstarpu_default_prio	= STARPU_DEFAULT_PRIO;
+
 intptr_t fstarpu_get_constant(char *s)
 {
 	if	(!strcmp(s, "FSTARPU_R"))	{ return fstarpu_r; }
@@ -118,9 +127,11 @@ intptr_t fstarpu_get_constant(char *s)
 	else if	(!strcmp(s, "FSTARPU_RW"))	{ return fstarpu_rw; }
 	else if	(!strcmp(s, "FSTARPU_SCRATCH"))	{ return fstarpu_scratch; }
 	else if	(!strcmp(s, "FSTARPU_REDUX"))	{ return fstarpu_redux; }
+	else if	(!strcmp(s, "FSTARPU_MPI_REDUX"))	{ return fstarpu_mpi_redux; }
 	else if	(!strcmp(s, "FSTARPU_COMMUTE"))	{ return fstarpu_commute; }
 	else if	(!strcmp(s, "FSTARPU_SSEND"))	{ return fstarpu_ssend; }
 	else if	(!strcmp(s, "FSTARPU_LOCALITY"))	{ return fstarpu_locality; }
+	else if	(!strcmp(s, "FSTARPU_NOFOOTPRINT"))	{ return fstarpu_nofootprint; }
 
 
 	else if	(!strcmp(s, "FSTARPU_DATA_ARRAY"))	{ return fstarpu_data_array; }
@@ -164,12 +175,14 @@ intptr_t fstarpu_get_constant(char *s)
 	else if (!strcmp(s, "FSTARPU_TASK_PROFILING_INFO"))	{ return fstarpu_task_profiling_info; }
 	else if (!strcmp(s, "FSTARPU_TASK_NO_SUBMITORDER"))	{ return fstarpu_task_no_submitorder; }
 	else if	(!strcmp(s, "FSTARPU_TASK_SCHED_DATA"))	{ return fstarpu_task_sched_data; }
+	else if	(!strcmp(s, "FSTARPU_TASK_FILE"))	{ return fstarpu_task_file; }
+	else if	(!strcmp(s, "FSTARPU_TASK_LINE"))	{ return fstarpu_task_line; }
 
 	else if (!strcmp(s, "FSTARPU_CPU_WORKER"))	{ return fstarpu_cpu_worker; }
 	else if (!strcmp(s, "FSTARPU_CUDA_WORKER"))	{ return fstarpu_cuda_worker; }
 	else if (!strcmp(s, "FSTARPU_OPENCL_WORKER"))	{ return fstarpu_opencl_worker; }
-	else if (!strcmp(s, "FSTARPU_MIC_WORKER"))	{ return fstarpu_mic_worker; }
 	else if (!strcmp(s, "FSTARPU_ANY_WORKER"))	{ return fstarpu_any_worker; }
+	else if (!strcmp(s, "FSTARPU_NARCH"))	{ return fstarpu_narch; }
 
 	else if (!strcmp(s, "FSTARPU_NMAXBUFS"))	{ return fstarpu_nmaxbufs; }
 
@@ -187,7 +200,6 @@ intptr_t fstarpu_get_constant(char *s)
 	else if (!strcmp(s, "FSTARPU_CPU"))	{ return fstarpu_starpu_cpu; }
 	else if (!strcmp(s, "FSTARPU_CUDA"))	{ return fstarpu_starpu_cuda; }
 	else if (!strcmp(s, "FSTARPU_OPENCL"))	{ return fstarpu_starpu_opencl; }
-	else if (!strcmp(s, "FSTARPU_MIC"))	{ return fstarpu_starpu_mic; }
 
 	else if (!strcmp(s, "FSTARPU_CODELET_SIMGRID_EXECUTE"))	{ return fstarpu_starpu_codelet_simgrid_execute; }
 	else if (!strcmp(s, "FSTARPU_CODELET_SIMGRID_EXECUTE_AND_INJECT"))	{ return fstarpu_starpu_codelet_simgrid_execute_and_inject; }
@@ -202,9 +214,17 @@ intptr_t fstarpu_get_constant(char *s)
 	else if (!strcmp(s, "FSTARPU_NL_REGRESSION_BASED"))	{ return fstarpu_nl_regression_based; }
 	else if (!strcmp(s, "FSTARPU_MULTIPLE_REGRESSION_BASED"))	{ return fstarpu_multiple_regression_based; }
 
+	else if (!strcmp(s, "FSTARPU_SEQ"))	{ return fstarpu_seq; }
+	else if (!strcmp(s, "FSTARPU_SPMD"))	{ return fstarpu_spmd; }
+	else if (!strcmp(s, "FSTARPU_FORKJOIN"))	{ return fstarpu_forkjoin; }
+
+	else if (!strcmp(s, "FSTARPU_DEFAULT_PRIO"))	{ return fstarpu_default_prio; }
+
 	else { _STARPU_ERROR("unknown constant"); }
+	return -1;
 }
 
+STARPU_ATTRIBUTE_MALLOC
 struct starpu_conf *fstarpu_conf_allocate(void)
 {
 	struct starpu_conf *conf;
@@ -252,12 +272,6 @@ void fstarpu_conf_set_nopencl(struct starpu_conf *conf, int nopencl)
 	conf->nopencl = nopencl;
 }
 
-void fstarpu_conf_set_nmic(struct starpu_conf *conf, int nmic)
-{
-	STARPU_ASSERT(nmic >= 0 && nmic <= STARPU_NMAXWORKERS);
-	conf->nmic = nmic;
-}
-
 void fstarpu_conf_set_calibrate(struct starpu_conf *conf, int calibrate)
 {
 	STARPU_ASSERT(calibrate == 0 || calibrate == 1);
@@ -275,6 +289,7 @@ void fstarpu_topology_print(void)
 	starpu_topology_print(stderr);
 }
 
+STARPU_ATTRIBUTE_MALLOC
 struct starpu_codelet *fstarpu_codelet_allocate(void)
 {
 	struct starpu_codelet *cl;
@@ -294,6 +309,12 @@ void fstarpu_codelet_set_name(struct starpu_codelet *cl, const char *cl_name)
 	cl->name = cl_name;
 }
 
+void fstarpu_codelet_set_color(struct starpu_codelet *cl, int cl_color)
+{
+	STARPU_ASSERT(cl_color >= 0);
+	cl->color = (unsigned)cl_color;
+}
+
 void fstarpu_codelet_set_model(struct starpu_codelet *cl, struct starpu_perfmodel *cl_perfmodel)
 {
 	cl->model = cl_perfmodel;
@@ -379,21 +400,6 @@ void fstarpu_codelet_add_opencl_flags(struct starpu_codelet *cl, intptr_t flags)
 	_STARPU_ERROR("fstarpu: too many opencl flags in Fortran codelet");
 }
 
-void fstarpu_codelet_add_mic_func(struct starpu_codelet *cl, void *f_ptr)
-{
-	const size_t max_mic_funcs = sizeof(cl->mic_funcs)/sizeof(cl->mic_funcs[0])-1;
-	unsigned i;
-	for (i = 0; i < max_mic_funcs; i++)
-	{
-		if (cl->mic_funcs[i] == NULL)
-		{
-			cl->mic_funcs[i] = f_ptr;
-			return;
-		}
-	}
-	_STARPU_ERROR("fstarpu: too many mic functions in Fortran codelet");
-}
-
 void fstarpu_codelet_add_buffer(struct starpu_codelet *cl, intptr_t _mode)
 {
 
@@ -442,6 +448,24 @@ void fstarpu_codelet_set_where(struct starpu_codelet *cl, intptr_t where)
 	cl->where = (uint32_t)where;
 }
 
+void fstarpu_codelet_set_type(struct starpu_codelet *cl, intptr_t type_constant)
+{
+	STARPU_ASSERT(type_constant == STARPU_SEQ || type_constant == STARPU_SPMD || type_constant == STARPU_FORKJOIN);
+	cl->type = (int)type_constant;
+}
+
+void fstarpu_codelet_set_max_parallelism(struct starpu_codelet *cl, int max_parallelism)
+{
+	if (max_parallelism >= 1)
+	{
+		cl->max_parallelism = max_parallelism;
+	}
+	else
+	{
+		_STARPU_ERROR("fstarpu: invalid max_parallelism parameter");
+	}
+}
+
 STARPU_ATTRIBUTE_MALLOC
 struct starpu_perfmodel *fstarpu_perfmodel_allocate(void)
 {
@@ -600,6 +624,7 @@ void fstarpu_worker_get_type_as_string(intptr_t type, char *dst, size_t maxlen)
 	snprintf(dst, maxlen, "%s", str);
 }
 
+STARPU_ATTRIBUTE_MALLOC
 starpu_data_handle_t *fstarpu_data_handle_array_alloc(int nb)
 {
 	void *ptr;
@@ -617,6 +642,7 @@ void fstarpu_data_handle_array_set(starpu_data_handle_t *handles, int i, starpu_
 	handles[i] = handle;
 }
 
+STARPU_ATTRIBUTE_MALLOC
 struct starpu_data_descr *fstarpu_data_descr_array_alloc(int nb)
 {
 	void *ptr;
@@ -624,6 +650,7 @@ struct starpu_data_descr *fstarpu_data_descr_array_alloc(int nb)
 	return ptr;
 }
 
+STARPU_ATTRIBUTE_MALLOC
 struct starpu_data_descr *fstarpu_data_descr_alloc(void)
 {
 	return fstarpu_data_descr_array_alloc(1);
@@ -650,6 +677,7 @@ void fstarpu_data_descr_set(struct starpu_data_descr *descr, starpu_data_handle_
 	fstarpu_data_descr_array_set(descr, 1, handle, mode);
 }
 
+STARPU_ATTRIBUTE_MALLOC
 struct starpu_data_filter *fstarpu_data_filter_allocate(void)
 {
 	struct starpu_data_filter *filter;
@@ -660,6 +688,7 @@ struct starpu_data_filter *fstarpu_data_filter_allocate(void)
 /* Note: use fstarpu_df_alloc_ prefix instead of fstarpu_data_filter_allocate_ to fit within the
  * Fortran id length limit */
 #define _FSTARPU_DATA_FILTER_ALLOCATOR(name) \
+STARPU_ATTRIBUTE_MALLOC \
 struct starpu_data_filter *fstarpu_df_alloc_##name(void) \
 { \
 	struct starpu_data_filter *filter = fstarpu_data_filter_allocate(); \
