@@ -1,8 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2011-2013,2017                           Inria
- * Copyright (C) 2011-2013,2015,2017                      CNRS
- * Copyright (C) 2012-2014                                Université de Bordeaux
+ * Copyright (C) 2011-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -44,7 +42,7 @@ unregister_handle(void)
 	starpu_data_unregister(handle);
 }
 
-#if defined(STARPU_USE_CUDA) || defined(STARPU_USE_OPENCL) || defined(STARPU_USE_MIC)
+#if defined(STARPU_USE_CUDA) || defined(STARPU_USE_OPENCL)
 static void
 create_and_submit(int where)
 {
@@ -56,9 +54,6 @@ create_and_submit(int where)
 #endif
 #ifdef STARPU_USE_OPENCL
 		.opencl_funcs = {opencl_func},
-#endif
-#ifdef STARPU_USE_MIC
-		.mic_funcs = {mic_func},
 #endif
 		.nbuffers    = 1
 	};
@@ -68,7 +63,7 @@ create_and_submit(int where)
 	task->cl = &cl;
 	task->handles[0] = handle;
 
-	/* We need to be sure the data has been copied to the GPU at the end 
+	/* We need to be sure the data has been copied to the GPU at the end
 	 * of this function */
 	task->synchronous = 1;
 	if (starpu_task_submit(task) == -ENODEV)
@@ -119,25 +114,6 @@ test(void)
 	}
 #endif /* !STARPU_USE_OPENCL */
 
-#ifdef STARPU_USE_MIC
-	create_and_submit(STARPU_MIC);
-	starpu_data_acquire(handle, STARPU_RW);
-
-	expected_stats.mic = 1;
-	expected_stats.cpu_to_mic = 1;
-	expected_stats.mic_to_cpu = 1;
-
-	starpu_data_release(handle);
-	if (compare_stats(&global_stats, &expected_stats) != 0)
-	{
-		FPRINTF(stderr, "MIC failed\n");
-		print_stats(&global_stats);
-		FPRINTF(stderr ,"\n");
-		print_stats(&expected_stats);
-		return -ENODEV;
-	}
-#endif /* !STARPU_USE_CUDA */
-
 	return 0;
 }
 
@@ -149,9 +125,12 @@ main(int argc, char **argv)
 	struct starpu_conf conf;
 	starpu_conf_init(&conf);
 
+#if defined(STARPU_USE_CUDA0) || defined(STARPU_USE_CUDA1)
+	conf.ncuda = 0;
+#else
 	conf.ncuda = 1;
+#endif
 	conf.nopencl = 1;
-	conf.nmic = 1;
 	memset(&global_stats, 0, sizeof(global_stats));
 	ret = starpu_initialize(&conf, &argc, &argv);
 	if (ret == -ENODEV || starpu_cpu_worker_get_count() == 0) return STARPU_TEST_SKIPPED;
