@@ -1,7 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2011,2012                                Inria
- * Copyright (C) 2012,2015-2017                           CNRS
+ * Copyright (C) 2011-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -74,24 +73,11 @@ void test_variable_opencl_func(void *buffers[], void *args)
 
 	{
 		size_t global = 1;
-		size_t local;
-                size_t s;
+                size_t local = 1;
                 cl_device_id device;
 
                 starpu_opencl_get_device(devid, &device);
 
-                err = clGetKernelWorkGroupInfo (kernel,
-						device,
-						CL_KERNEL_WORK_GROUP_SIZE,
-						sizeof(local),
-						&local,
-						&s);
-                if (err != CL_SUCCESS)
-			STARPU_OPENCL_REPORT_ERROR(err);
-
-                if (local > global)
-			local = global;
-
 		err = clEnqueueNDRangeKernel(queue,
 					kernel,
 					1,
@@ -109,7 +95,7 @@ void test_variable_opencl_func(void *buffers[], void *args)
 	err = clEnqueueReadBuffer(queue,
 				  fail,
 				  CL_TRUE,
-				  0, 
+				  0,
 				  sizeof(int),
 				  &variable_config.copy_failed,
 				  0,
