@@ -1,8 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2012-2013                                Inria
- * Copyright (C) 2012-2013                                CNRS
- * Copyright (C) 2011,2013-2016                           Université de Bordeaux
+ * Copyright (C) 2011-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -55,7 +53,8 @@ int main(int argc, char **argv)
 
 	starpu_vector_data_register(&handle, STARPU_MAIN_RAM, (uintptr_t)foo, size, sizeof(*foo));
 
-	starpu_task_insert(&scal_codelet, STARPU_RW, handle, 0);
+	ret = starpu_task_insert(&scal_codelet, STARPU_RW, handle, 0);
+	STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_insert");
 
 	struct starpu_data_filter f =
 	{
@@ -100,6 +99,7 @@ int main(int argc, char **argv)
         return ret;
 
 enodev:
+	starpu_data_unpartition(handle, STARPU_MAIN_RAM);
 	starpu_data_unregister(handle);
 	fprintf(stderr, "WARNING: No one can execute this task\n");
 	/* yes, we do not perform the computation but we did detect that no one
