@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2015-2023  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2015-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -24,20 +24,35 @@
 void sum_cpu(void * descr[], void *cl_arg)
 {
 	(void)cl_arg;
-	double * v_dst = (double *) STARPU_VARIABLE_GET_PTR(descr[0]);
-	double * v_src = (double *) STARPU_VARIABLE_GET_PTR(descr[1]);
+	double * v_dst = (double *) STARPU_VECTOR_GET_PTR(descr[0]);
+	double * v_src = (double *) STARPU_VECTOR_GET_PTR(descr[1]);
+	STARPU_ASSERT(v_dst == v_src);
 	*v_dst+=*v_src;
 }
 
 void sum3_cpu(void * descr[], void *cl_arg)
 {
 	(void)cl_arg;
-	double * v_src1 = (double *) STARPU_VARIABLE_GET_PTR(descr[1]);
-	double * v_src2 = (double *) STARPU_VARIABLE_GET_PTR(descr[1]);
-	double * v_dst = (double *) STARPU_VARIABLE_GET_PTR(descr[0]);
+	double * v_src1 = (double *) STARPU_VECTOR_GET_PTR(descr[0]);
+	double * v_src2 = (double *) STARPU_VECTOR_GET_PTR(descr[1]);
+	double * v_dst = (double *) STARPU_VECTOR_GET_PTR(descr[2]);
+	STARPU_ASSERT(v_dst == v_src1);
+	STARPU_ASSERT(v_dst == v_src2);
 	*v_dst+=*v_src1+*v_src2;
 }
 
+void sum4_cpu(void * descr[], void *cl_arg)
+{
+	(void)cl_arg;
+	double * v_src1 = (double *) STARPU_VECTOR_GET_PTR(descr[0]);
+	double * v_src2 = (double *) STARPU_VECTOR_GET_PTR(descr[1]);
+	double * v_dst1 = (double *) STARPU_VECTOR_GET_PTR(descr[2]);
+	double * v_dst2 = (double *) STARPU_VECTOR_GET_PTR(descr[3]);
+	STARPU_ASSERT(v_src1 == v_dst1);
+	STARPU_ASSERT(v_src2 == v_dst2);
+	*v_dst2 = (*v_dst1+=*v_src1+*v_src2);
+}
+
 static struct starpu_codelet sum_cl =
 {
 	.cpu_funcs = {sum_cpu},
@@ -54,11 +69,20 @@ static struct starpu_codelet sum3_cl =
 	.modes={STARPU_R,STARPU_R,STARPU_RW}
 };
 
+static struct starpu_codelet sum4_cl =
+{
+	.cpu_funcs = {sum4_cpu},
+	.cpu_funcs_name = {"sum4_cpu"},
+	.nbuffers = 4,
+	.modes={STARPU_R,STARPU_R,STARPU_RW,STARPU_RW}
+};
+
+#define N 10
 int main(void)
 {
 	starpu_data_handle_t handle;
 	int ret = 0;
-	double value=1.0;
+	double value[N] = { 1.0 };
 	int i;
 	struct starpu_conf conf;
 
@@ -71,7 +95,7 @@ int main(void)
 	ret=starpu_init(&conf);
 	if (ret == -ENODEV) return STARPU_TEST_SKIPPED;
 
-	starpu_variable_data_register(&handle,0,(uintptr_t)&value,sizeof(double));
+	starpu_vector_data_register(&handle,0,(uintptr_t)&value,N,sizeof(double));
 
 	for (i=0; i<2; i++)
 	{
@@ -88,13 +112,32 @@ int main(void)
 		if (ret == -ENODEV) goto enodev;
 	}
 
-	starpu_task_wait_for_all();
-	starpu_data_unregister(handle);
-	if (value != 36)
+	starpu_data_acquire(handle, STARPU_R);
+	if (value[0] != 36)
 	{
-		FPRINTF(stderr, "value is %f instead of %f\n", value, 36.);
+		FPRINTF(stderr, "value is %f instead of %f\n", value[0], 36.);
 		ret = EXIT_FAILURE;
 	}
+	starpu_data_release(handle);
+
+	struct starpu_data_filter f =
+	{
+		.filter_func = starpu_vector_filter_block,
+		.nchildren = 2,
+	};
+	starpu_data_partition(handle, &f);
+
+	starpu_task_insert(&sum4_cl,
+			STARPU_R,starpu_data_get_sub_data(handle,1,0),
+			STARPU_R,starpu_data_get_sub_data(handle,1,1),
+			STARPU_RW,starpu_data_get_sub_data(handle,1,0),
+			STARPU_RW,starpu_data_get_sub_data(handle,1,1),
+			0);
+
+	starpu_data_unpartition(handle, STARPU_MAIN_RAM);
+
+	starpu_task_wait_for_all();
+	starpu_data_unregister(handle);
 
 	starpu_shutdown();
 	return ret;
