@@ -1,9 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2015-2017                                CNRS
- * Copyright (C) 2013                                     Inria
- * Copyright (C) 2013-2017                                Université de Bordeaux
- * Copyright (C) 2013                                     Corentin Salingue
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2013-2013  Corentin Salingue
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -28,9 +26,16 @@
 #include <math.h>
 #include "../helper.h"
 
+#if STARPU_MAXNODES == 1
+/* Cannot register a disk */
+int main(int argc, char **argv)
+{
+	return STARPU_TEST_SKIPPED;
+}
+#else
 /*
  * Try to write into disk memory
- * Use mechanism to push datas from main ram to disk ram
+ * Use mechanism to push data from main ram to disk ram
  * Here we force using the pack/unpack mechanism
  */
 
@@ -40,7 +45,7 @@ const struct starpu_data_copy_methods my_vector_copy_data_methods_s;
 struct starpu_data_interface_ops starpu_interface_my_vector_ops;
 
 void starpu_my_vector_data_register(starpu_data_handle_t *handleptr, unsigned home_node,
-                        uintptr_t ptr, uint32_t nx, size_t elemsize)
+			uintptr_t ptr, uint32_t nx, size_t elemsize)
 {
 	struct starpu_vector_interface vector =
 	{
@@ -48,9 +53,10 @@ void starpu_my_vector_data_register(starpu_data_handle_t *handleptr, unsigned ho
 		.ptr = ptr,
 		.nx = nx,
 		.elemsize = elemsize,
-                .dev_handle = ptr,
+		.dev_handle = ptr,
 		.slice_base = 0,
-                .offset = 0
+		.offset = 0,
+		.allocsize = nx * elemsize,
 	};
 
 	starpu_data_register(handleptr, home_node, &vector, &starpu_interface_my_vector_ops);
@@ -61,18 +67,16 @@ int dotest(struct starpu_disk_ops *ops, char *base)
 	int *A, *C;
 
 	/* Initialize StarPU without GPU devices to make sure the memory of the GPU devices will not be used */
+	// Ignore environment variables as we want to force the exact number of workers
 	struct starpu_conf conf;
 	int ret = starpu_conf_init(&conf);
 	if (ret == -EINVAL)
 		return EXIT_FAILURE;
-#ifdef STARPU_HAVE_UNSETENV
-	unsetenv("STARPU_NCUDA");
-	unsetenv("STARPU_NOPENCL");
-#endif
-	conf.ncuda = 0;
-	conf.nopencl = 0;
-	conf.nmic = 0;
-	conf.nscc = 0;
+	conf.precedence_over_environment_variables = 1;
+	starpu_conf_noworker(&conf);
+	conf.ncpus = -1;
+	conf.nmpi_ms = -1;
+	conf.ntcpip_ms = -1;
 	ret = starpu_init(&conf);
 	if (ret == -ENODEV) goto enodev;
 
@@ -145,23 +149,23 @@ int dotest(struct starpu_disk_ops *ops, char *base)
 	if (f == NULL)
 		goto enoent2;
 
-	/* replace all datas by 0 */
+	/* replace all data by 0 */
 	fwrite(C, sizeof(int), NX, f);
 
 	/* close the file */
 	fclose(f);
 
-        descriptor = open(path_file_end, O_RDWR);
+	descriptor = open(path_file_end, O_RDWR);
 	if (descriptor < 0)
 		goto enoent2;
 #ifdef STARPU_HAVE_WINDOWS
-        _commit(descriptor);
+	_commit(descriptor);
 #else
-        fsync(descriptor);
+	fsync(descriptor);
 #endif
 	close(descriptor);
 
-	/* And now, you want to use your datas in StarPU */
+	/* And now, you want to use your data in StarPU */
 	/* Open the file ON the disk */
 	void * data = starpu_disk_open(dd, (void *) name_file_start, NX*sizeof(int));
 	void * data_result = starpu_disk_open(dd, (void *) name_file_end, NX*sizeof(int));
@@ -192,9 +196,9 @@ int dotest(struct starpu_disk_ops *ops, char *base)
 	f = fopen(path_file_end, "rb+");
 	if (f == NULL)
 		goto enoent2;
-	/* take datas */
+	/* take data */
 	size_t read = fread(C, sizeof(int), NX, f);
-        STARPU_ASSERT(read == NX);
+	STARPU_ASSERT(read == NX);
 
 	/* close the file */
 	fclose(f);
@@ -258,6 +262,10 @@ int main(void)
 	char s[128];
 	char *ptr;
 
+#ifdef STARPU_HAVE_SETENV
+	setenv("STARPU_CALIBRATE_MINIMUM", "1", 1);
+#endif
+
 	snprintf(s, sizeof(s), "/tmp/%s-disk-XXXXXX", getenv("USER"));
 	ptr = _starpu_mkdtemp(s);
 	if (!ptr)
@@ -277,3 +285,4 @@ int main(void)
 		STARPU_CHECK_RETURN_VALUE(-errno, "rmdir '%s'\n", s);
 	return ret;
 }
+#endif
