@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2011-2023  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2011-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -25,6 +25,9 @@ void cpu_increment(void *descr[], void *arg)
 	(*var) += 2;
 }
 
+/* Also test that the application can provide its own main function */
+#undef main
+
 int main(void)
 {
         starpu_data_handle_t data_handles[2];
@@ -36,6 +39,9 @@ int main(void)
 	starpu_conf_init(&conf);
 	starpu_conf_noworker(&conf);
 	conf.ncpus = -1;
+#ifndef STARPU_SIMGRID
+	conf.ncuda = -1;
+#endif
 	conf.nmpi_ms = -1;
 	conf.ntcpip_ms = -1;
 
