@@ -1,7 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2012-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2013       Thibaut Lambert
+ * Copyright (C) 2012-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2013-2013  Thibaut Lambert
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -46,6 +46,8 @@ static int check_cpu(int env_cpu, int conf_cpu, int precedence_over_env, int exp
 
 	struct starpu_conf user_conf;
 	starpu_conf_init(&user_conf);
+	user_conf.nmpi_ms = 0;
+	user_conf.ntcpip_ms = 0;
 	user_conf.precedence_over_environment_variables = precedence_over_env;
 
 	if (conf_cpu != -1)
