@@ -1,7 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010-2012, 2015  Université de Bordeaux
- * Copyright (C) 2010, 2011, 2012, 2013  Centre National de la Recherche Scientifique
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -20,15 +19,21 @@
 #include <starpu.h>
 #include "../helper.h"
 
+/*
+ * Test task submission
+ */
+
 static int i = 0, j;
 
-static void dummy_func(void *descr[] STARPU_ATTRIBUTE_UNUSED, void *arg STARPU_ATTRIBUTE_UNUSED)
+void dummy_func(void *descr[], void *arg)
 {
+	(void)descr;
+	(void)arg;
 	int old_i = STARPU_ATOMIC_ADD(&i, 1);
 	FPRINTF(stdout, "called third task, i = %d\n", old_i+1);
 }
 
-static struct starpu_codelet dummy_codelet = 
+static struct starpu_codelet dummy_codelet =
 {
 	.cpu_funcs = {dummy_func},
 	.cuda_funcs = {dummy_func},
@@ -37,17 +42,18 @@ static struct starpu_codelet dummy_codelet =
 	.nbuffers = 0
 };
 
-static void callback(void *arg STARPU_ATTRIBUTE_UNUSED)
+static void callback(void *arg)
 {
+	(void)arg;
 	struct starpu_task *task = starpu_task_create();
 	task->cl = &dummy_codelet;
 	task->detach = 1;
-	if (starpu_task_submit(task) == ENODEV)
+	if (starpu_task_submit(task) == -ENODEV)
 		exit(STARPU_TEST_SKIPPED);
 	FPRINTF(stdout, "submitted third task, i = %d\n", i);
 }
 
-static struct starpu_codelet callback_submit_codelet = 
+static struct starpu_codelet callback_submit_codelet =
 {
 	.cpu_funcs = {dummy_func},
 	.cuda_funcs = {dummy_func},
@@ -56,19 +62,21 @@ static struct starpu_codelet callback_submit_codelet =
 	.nbuffers = 0
 };
 
-static void task_submit_func(void *descr[] STARPU_ATTRIBUTE_UNUSED, void *arg STARPU_ATTRIBUTE_UNUSED)
+static void task_submit_func(void *descr[], void *arg)
 {
+	(void)descr;
+	(void)arg;
 	struct starpu_task *task = starpu_task_create();
 	task->cl = &callback_submit_codelet;
 	task->callback_func = callback;
 	task->detach = 1;
-	if (starpu_task_submit(task) == ENODEV)
+	if (starpu_task_submit(task) == -ENODEV)
 		exit(STARPU_TEST_SKIPPED);
 	int old_i = STARPU_ATOMIC_ADD(&i, 1);
 	FPRINTF(stdout, "submitted second task, i = %d\n", old_i + 1);
 }
 
-static struct starpu_codelet task_submit_codelet = 
+static struct starpu_codelet task_submit_codelet =
 {
 	.cpu_funcs = {task_submit_func},
 	.cuda_funcs = {task_submit_func},
@@ -77,7 +85,7 @@ static struct starpu_codelet task_submit_codelet =
 	.nbuffers = 0
 };
 
-int main(int argc, char **argv)
+int main(void)
 {
 	int ret;
 
