@@ -1,7 +1,7 @@
 #!/bin/bash
 # StarPU --- Runtime system for heterogeneous multicore architectures.
 #
-# Copyright (C) 2016-2023  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+# Copyright (C) 2010-2025   University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
 #
 # StarPU is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -19,6 +19,6 @@ if test -n "$STARPU_MICROBENCHS_DISABLED" ; then exit 77 ; fi
 
 source $(dirname $0)/microbench.sh
 
-XSUCCESS="dmda dmdap dmdar dmdas dmdasd pheft"
+XSUCCESS="dmda dmdap dmdar dmdas dmdasd modular-dmda modular-dmdap modular-dmdar modular-dmdas pheft"
 
 test_scheds parallel_independent_heterogeneous_tasks_data
