@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2014-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2014-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -58,7 +58,7 @@ void task_region_h(void *buffers[], void *args)
 
 	for (i = 0; i < nx; i++)
 	{
-                v[i] += f;
+		v[i] += f;
 	}
 
 	printf("depth 2 task ending\n");
@@ -84,6 +84,7 @@ void task_region_g(void *buffers[], void *args)
 		}
 
 		starpu_vector_data_register(&task_vector_handle, STARPU_MAIN_RAM, (uintptr_t)v, NX, sizeof(v[0]));
+		starpu_omp_handle_register(task_vector_handle);
 		printf("depth 1 task, block 1: task_vector_handle = %p\n", task_vector_handle);
 	}
 
@@ -92,22 +93,22 @@ void task_region_g(void *buffers[], void *args)
 		struct starpu_omp_task_region_attr attr;
 		int i;
 
-		task_vector_handle = starpu_data_lookup(v);
+		task_vector_handle = starpu_omp_data_lookup(v);
 		printf("depth 1 task, block 2: task_vector_handle = %p\n", task_vector_handle);
 
 		memset(&attr, 0, sizeof(attr));
 #ifdef STARPU_SIMGRID
-		attr.cl.model         = &starpu_perfmodel_nop;
+		attr.cl.model	      = &starpu_perfmodel_nop;
 #endif
-		attr.cl.flags         = STARPU_CODELET_SIMGRID_EXECUTE;
+		attr.cl.flags	      = STARPU_CODELET_SIMGRID_EXECUTE;
 		attr.cl.cpu_funcs[0]  = task_region_h;
-		attr.cl.where         = STARPU_CPU;
+		attr.cl.where	      = STARPU_CPU;
 		attr.cl.nbuffers      = 1;
 		attr.cl.modes[0]      = STARPU_RW;
-		attr.handles          = &task_vector_handle;
+		attr.handles	      = &task_vector_handle;
 		attr.cl_arg_size      = sizeof(void *);
 		attr.cl_arg_free      = 0;
-		attr.if_clause        = 1;
+		attr.if_clause	      = 1;
 		attr.final_clause     = 0;
 		attr.untied_clause    = 1;
 		attr.mergeable_clause = 0;
@@ -125,6 +126,7 @@ void task_region_g(void *buffers[], void *args)
 
 void master_g1(void *arg)
 {
+	(void)arg;
 	starpu_data_handle_t region_vector_handle;
 	int i;
 
@@ -135,31 +137,33 @@ void master_g1(void *arg)
 	}
 
 	starpu_vector_data_register(&region_vector_handle, STARPU_MAIN_RAM, (uintptr_t)global_vector, NX, sizeof(global_vector[0]));
+	starpu_omp_handle_register(region_vector_handle);
 	printf("master_g1: region_vector_handle = %p\n", region_vector_handle);
 }
 
 void master_g2(void *arg)
 {
+	(void)arg;
 	starpu_data_handle_t region_vector_handle;
 	struct starpu_omp_task_region_attr attr;
 	int i;
 
-	region_vector_handle = starpu_data_lookup(global_vector);
+	region_vector_handle = starpu_omp_data_lookup(global_vector);
 	printf("master_g2: region_vector_handle = %p\n", region_vector_handle);
 
 	memset(&attr, 0, sizeof(attr));
 #ifdef STARPU_SIMGRID
-	attr.cl.model         = &starpu_perfmodel_nop;
+	attr.cl.model	      = &starpu_perfmodel_nop;
 #endif
-	attr.cl.flags         = STARPU_CODELET_SIMGRID_EXECUTE;
+	attr.cl.flags	      = STARPU_CODELET_SIMGRID_EXECUTE;
 	attr.cl.cpu_funcs[0]  = task_region_g;
-	attr.cl.where         = STARPU_CPU;
+	attr.cl.where	      = STARPU_CPU;
 	attr.cl.nbuffers      = 1;
 	attr.cl.modes[0]      = STARPU_RW;
-	attr.handles          = &region_vector_handle;
+	attr.handles	      = &region_vector_handle;
 	attr.cl_arg_size      = sizeof(void *);
 	attr.cl_arg_free      = 0;
-	attr.if_clause        = 1;
+	attr.if_clause	      = 1;
 	attr.final_clause     = 0;
 	attr.untied_clause    = 1;
 	attr.mergeable_clause = 0;
@@ -178,11 +182,13 @@ void master_g2(void *arg)
 
 void parallel_region_f(void *buffers[], void *args)
 {
+	(void)buffers;
+	(void)args;
 	starpu_omp_master(master_g1, NULL);
 	starpu_omp_barrier();
 	{
 		starpu_data_handle_t region_vector_handle;
-		region_vector_handle = starpu_data_lookup(global_vector);
+		region_vector_handle = starpu_omp_data_lookup(global_vector);
 		printf("parallel_region block 1: region_vector_handle = %p\n", region_vector_handle);
 	}
 	starpu_omp_barrier();
@@ -190,24 +196,23 @@ void parallel_region_f(void *buffers[], void *args)
 	starpu_omp_barrier();
 	{
 		starpu_data_handle_t region_vector_handle;
-		region_vector_handle = starpu_data_lookup(global_vector);
+		region_vector_handle = starpu_omp_data_lookup(global_vector);
 		printf("parallel_region block 2: region_vector_handle = %p\n", region_vector_handle);
 	}
 }
 
-int
-main (void)
+int main(void)
 {
 	struct starpu_omp_parallel_region_attr attr;
 
 	memset(&attr, 0, sizeof(attr));
 #ifdef STARPU_SIMGRID
-	attr.cl.model        = &starpu_perfmodel_nop;
+	attr.cl.model	     = &starpu_perfmodel_nop;
 #endif
-	attr.cl.flags        = STARPU_CODELET_SIMGRID_EXECUTE;
+	attr.cl.flags	     = STARPU_CODELET_SIMGRID_EXECUTE;
 	attr.cl.cpu_funcs[0] = parallel_region_f;
-	attr.cl.where        = STARPU_CPU;
-	attr.if_clause       = 1;
+	attr.cl.where	     = STARPU_CPU;
+	attr.if_clause	     = 1;
 	starpu_omp_parallel_region(&attr);
 	return 0;
 }
