@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2014-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -54,8 +54,7 @@ void task_region_f(void *buffers[], void *args)
 	printf("[tid %p] task thread = %d: explicit task \"f\"\n", (void *)tid, worker_id);
 }
 
-int
-main (void)
+int main(void)
 {
 	struct starpu_omp_task_region_attr attr;
 	memset(&attr, 0, sizeof(attr));
