@@ -1,9 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2012-2013                                Inria
- * Copyright (C) 2010-2016                                Université de Bordeaux
- * Copyright (C) 2010-2013,2015,2017                      CNRS
- * Copyright (C) 2013                                     Thibaut Lambert
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2013-2013  Thibaut Lambert
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -33,14 +31,17 @@
 #endif
 #define VECTORSIZE	1024
 
-void codelet_null(void *descr[], STARPU_ATTRIBUTE_UNUSED void *_args)
+void codelet_null(void *descr[], void *_args)
 {
+	(void)descr;
+	(void)_args;
+
 	STARPU_SKIP_IF_VALGRIND;
 
 	int worker_size = starpu_combined_worker_get_size();
 	STARPU_ASSERT(worker_size > 0);
 
-	usleep(1000/worker_size);
+	starpu_usleep(1000./worker_size);
 #if 0
 	int id = starpu_worker_get_id();
 	int combined_id = starpu_combined_worker_get_id();
@@ -62,20 +63,19 @@ static struct starpu_codelet cl =
 	.cpu_funcs = {codelet_null},
 	.cpu_funcs_name = {"codelet_null"},
 	.cuda_funcs = {codelet_null},
-        .opencl_funcs = {codelet_null},
+	.opencl_funcs = {codelet_null},
 	.model = &model,
 	.nbuffers = 1,
 	.modes = {STARPU_R}
 };
 
-
-int main(int argc, char **argv)
+int main(void)
 {
 	int ret;
 	starpu_data_handle_t v_handle;
 	unsigned *v;
 
-        struct starpu_conf conf;
+	struct starpu_conf conf;
 	starpu_conf_init(&conf);
 	conf.sched_policy_name = "pheft";
 	conf.calibrate = 1;
@@ -89,8 +89,13 @@ int main(int argc, char **argv)
 
 	unsigned nworker = starpu_worker_get_count() + starpu_combined_worker_get_count();
 
-	unsigned iter, worker;
-	for (iter = 0; iter < N; iter++)
+	unsigned iter, worker, n;
+	n = N;
+	if (STARPU_RUNNING_ON_VALGRIND)
+	{
+		n /= 300;
+	}
+	for (iter = 0; iter < n; iter++)
 	{
 		for (worker = 0; worker < nworker; worker++)
 		{
@@ -110,16 +115,16 @@ int main(int argc, char **argv)
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_wait_for_all");
 
 	starpu_data_unregister(v_handle);
-	starpu_free(v);
+	starpu_free_noflag(v, VECTORSIZE*sizeof(unsigned));
 	starpu_shutdown();
 	STARPU_RETURN(EXIT_SUCCESS);
 
 enodev:
 	starpu_data_unregister(v_handle);
-	starpu_free(v);
+	starpu_free_noflag(v, VECTORSIZE*sizeof(unsigned));
 	fprintf(stderr, "WARNING: No one can execute this task\n");
 	/* yes, we do not perform the computation but we did detect that no one
- 	 * could perform the kernel, so this is not an error from StarPU */
+	 * could perform the kernel, so this is not an error from StarPU */
 	starpu_shutdown();
 	STARPU_RETURN(STARPU_TEST_SKIPPED);
 }
