@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2014-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -43,8 +43,8 @@ static struct starpu_codelet my_codelet =
 
 double cuda_cost_function(struct starpu_task *t, struct starpu_perfmodel_arch *a, unsigned i)
 {
-	t;
-	a;
+	(void) t;
+	(void) a;
 	return (double)i;
 }
 
